(function() {
	var Loading = /*@__PURE__*/ (function(Component) {
		function Loading(props) {
			Component.call(this, props);
			this.data = {};
		}

		if (Component) Loading.__proto__ = Component;
		Loading.prototype = Object.create(Component && Component.prototype);
		Loading.prototype.constructor = Loading;
		Loading.prototype.apiready = function() {};
		Loading.prototype.render = function() {
			return apivm.h("image", {
				class: "" + (this.props.type ? "loading_" + this.props.type : "loading_"),
				src: "../../image/loading.gif"
			});
		};

		return Loading;
	})(Component);
	Loading.css = {
		".loading_": {
			width: "65px",
			height: "65px",
			position: "absolute",
			top: "43%",
			left: "50%",
			transform: "translateX(-25px)",
			zIndex: "99"
		},
		".loading_login": {
			width: "65px",
			height: "65px",
			position: "absolute",
			top: "17%",
			left: "50%",
			transform: "translateX(-25px)",
			zIndex: "99"
		}
	};
	apivm.define("loading", Loading);

	// api接口请求地址
	var BASEURL = "https://cbt.tibaitong.com/";

	// 请求权限名字
	var PERMISSIONNAME = {
		camera: "相机", // 相机/拍照/录像
		photos: "访问相册", // 访问相册|本地存储空间。Android上等同storage权限
		phone: "电话", // 直接拨打电话/获取手机号码|IMEI。只支持Android
		storage: "存储", // 读取/写入|相册|多媒体|本地存储空间。只支持Android
		"phone-r": "设备信息"
	};

	// 文件类型图标
	var FILETYPE = {
		default: "https://files.zhuokao360.com/images/fileType/unknown.png",
		txt: "https://files.zhuokao360.com/images/fileType/txt.png",
		pdf: "https://files.zhuokao360.com/images/fileType/pdf.png",
		doc: "https://files.zhuokao360.com/images/fileType/word.png",
		docx: "https://files.zhuokao360.com/images/fileType/word.png",
		ppt: "https://files.zhuokao360.com/images/fileType/ppt.png",
		pptx: "https://files.zhuokao360.com/images/fileType/ppt.png",
		rar: "https://files.zhuokao360.com/images/fileType/rar.png",
		zip: "https://files.zhuokao360.com/images/fileType/rar.png",
		jpg: "https://files.zhuokao360.com/images/fileType/image.png",
		png: "https://files.zhuokao360.com/images/fileType/image.png",
		mp4: "https://files.zhuokao360.com/images/fileType/video.png"
	};

	/********************************************
	 *             系统和业务                   *
	 ******************************************/

	// 本地存储
	var storage = {
		set: function set(key, value) {
			api.setPrefs({
				key: key,
				value: typeof value === "string" ? value : JSON.stringify(value)
			});
		},

		get: function get(key) {
			var value = api.getPrefs({sync: true, key: key}) || "";

			try {
				return JSON.parse(value);
			} catch (e) {
				return value;
			}
		},

		del: function del(key) {
			api.removePrefs({key: key});
		}
	};

	// 请求
	function ajax(_ref) {
		var url = _ref.url,
			_ref$method = _ref.method,
			method = _ref$method === void 0 ? "get" : _ref$method,
			_ref$data = _ref.data,
			data = _ref$data === void 0 ? {} : _ref$data;
		return new Promise(function(resolve, reject) {
			api.ajax(
				{
					url: url.indexOf("http") === 0 ? url : BASEURL + url,
					method: method,
					headers: {
						"Content-Type": "application/json;charset=utf-8",
						"ZK-TOKEN": storage.get("token"),
						"APP-TYPE": 2
					},

					timeout: 60,
					data: {
						body: data
					}
				},

				function(ret, err) {
					if (ret) {
						if (ret.code === 200) {
							resolve(ret.data);
						} else if (ret.code === 600) {
							api.sendEvent({
								name: "loginExpired"
							});
						} else {
							api.toast({
								msg: ret.msg
							});
						}

						reject(ret);
					} else {
						api.toast({
							msg: "网络不畅,请检查网络"
						});

						reject(err);
					}
				}
			);
		});
	}

	// 获取登录状态
	function getLoginStatus() {
		return storage.get("isLogin") || false;
	}

	// 获取用户信息（包括昵称、头像、个性签名等）
	function getUserInfo() {
		return storage.get("userInfo") || {};
	}

	// 打开登录页面
	function openLogin() {
		api.openTabLayout({
			name: "login",
			url: "../login/login.stml",
			navigationBar: {
				background: "#5538de",
				shadow: "#5538de",
				color: "#fff"
			}
		});
	}

	/**
	 * 判断是否拥有设备权限
	 * @param {Array} perms 权限列表
	 */
	function hasPermission(perms) {
		var resultList = api.hasPermission({
			list: perms
		});

		return resultList;
	}

	/**
	 * 向系统请求设备权限
	 * @param {Array} perms 权限列表
	 */
	function requestPermission(perms) {
		api.requestPermission({
			list: perms,
			code: 1
		});
	}

	/**
	 * 确认设备权限(无权限提示获取)
	 * @param {Array} perms 权限列表
	 */
	function confirmPermission(perms) {
		var resultList = hasPermission(perms);

		// 获取需要请求的权限列表
		var requestList = [];
		resultList.forEach(function(item, index) {
			if (!item || !item.granted) {
				requestList.push(perms[index]);
			}
		});

		// 如果拥有全部权限
		if (requestList.length === 0) {
			return true;
		}

		// 否则，提示请求权限
		var str = "";
		requestList.forEach(function(per) {
			str += PERMISSIONNAME[per] + "\u3001";
		});
		str = str.slice(0, str.length - 1);

		if (str === "存储") {
			api.confirm(
				{
					title: "权限说明",
					msg:
						"\u5E94\u7528\u5BF9" +
						str +
						"\u6743\u9650\u7533\u8BF7\u8BF4\u660E\uFF1A\u4FBF\u4E8E\u60A8\u4F7F\u7528\u8BE5\u529F\u80FD\u4FDD\u5B58\u6587\u4EF6/\u89C6\u9891\u7528\u4E8E\u7F13\u5B58\u79BB\u7EBF\u89C6\u9891\u3001\u8BB2\u4E49\u7684\u573A\u666F\u4E2D\u8BFB\u53D6\u548C\u5199\u5165\u8BBE\u5907\u5B58\u50A8\u3002",
					buttons: ["去设置", "取消"]
				},

				function(ret) {
					if (ret.buttonIndex === 1) {
						requestPermission(perms);
					}
				}
			);
		} else {
			api.confirm(
				{
					title: "权限说明",
					msg:
						"\u5E94\u7528\u5BF9" +
						str +
						"\u6743\u9650\u7533\u8BF7\u8BF4\u660E\uFF1A\u4FBF\u4E8E\u60A8\u4F7F\u7528\u8BE5\u529F\u80FD\u4E0A\u4F20\u7167\u7247/\u56FE\u7247\u7528\u4E8E\u610F\u89C1\u53CD\u9988\u3001\u4FDD\u5B58\u76F8\u518C\u3001\u4E0B\u8F7D\u7684\u573A\u666F\u4E2D\u8BFB\u53D6\u548C\u5199\u5165\u76F8\u518C\u3002",
					buttons: ["去设置", "取消"]
				},

				function(ret) {
					if (ret.buttonIndex === 1) {
						requestPermission(perms);
					}
				}
			);
		}

		return false;
	}

	/**
	 * 格式化文件大小, 输出成带单位的字符串
	 * @param {Number} size 文件大小
	 */
	function formatFileSize(size) {
		var units = ["B", "K", "M", "G", "TB"];
		var fileSize = parseInt(size);
		for (var i = 0; fileSize >= 1024; i += 1) {
			fileSize /= 1024;
			units.shift();
		}
		return fileSize.toFixed(1) + units[0];
	}

	/**
	 * 浏览器打开
	 * @param {String} url 需要打开的地址
	 */
	function openBrowser(url) {
		// api.openApp({
		//   androidPkg: 'android.intent.action.VIEW',
		//   uri: url,
		//   iosUrl: url,
		// });
		// ios
		if (api.systemType == "ios") {
			api.openApp({
				iosUrl: url
			});
		} else {
			// 安卓

			var jumpbrowser = api.require("jumpbrowser");
			var param = {Url: url};
			jumpbrowser.jumpBrowser(param, function(ret, err) {
				if (err) {
					api.alert({
						title: "提示",
						msg: "出错了,请稍后再试"
					});
				}
			});
		}
	}

	/**
	 * 未登录做题提示
	 */
	function noLoginDoQuestionTip() {
		api.confirm(
			{
				title: "需要登录",
				msg: "为了保存您的做题进度，请登录后使用。",
				buttons: ["去登录", "稍后再说"]
			},
			function(ret) {
				if (ret.buttonIndex === 1) {
					openLogin();
				}
			}
		);
	}

	/**
	 * 打开一个带导航的本地页面
	 * @param {String} name 标题
	 * @param {String} title 标题
	 * @param {String} url 网络地址
	 */
	function openNavStml(name, title, url) {
		api.openTabLayout({
			name: name,
			title: title,
			url: url,
			navigationBar: {}
		});
	}

	/**
	 * 打开一个webview页面
	 * @param {String} title 标题
	 * @param {String} url 网络地址
	 */
	function openWebview(title, url) {
		api.openTabLayout({
			name: "webview",
			url: url,
			title: title,
			navigationBar: {},
			slidBackEnabled: false, // 是否支持滑动返回
			avm: false
		});
	}

	function toast(msg) {
		api.toast({msg: msg});
	}

	/**
	 * 获取课程学习进度
	 * @param {Number} courseId 课程id
	 * @param {Number} type 课程类型
	 */
	function getCourseProgress(courseId, type) {
		if (type === void 0) {
			type = 1;
		}
		return ajax({
			url: "courseStage/getCourseLearnInfo",
			data: {
				courseId: courseId,
				type: type
			}
		});
	}

	/**
	 * 获取课时列表
	 * @param {Number} courseId 课程id
	 * @param {Number} type 课程类型
	 */
	function getLessonList(courseId, type) {
		if (type === void 0) {
			type = 1;
		}
		return ajax({
			// url: 'courseStage/findCourseStageByType',
			url: "courseStage/findNewCourseStageType",
			data: {
				courseId: courseId,
				type: type
			}
		});
	}

	/**
	 * 获取真题列表
	 * @param {Number} courseId 课程id
	 */
	function getQuestionList(courseId) {
		return ajax({
			url: "section/findSectionBy",
			data: {
				courseId: courseId,
				sectionType: 8
			}
		});
	}

	/**
	 * 是否有资料
	 * @param {Number} courseId 课程id
	 * @param {Number} type 课程类型
	 */
	function isHasFile(courseId) {
		return ajax({
			url: "videoHandout/isHas",
			data: {
				courseId: courseId,
				type: 12
			}
		});
	}

	/**
	 * 获取资料列表，读取讲义表
	 * @param {Number} courseId 课程id
	 */
	function getHandoutList(courseId, type) {
		return ajax({
			url: "videoHandout/findVideoHandout",
			data: {
				courseId: courseId,
				type: type
			}
		});
	}

	/**
	 * 记录用户讲义下载记录
	 * @param {Number} courseId 课程id
	 * @param {Number} handoutId 讲义id
	 */
	function saveUserHandout(handoutId, courseId) {
		return ajax({
			url: "/videoHandout/saveUserHandout",
			method: "post",
			data: {
				handoutId: handoutId,
				courseId: courseId
			}
		});
	}

	/**
	 * 记录用户视频下载记录
	 * @param {Number} courseId 课程id
	 * @param {Number} handoutId 讲义id
	 */
	function saveUserVideo(courseId, videoId) {
		return ajax({
			url: "/videoPlus/saveUserVideo",
			method: "post",
			data: {
				videoId: videoId,
				courseId: courseId
			}
		});
	}

	var HandoutList = /*@__PURE__*/ (function(Component) {
		function HandoutList(props) {
			Component.call(this, props);
		}

		if (Component) HandoutList.__proto__ = Component;
		HandoutList.prototype = Object.create(Component && Component.prototype);
		HandoutList.prototype.constructor = HandoutList;
		HandoutList.prototype.downloadHandout = function(handout, courseId) {
			// 更新下载记录
			saveUserHandout(handout.videoHandoutId, courseId)
				.then(function(res) {
					console.log(res, "res");
					// 下载讲义
					openBrowser(handout.downloadUrl);
				})
				.catch(function(err) {
					console.log(err, "err");
				});
		};
		HandoutList.prototype.file = function(type) {
			return FILETYPE[type] || FILETYPE.default;
		};
		HandoutList.prototype.render = function() {
			var this$1 = this;
			return apivm.h(
				"view",
				{class: "handout-list"},

				(Array.isArray(this.props.list)
					? this.props.list
					: Object.values(this.props.list)
				).map(function(handout) {
					return apivm.h(
						"view",
						{
							class: "handout-item",
							onClick: function() {
								return this$1.downloadHandout(handout, this$1.props.courseId);
							}
						},

						apivm.h("image", {
							class: "handout-type",
							src: this$1.file(handout.fileType)
						}),
						apivm.h(
							"view",
							{class: "handout-info"},
							apivm.h("text", {class: "handout-title"}, handout.title),
							apivm.h("text", {class: "handout-size"}, formatFileSize(handout.size))
						),
						apivm.h("image", {
							class: "handout-icon",
							src: "../../image/icon/download-file.png"
						})
					);
				})
			);
		};

		return HandoutList;
	})(Component);
	HandoutList.css = {
		".handout-list": {backgroundColor: "#fff", margin: "0 15px 20px"},
		".handout-item": {flexDirection: "row", alignItems: "center", margin: "15px"},
		".handout-type": {width: "30px", height: "30px", marginRight: "10px"},
		".handout-info": {flex: "1"},
		".handout-title": {fontSize: "14px", fontWeight: "bold", color: "#333"},
		".handout-size": {fontSize: "12px", color: "#666", marginTop: "10px"},
		".handout-icon": {width: "15px", height: "15px"}
	};
	apivm.define("handout-list", HandoutList);

	var QuestionList = /*@__PURE__*/ (function(Component) {
		function QuestionList(props) {
			Component.call(this, props);
		}

		if (Component) QuestionList.__proto__ = Component;
		QuestionList.prototype = Object.create(Component && Component.prototype);
		QuestionList.prototype.constructor = QuestionList;
		QuestionList.prototype.openQuestion = function(title, sectionId) {
			var ref = getUserInfo();
			var userId = ref.userId;
			var url =
				"https://cj.zhuokao360.com/questionApp/question/list?sectionId=" +
				sectionId +
				"&userId=" +
				userId;
			openWebview(title, url);
		};
		QuestionList.prototype.render = function() {
			var this$1 = this;
			return apivm.h(
				"view",
				{class: "question-list"},
				(Array.isArray(this.props.list)
					? this.props.list
					: Object.values(this.props.list)
				).map(function(item$1) {
					return apivm.h(
						"view",
						{
							class: "question-item",
							onClick: function() {
								return this$1.openQuestion(item$1.name, item$1.courseSectionId);
							}
						},
						apivm.h(
							"view",
							{class: "question-item-title"},
							apivm.h("image", {
								class: "question-title_icon",
								src: "../../image/icon/course-tab-2.png"
							}),
							apivm.h("text", {class: "question-title_text"}, item$1.name)
						),
						apivm.h(
							"view",
							{class: "question-item-do"},
							apivm.h("image", {
								class: "question-do_icon",
								src: "../../image/icon/course-question.png"
							}),
							apivm.h("text", {class: "do_text"}, "开始做题")
						)
					);
				})
			);
		};

		return QuestionList;
	})(Component);
	QuestionList.css = {
		".question-list": {
			backgroundColor: "#fff",
			borderTop: "1px solid rgba(70, 70, 70, 0.1)",
			margin: "0 15px 20px"
		},
		".question-item": {
			flexDirection: "row",
			alignItems: "center",
			padding: "25px 0",
			margin: "0 15px",
			borderBottom: "0.5px solid rgba(90, 90, 90, 0.1)"
		},
		".question-item-title": {
			flex: "1",
			flexDirection: "row",
			alignItems: "center"
		},
		".question-title_text": {fontSize: "14px", color: "#333"},
		".question-title_icon": {width: "15px", height: "15px", marginRight: "5px"},
		".question-item-do": {flexDirection: "row", alignItems: "center"},
		".question-item-do image": {flexDirection: "row"},
		".question-do_icon": {width: "10px", height: "10px", marginRight: "5px"},
		".do_text": {fontSize: "12px", color: "#666"}
	};
	apivm.define("question-list", QuestionList);

	var downloadManager = api.require("downloadManager");

	// 根据映射的ID查询下载项
	function queryById(id) {
		var map = getMap();
		var downloadId = Object.keys(map).find(function(item) {
			return map[item] === id;
		});

		if (!downloadId) {
			return Promise.resolve();
		}

		return new Promise(function(resolve, reject) {
			downloadManager.query(
				{
					ids: [downloadId]
				},

				function(ret, err) {
					if (ret) {
						if (ret.data && ret.data.length) {
							resolve(ret.data[0]);
						} else {
							delMap(downloadId);
							resolve();
						}
					} else {
						reject(err);
					}
				}
			);
		});
	}

	// 开启下载
	function enqueue(title, url, mapId, savePath) {
		return new Promise(function(resolve, reject) {
			downloadManager.enqueue(
				{
					title: title,
					url: url,
					savePath: savePath,
					allowResume: true // 开启断点续传
				},
				function(ret, err) {
					if (ret) {
						addMap(ret.id, mapId);
						resolve(ret);
					} else {
						reject(err);
					}
				}
			);
		});
	}

	// 打开下载管理
	function openManagerView() {
		downloadManager.openManagerView(
			{
				title: "下载管理"
			},

			function(ret) {
				if (ret && ret.id) {
					// 点击某个下载完成项
					var mapId = getMap(ret.id);
					if (mapId) {
						openVideo(mapId);
					} else {
						openDownloadedFile(id);
					}
				}
			}
		);
	}

	// 打开下载文件
	function openDownloadedFile(id) {
		downloadManager.openDownloadedFile({id: id});
	}

	// 打开视频播放页
	function openVideo(videoId) {
		api.openWin({
			name: "video",
			url: "widget://pages/video/video.stml",
			slidBackEnabled: false,
			pageParam: {
				videoId: videoId
			}
		});
	}

	// 获取映射
	function getMap(downloadId) {
		var map = storage.get("downloadMap") || {};
		return downloadId ? map[downloadId] : map;
	}

	// 保存映射
	function setMap(map) {
		return storage.set("downloadMap", map);
	}

	// 添加映射
	function addMap(downloadId, id) {
		var map = getMap();
		map[downloadId] = id;
		setMap(map);
	}

	// 删除某一映射
	function delMap(downloadId) {
		var map = getMap();
		delete map[downloadId];
		setMap(map);
	}

	var CourseList = /*@__PURE__*/ (function(Component) {
		function CourseList(props) {
			Component.call(this, props);
			this.data = {
				stageIndex: -1
			};
		}

		if (Component) CourseList.__proto__ = Component;
		CourseList.prototype = Object.create(Component && Component.prototype);
		CourseList.prototype.constructor = CourseList;
		CourseList.prototype.openCourse = function(index) {
			this.props.stageArray[index]
				? (this.props.stageArray[index] = 0)
				: (this.props.stageArray[index] = 1);
		};
		CourseList.prototype.openQuestion = function(title, sectionId) {
			var isLogin = getLoginStatus();
			if (!isLogin) {
				noLoginDoQuestionTip();
				return;
			}

			if (!sectionId) {
				toast("不要着急，试题还在准备中~");
				return;
			}

			var ref = getUserInfo();
			var userId = ref.userId;
			var url =
				"https://cj.zhuokao360.com/questionApp/question/list?sectionId=" +
				sectionId +
				"&userId=" +
				userId;
			openWebview(title, url);
		};
		CourseList.prototype.openVideo = function(videoId) {
			api.openWin({
				name: "video",
				url: "../video/video.stml",
				slidBackEnabled: false,
				pageParam: {
					videoId: videoId
				}
			});
		};
		CourseList.prototype.openDownload = function(ref, courseId) {
			var videoId = ref.videoId;
			var name = ref.name;
			var videoUrl = ref.videoUrl;

			if (!videoId || !videoUrl) {
				toast("该视频暂无法下载~");
				return;
			}

			var has = confirmPermission(["storage"]);
			if (!has) {
				return;
			}

			queryById(videoId)
				.then(function(res) {
					if (res) {
						return Promise.resolve(res);
					}

					if (api.systemType != "ios") {
						var downloadManager = api.require("downloadManager");
						downloadManager.getPrivateDirs(function(ret) {
							var savePath = ret.dir + videoId + ".mp4";
							return enqueue(name, videoUrl, videoId, savePath);
						});
					} else {
						var savePath = "fs://video/" + videoId + ".mp4";
						return enqueue(name, videoUrl, videoId, savePath);
					}
				})
				.then(function() {
					// 更新视频下载记录
					saveUserVideo(courseId, videoId).then(function(res) {
						console.log(res, "res");
					});
				})
				.then(function(res) {
					openManagerView();
				})
				.catch(function() {
					toast("出现小错误，请退出重试~");
				});
		};
		CourseList.prototype.buy = function() {
			openNavStml("shop", "购买课程", "../my/shop.stml");
		};
		CourseList.prototype.render = function() {
			var this$1 = this;
			return apivm.h(
				"view",
				{class: "course-list"},
				(Array.isArray(this.props.list)
					? this.props.list
					: Object.values(this.props.list)
				).map(function(item$1, index$1) {
					return apivm.h(
						"view",
						{class: "course-item"},
						apivm.h(
							"view",
							{
								class: "course-item-title",
								onClick: function() {
									return this$1.openCourse(index$1);
								}
							},
							apivm.h("text", {class: "course-title_texts"}, item$1.stageName),
							apivm.h("image", {
								class: this$1.props.stageArray[index$1] ? "arrow_icons" : "arrow_icon",
								src: "../../image/icon/arrow.png"
							})
						),

						apivm.h(
							"view",
							{style: {display: this$1.props.stageArray[index$1] ? "flex" : "none"}},
							(Array.isArray(item$1.lists)
								? item$1.lists
								: Object.values(item$1.lists)
							).map(function(_item, _index) {
								return apivm.h(
									"view",
									{class: "course-item-stage"},
									apivm.h("text", {class: "course-title_text"}, _item.name),
									apivm.h(
										"text",
										{class: _item.isFinish ? "course-status_1" : "course-status_0"},
										_item.isFinish ? "已完成" : "未完成"
									),

									this$1.props.isLogin ||
										(!this$1.props.isLogin && index$1 < 1 && _index <= 1)
										? apivm.h(
												"view",
												{class: "stage-options"},
												_item.questionStatus != 2
													? apivm.h(
															"view",
															{
																class: "stage-options-item",
																onClick: function() {
																	return this$1.openQuestion(_item.sectionName, _item.sectionId);
																}
															},
															apivm.h("image", {
																class: "do_icon",
																src: "../../image/icon/course-question.png"
															}),
															apivm.h("text", {class: "stage-options_text"}, "开始做题")
													  )
													: null,

												apivm.h(
													"view",
													{
														class: "stage-options-item",
														onClick: function() {
															return this$1.openVideo(_item.videoId);
														}
													},
													apivm.h("image", {
														class: "do_icon",
														src: "../../image/icon/course-video.png"
													}),
													apivm.h("text", {class: "stage-options_text"}, "观看视频")
												),

												apivm.h(
													"view",
													{
														class: "stage-options-item",
														onClick: function() {
															return this$1.openDownload(_item, this$1.props.courseId);
														}
													},
													apivm.h("image", {
														class: "do_icon",
														src: "../../image/icon/course-download.png"
													}),
													apivm.h("text", {class: "stage-options_text"}, "下载视频")
												)
										  )
										: null,
									!this$1.props.isLogin && (_index > 1 || index$1 >= 1)
										? apivm.h(
												"view",
												{class: "nologin"},
												apivm.h("text", {class: "nologin_text"}, "付费后解锁课程，"),
												apivm.h("text", {class: "buy", onClick: this$1.buy}, "去购买")
										  )
										: null
								);
							})
						)
					);
				})
			);
		};

		return CourseList;
	})(Component);
	CourseList.css = {
		".course-list": {
			backgroundColor: "#fff",
			borderTop: "1px solid rgba(70, 70, 70, 0.1)",
			margin: "0 15px 20px"
		},
		".course-item": {
			margin: "0 15px",
			borderBottom: "0.5px solid rgba(90, 90, 90, 0.1)"
		},
		".course-item-title": {
			display: "flex",
			flexDirection: "row",
			alignItems: "center",
			padding: "25px 0",
			borderBottom: "0.5px solid rgba(90, 90, 90, 0.1)"
		},
		".course-item-title:active": {backgroundColor: "rgba(200, 200, 200, 0.1)"},
		".course-title_texts": {flex: "1", fontSize: "14px", color: "#333"},
		".course-title_text": {fontSize: "14px", color: "#333"},
		".arrow_icon": {width: "13px", height: "13px", transform: "rotate(90deg)"},
		".arrow_icons": {width: "13px", height: "13px", transform: "rotate(-90deg)"},
		".do_icon": {width: "15px", height: "15px", marginRight: "5px"},
		".course-item-stage": {
			padding: "25px 0",
			borderBottom: "0.5px solid rgba(90, 90, 90, 0.1)"
		},
		".course-status_0": {fontSize: "14px", color: "#de3838", marginTop: "10px"},
		".course-status_1": {fontSize: "14px", color: "#5538de", marginTop: "10px"},
		".stage-options": {flexDirection: "row", width: "100%", marginTop: "25px"},
		".stage-options-item": {
			flexDirection: "row",
			alignItems: "center",
			width: "88px",
			marginRight: "15px"
		},
		".stage-options_text": {fontSize: "13px", color: "#666"},
		".nologin": {flexDirection: "row", marginTop: "25px"},
		".nologin_text": {fontSize: "13px", color: "#666"},
		".buy": {fontSize: "13px", color: "#5538de"}
	};
	apivm.define("course-list", CourseList);

	function _defineProperty(obj, key, value) {
		if (key in obj) {
			Object.defineProperty(obj, key, {
				value: value,
				enumerable: true,
				configurable: true,
				writable: true
			});
		} else {
			obj[key] = value;
		}

		return obj;
	}

	function _inheritsLoose(subClass, superClass) {
		subClass.prototype = Object.create(superClass.prototype);
		subClass.prototype.constructor = subClass;

		_setPrototypeOf(subClass, superClass);
	}

	function _setPrototypeOf(o, p) {
		_setPrototypeOf = Object.setPrototypeOf
			? Object.setPrototypeOf.bind()
			: function _setPrototypeOf(o, p) {
					o.__proto__ = p;
					return o;
			  };
		return _setPrototypeOf(o, p);
	}

	function _assertThisInitialized(self) {
		if (self === void 0) {
			throw new ReferenceError(
				"this hasn't been initialised - super() hasn't been called"
			);
		}

		return self;
	}

	function toCSSLength(val) {
		return typeof val === "number" ? val + "px" : val;
	}

	// packages/avm-ui/src/components/progress-bar/progress-bar.less
	var progress_bar_default =
		".adm-progress-bar {\n  width: 100%;\n  padding: 20px 15px;\n}\n.adm-progress-bar-trail {\n  width: 100%;\n}\n.adm-progress-bar-fill {\n  transition: width 0.3s;\n  height: 100%;\n}\n";

	// packages/avm-ui/src/components/progress-bar/progress-bar.tsx
	var classPrefix = "adm-progress-bar";
	var ProgressBar = /*#__PURE__*/ (function(_Component) {
		_inheritsLoose(ProgressBar, _Component);
		function ProgressBar() {
			var _this;
			for (
				var _len = arguments.length, args = new Array(_len), _key = 0;
				_key < _len;
				_key++
			) {
				args[_key] = arguments[_key];
			}
			_this = _Component.call.apply(_Component, [this].concat(args)) || this;
			_defineProperty(_assertThisInitialized(_this), "render", function(props) {
				var back = {};
				back["height"] = toCSSLength(props.trackWidth) || "2px";
				back["borderRadius"] = toCSSLength(props.borderRadius) || "3px";
				back["backgroundColor"] = props.fillColor || "rgb(229, 229, 229)";
				var styles = {};
				styles["width"] = props.percent + "%";
				styles["width"] =
					props.percent == "0" || 0
						? "0%"
						: props.percent
						? props.percent + "%"
						: "30%";
				styles["background"] = props.trackColor || "#7FA000";
				styles["borderRadius"] = toCSSLength(props.borderRadius) || "3px";
				return apivm.h(
					"div",
					{className: classPrefix},
					apivm.h(
						"div",
						{className: classPrefix + "-trail", style: back},
						apivm.h("div", {className: classPrefix + "-fill", style: styles})
					)
				);
			});
			_defineProperty(_assertThisInitialized(_this), "css", function() {
				return progress_bar_default;
			});
			return _this;
		}
		return ProgressBar;
	})(Component);
	avm.define("avm-progress-bar", ProgressBar);

	var LearnProgress = /*@__PURE__*/ (function(Component) {
		function LearnProgress(props) {
			Component.call(this, props);
		}

		if (Component) LearnProgress.__proto__ = Component;
		LearnProgress.prototype = Object.create(Component && Component.prototype);
		LearnProgress.prototype.constructor = LearnProgress;
		LearnProgress.prototype.renderLeftRate = function(rate) {
			if (rate >= 50) {
				return "transform: rotate(" + 3.6 * (rate - 50) + "deg);";
			}
		};
		LearnProgress.prototype.renderRightRate = function(rate) {
			if (rate < 50) {
				return "transform: rotate(" + 3.6 * rate + "deg);";
			} else {
				return "transform: rotate(0);border-color: #54c4fd;";
			}
		};
		LearnProgress.prototype.render = function() {
			return apivm.h(
				"view",
				{class: "learn-progress"},
				this.props.progress.totalVideoNum
					? apivm.h(
							"view",
							{class: "progress-item"},
							apivm.h("text", {class: "progress-name"}, "视频学习"),
							apivm.h(
								"text",
								{class: "progress-data"},
								this.props.progress.learnVideoNum,
								"/",
								this.props.progress.totalVideoNum
							)
					  )
					: null,
				this.props.progress.totalSectionNum
					? apivm.h(
							"view",
							{class: "progress-item"},
							apivm.h("text", {class: "progress-name"}, "做题练习"),
							apivm.h(
								"text",
								{class: "progress-data"},
								this.props.progress.learnSectionNum,
								"/",
								this.props.progress.totalSectionNum
							)
					  )
					: null,

				apivm.h(
					"view",
					{class: "progress-item"},
					apivm.h("text", {class: "progress-name"}, "总体进度"),
					apivm.h(
						"text",
						{class: "progress-data"},
						this.props.progress.totalRate,
						"%"
					)
				),

				!this.props.isLogin
					? apivm.h(
							"view",
							{class: "progress-nologin"},
							apivm.h("text", {class: "progress-nologin_text"}, "登录后查看学习统计"),
							apivm.h(
								"text",
								{class: "progress-nologin_btn", onClick: openLogin},
								"去登录"
							)
					  )
					: null
			);
		};

		return LearnProgress;
	})(Component);
	LearnProgress.css = {
		".learn-progress": {
			position: "relative",
			flexDirection: "row",
			justifyContent: "space-around",
			alignItems: "center",
			backgroundColor: "#fff",
			borderRadius: "10px",
			padding: "30px 25px",
			margin: "-50px 15px 0"
		},
		".progress-item": {alignItems: "center"},
		".progress-name": {fontSize: "14px", color: "#666"},
		".progress-data": {fontSize: "15px", marginTop: "10px"},
		".progress-nologin": {
			position: "absolute",
			left: "10px",
			width: "100%",
			borderRadius: "10px",
			padding: "30px 0",
			margin: "-50px 15px 0",
			backgroundColor: "rgba(255, 255, 255, 0.9)"
		},
		".progress-nologin_text": {textAlign: "center"},
		".progress-nologin_btn": {
			alignSelf: "center",
			width: "70px",
			borderRadius: "15px",
			backgroundColor: "#5538de",
			textAlign: "center",
			fontSize: "14px",
			color: "#fff",
			padding: "5px 10px",
			boxSizing: "border-box",
			marginTop: "10px"
		}
	};
	apivm.define("learn-progress", LearnProgress);

	var Course = /*@__PURE__*/ (function(Component) {
		function Course(props) {
			Component.call(this, props);
			this.data = {
				params: {},
				progressInfo: {},
				allLessonList: [],
				stageArray: [],
				lessonList: [],
				questionList: [],
				allHandoutList: [],
				handoutList: [],
				years: [],
				currentYear: null,
				activeTab: 1,
				isLogin: false,
				hasFile: false,
				dataFinish: false
			};
		}

		if (Component) Course.__proto__ = Component;
		Course.prototype = Object.create(Component && Component.prototype);
		Course.prototype.constructor = Course;
		Course.prototype.apiready = function() {
			this.data.params = api.pageParam;
			this.init();
			this.initEventListenter();
		};
		Course.prototype.init = function() {
			var ref = this.data.params;
			var yearQuestion = ref.yearQuestion;
			var courseType = ref.courseType;
			this.data.isLogin = getLoginStatus();
			this.getCourseProgress();

			if (this.data.isLogin) {
				if (yearQuestion) {
					this.getQuestionList();
				}

				if (courseType === 2) {
					this.getHandoutList(11);
				} else if (courseType === 3) {
					this.getHandoutList(6);
				} else {
					this.file();
				}
			} else {
				this.noLoginTip();
			}
		};
		Course.prototype.initEventListenter = function() {
			var this$1 = this;

			api.addEventListener(
				{
					name: "viewappear"
				},
				function() {
					this$1.getLessonList();
					api.setScreenOrientation({
						orientation: "portrait_up"
					});
				}
			);
		};
		Course.prototype.getCourseProgress = function() {
			var this$1 = this;

			var ref = this.data.params;
			var courseId = ref.courseId;
			var courseType = ref.courseType;
			getCourseProgress(courseId, courseType)
				.then(function(res) {
					this$1.data.progressInfo = res;
				})
				.catch(function(err) {
					this$1.data.progressInfo = {};
				});
		};
		Course.prototype.file = function() {
			var this$1 = this;

			isHasFile(this.data.params.courseId).then(function(res) {
				this$1.data.hasFile = res;
			});
		};
		Course.prototype.getLessonList = function() {
			var this$1 = this;

			if (this.data.lessonList.length > 0) {
				return;
			}
			var ref = this.data.params;
			var courseId = ref.courseId;
			var courseType = ref.courseType;
			getLessonList(courseId, courseType)
				.then(function(res) {
					var foldIndex = [];
					var years = [];
					this$1.data.allLessonList = res || [];
					if (res.length > 1) {
						res.map(function(lesson) {
							if (lesson.isDefault) {
								this$1.data.lessonList = lesson.courseStageInfoRes || [];
								this$1.data.currentYear = lesson.byYear;
							}
							years.push(lesson.byYear);
						});
						this$1.data.years = years;
						// 根据年份设置展示讲义数组

						this$1.handleHandoutList(this$1.data.currentYear);
					} else {
						this$1.data.lessonList = res[0].courseStageInfoRes || [];
					}

					if (this$1.data.stageArray.length == 0) {
						this$1.data.lessonList.map(function(item) {
							return foldIndex.push(0);
						});
						this$1.data.stageArray = foldIndex;
					}

					this$1.data.dataFinish = true;
				})
				.catch(function(err) {
					this$1.data.lessonList = [];
				});
		};
		Course.prototype.getQuestionList = function() {
			var this$1 = this;

			getQuestionList(this.data.params.courseId)
				.then(function(res) {
					this$1.data.questionList = res || [];
				})
				.catch(function(err) {
					this$1.data.questionList = [];
				});
		};
		Course.prototype.getHandoutList = function(type) {
			var this$1 = this;

			getHandoutList(this.data.params.courseId, type)
				.then(function(res) {
					// 存入全部讲义数组
					this$1.data.allHandoutList = res || [];
					this$1.data.handoutList = this$1.data.allHandoutList;
				})
				.catch(function(err) {
					this$1.data.handoutList = [];
				});
		};
		Course.prototype.openFileCollect = function() {
			api.openTabLayout({
				name: "file-collect",
				title: "资料汇总",
				url: "./file-collect.stml",
				navigationBar: {},
				pageParam: {
					courseId: this.data.params.courseId
				}
			});
		};
		Course.prototype.popYearList = function() {
			var this$1 = this;

			var years = this.data.years;
			if (!years.length) {
				return;
			}

			api.actionSheet(
				{
					title: "选择年份",
					buttons: years
				},
				function(ret, err) {
					var index = ret.buttonIndex - 1;
					if (index < years.length) {
						var foldIndex = [];
						this$1.data.currentYear = years[index];
						this$1.data.allLessonList.map(function(lesson) {
							if (lesson.byYear == years[index]) {
								this$1.data.lessonList = lesson.courseStageInfoRes || [];
							}
						});
						// 年份切换,讲义修改
						this$1.handleHandoutList(years[index]);

						this$1.data.lessonList.map(function(item) {
							return foldIndex.push(0);
						});
						this$1.data.stageArray = foldIndex;
						toast("当前是 " + this$1.data.currentYear + "年课程");
					}
				}
			);
		};
		Course.prototype.switchTab = function(index) {
			this.data.activeTab = index;
		};
		Course.prototype.back = function() {
			api.closeWin();
		};
		Course.prototype.noLoginTip = function() {
			api.alert({
				title: "欢迎进行课时学习",
				msg:
					"在未购买课程的情况下，你可以试听前两个课时（仅限观看视频以及下载讲义）。"
			});
		};
		Course.prototype.handleHandoutList = function(year) {
			console.log(year, "year");
			// 存储筛选的讲义
			var arr = [];
			// 置空展示讲义列表
			this.data.handoutList = [];
			// 循环数组取出符合条件的讲义
			this.data.allHandoutList.map(function(item) {
				if (item.byYear == year) {
					arr.push(item);
				}
			});
			// 如果当前年份列表为0,没有符合条件的讲义,将全部讲义放入展示列表
			this.data.handoutList = arr.length <= 0 ? this.data.allHandoutList : arr;
			if (arr.length <= 0) {
				toast("暂无 " + this.data.currentYear + "年讲义");
			}
		};
		Course.prototype.render = function() {
			var this$1 = this;
			return apivm.h(
				"view",
				{class: "course"},

				apivm.h(
					"view",
					{class: "title"},
					apivm.h(
						"view",
						{class: "back", onClick: this.back},
						apivm.h("image", {class: "back-icon", src: "../../image/icon/back.png"})
					),
					apivm.h("text", {class: "title_text"}, this.data.params.name)
				),

				apivm.h("learn-progress", {
					progress: this.data.progressInfo,
					isLogin: this.data.isLogin
				}),

				apivm.h(
					"view",
					{class: "mid-tabs"},

					apivm.h(
						"view",
						{
							class: "tabs-item",
							onClick: function() {
								return this$1.switchTab(1);
							}
						},
						apivm.h("image", {
							class: "tabs-icon",
							src:
								this.data.activeTab === 1
									? "../../image/icon/course-tabs-1.png"
									: "../../image/icon/course-tab-1.png"
						}),
						apivm.h(
							"text",
							{
								class: this.data.activeTab === 1 ? "tabs-text tabs-active" : "tabs-text"
							},
							this.data.params.courseType === 3 ? "精讲视频" : "课时学习"
						)
					),

					this.data.params.yearQuestion
						? apivm.h(
								"view",
								{
									class: "tabs-item tabs-items",
									onClick: function() {
										return this$1.switchTab(2);
									}
								},
								apivm.h("image", {
									class: "tabs-icon",
									src:
										this.data.activeTab === 2
											? "../../image/icon/course-tabs-2.png"
											: "../../image/icon/course-tab-2.png"
								}),
								apivm.h(
									"text",
									{
										class:
											this.data.activeTab === 2 ? "tabs-text tabs-active" : "tabs-text"
									},
									"真题演练"
								)
						  )
						: null,

					this.data.params.courseType === 3
						? apivm.h(
								"view",
								{
									class: "tabs-item tabs-items",
									onClick: function() {
										return this$1.switchTab(3);
									}
								},
								apivm.h("image", {
									class: "tabs-icon",
									src:
										this.data.activeTab === 3
											? "../../image/icon/course-tabs-2.png"
											: "../../image/icon/course-tab-2.png"
								}),
								apivm.h(
									"text",
									{
										class:
											this.data.activeTab === 3 ? "tabs-text tabs-active" : "tabs-text"
									},
									"讲义下载"
								)
						  )
						: null
				),

				this.data.allLessonList.length > 1
					? apivm.h(
							"view",
							{class: "years"},
							apivm.h("text", {class: "years-txt"}, "当前学习："),

							apivm.h(
								"view",
								{
									class: "years-btn",
									onClick: function() {
										return this$1.popYearList();
									}
								},
								apivm.h("text", {class: "years-txt"}, this.data.currentYear, "年"),
								apivm.h("image", {
									class: "years-img",
									src: "../../image/icon/years-switch.png"
								})
							)
					  )
					: null,

				apivm.h(
					"scroll-view",
					{class: "main"},
					this.data.activeTab === 1
						? apivm.h(
								"view",
								null,
								this.data.lessonList.length > 0
									? apivm.h("course-list", {
											list: this.data.lessonList,
											stageArray: this.data.stageArray,
											courseId: this.data.params.courseId,
											isLogin: this.data.isLogin
									  })
									: apivm.h("image", {class: "loading", src: "../../image/loading.gif"})
						  )
						: null,
					this.data.activeTab === 2
						? apivm.h(
								"view",
								null,
								this.data.questionList.length > 0
									? apivm.h("question-list", {list: this.data.questionList})
									: apivm.h("image", {class: "loading", src: "../../image/loading.gif"})
						  )
						: null,
					this.data.activeTab === 3
						? apivm.h(
								"view",
								null,
								this.data.handoutList.length > 0
									? apivm.h("handout-list", {
											list: this.data.handoutList,
											courseId: this.data.params.courseId
									  })
									: apivm.h("image", {class: "loading", src: "../../image/loading.gif"})
						  )
						: null
				),

				this.data.hasFile
					? apivm.h("image", {
							class: "file-collect",
							src: "http://resource.zhuokao360.com/app/btzx/image/data-download.png",
							onClick: this.openFileCollect
					  })
					: null
			);
		};

		return Course;
	})(Component);
	Course.css = {
		".course": {height: "100%", backgroundColor: "#f5f5f5"},
		".title": {height: "24%", backgroundColor: "#5538de", paddingTop: "20px"},
		".back": {height: "32px", padding: "8px 0 5px"},
		".back-icon": {width: "28px", height: "28px"},
		".title_text": {
			fontSize: "20px",
			fontWeight: "bold",
			color: "#fff",
			margin: "5px auto 0"
		},
		".mid-tabs": {
			flexDirection: "row",
			backgroundColor: "#fff",
			margin: "20px 15px"
		},
		".tabs-item": {
			flex: "1",
			flexDirection: "row",
			justifyContent: "center",
			alignItems: "center",
			padding: "12px 0",
			boxSizing: "border-box"
		},
		".tabs-items": {borderLeft: "1px solid rgba(153, 153, 153, 0.2)"},
		".tabs-icon": {width: "15px", height: "15px", marginRight: "5px"},
		".tabs-text": {fontSize: "15px", color: "#666"},
		".tabs-active": {fontSize: "15px", fontWeight: "bold", color: "#5538de"},
		".main": {flex: "1"},
		".file-collect": {
			position: "absolute",
			right: "0",
			bottom: "250px",
			width: "40px",
			height: "92px"
		},
		".loading": {width: "65px", height: "65px", margin: "20px auto"},
		".years": {
			alignSelf: "flex-end",
			flexDirection: "row",
			alignItems: "center",
			margin: "0px 15px 20px"
		},
		".years-btn": {
			flexDirection: "row",
			alignItems: "center",
			borderRadius: "12px",
			border: "1px solid #333333",
			padding: "3px 10px"
		},
		".years-txt": {fontSize: "12px", color: "#333333"},
		".years-img": {width: "12px", height: "12px", marginLeft: "10px"}
	};
	apivm.define("course", Course);
	apivm.render(apivm.h("course", null), "body");
})();
