(function() {
	var Loading = /*@__PURE__*/ (function(Component) {
		function Loading(props) {
			Component.call(this, props);
			this.data = {};
		}

		if (Component) Loading.__proto__ = Component;
		Loading.prototype = Object.create(Component && Component.prototype);
		Loading.prototype.constructor = Loading;
		Loading.prototype.apiready = function() {};
		Loading.prototype.render = function() {
			return apivm.h("image", {
				class: "" + (this.props.type ? "loading_" + this.props.type : "loading_"),
				src: "../../image/loading.gif"
			});
		};

		return Loading;
	})(Component);
	Loading.css = {
		".loading_": {
			width: "65px",
			height: "65px",
			position: "absolute",
			top: "43%",
			left: "50%",
			transform: "translateX(-25px)",
			zIndex: "99"
		},
		".loading_login": {
			width: "65px",
			height: "65px",
			position: "absolute",
			top: "17%",
			left: "50%",
			transform: "translateX(-25px)",
			zIndex: "99"
		}
	};
	apivm.define("loading", Loading);

	// 本地存储
	var storage = {
		set: function set(key, value) {
			api.setPrefs({
				key: key,
				value: typeof value === "string" ? value : JSON.stringify(value)
			});
		},

		get: function get(key) {
			var value = api.getPrefs({sync: true, key: key}) || "";

			// 如果JSON字符串无法解析，直接返回
			try {
				return JSON.parse(value);
			} catch (e) {
				return value;
			}
		},

		del: function del(key) {
			api.removePrefs({key: key});
		}
	};

	/**
	 * 格式化文件大小, 输出成带单位的字符串
	 * @param {Number} size 文件大小
	 */
	function formatFileSize(size) {
		var units = ["B", "K", "M", "G", "TB"];
		var fileSize = parseInt(size);
		for (var i = 0; fileSize >= 1024; i += 1) {
			fileSize /= 1024;
			units.shift();
		}
		return fileSize.toFixed(1) + units[0];
	}

	// 获取当前网络状态
	function getNetworkStatus() {
		return api.connectionType !== "none";
	}

	var downloadManager = api.require("downloadManager");

	// 查询下载状态，当查询条件均为空时，返回所有下载记录信息
	function query(id) {
		return new Promise(function(resolve, reject) {
			downloadManager.query(
				{
					ids: id instanceof Array ? id : [id]
				},
				function(ret, err) {
					if (ret) {
						ret.data && ret.data.length > 0 && resolve(ret.data);
					} else {
						console.log(JSON.stringify(err));
					}
				}
			);
		});
	}
	// 暂停下载
	function pause(id) {
		if (!id) {
			return;
		}

		return new Promise(function(resolve, reject) {
			downloadManager.pause(
				{
					id: id
				},
				function(ret, err) {
					if (ret.status) {
						resolve(ret);
					} else {
						console.log(JSON.stringify(err));
					}
				}
			);
		});
	}
	// 继续下载
	function resume(id) {
		if (!id) {
			return;
		}

		return new Promise(function(resolve, reject) {
			downloadManager.resume(
				{
					id: id
				},
				function(ret, err) {
					if (ret.status) {
						resolve(ret);
					} else {
						console.log(JSON.stringify(err));
					}
				}
			);
		});
	}
	// 删除下载
	function remove(id) {
		if (!id) {
			return;
		}

		return new Promise(function(resolve, reject) {
			downloadManager.remove(
				{
					ids: [id],
					deleteFiles: true
				},
				function(ret, err) {
					if (ret) {
						resolve(ret);
					} else {
						resolve(err);
					}
				}
			);
		});
	}

	var Download = /*@__PURE__*/ (function(Component) {
		function Download(props) {
			Component.call(this, props);
			this.data = {
				network: true,
				hasVideo: false,
				intervId: null, // 轮询计时器
				delay: 1000, // 计时秒
				editDelete: false, // 编辑删除
				loadingId: [], // 下载中的视频编号
				finish: [], // 已完成
				downloading: [], // 下载中
				error: [] // 下载失败
			};
		}

		if (Component) Download.__proto__ = Component;
		Download.prototype = Object.create(Component && Component.prototype);
		Download.prototype.constructor = Download;
		Download.prototype.apiready = function() {
			//like created
			this.editDel();
			this.getDownLoad();
			this.data.network = getNetworkStatus();
		};
		Download.prototype.getDownLoad = function() {
			var this$1 = this;

			var ids = [];
			var finishVideo = [];
			var errorVideo = [];
			var downloadingVideo = [];
			var localVideosList = storage.get("localVideos");
			this.data.downloading = [];
			this.data.loadingId = [];
			if (localVideosList.length > 0) {
				this.data.hasVideo = true;
			}
			if (localVideosList.length === 0) {
				this.data.finish = [];
				this.data.error = [];
				this.data.downloading = [];
				this.data.loadingId = [];
				this.data.hasVideo = false;
				return;
			}
			if (this.data.finish.length === 0) {
				this.data.finish = [];
			}
			// 查询所有下载
			query(ids)
				.then(function(res) {
					// 1:下载中  2:暂停  3:下载成功  4:下载失败
					for (var i = 0; i < res.length; i++) {
						if (res[i].status == 3) {
							finishVideo.push(res[i]);
							this$1.data.finish = [];
							this$1.data.finish = finishVideo;
						} else if (res[i].status == 4) {
							errorVideo.push(res[i]);
							this$1.data.error = [];
							this$1.data.error = errorVideo;
						} else if (
							res[i].status == 0 ||
							res[i].status == 1 ||
							res[i].status == 2
						) {
							downloadingVideo.push(res[i]);
							ids.push(res[i].id);
							this$1.data.downloading = downloadingVideo;
							this$1.data.loadingId = ids;
							// download.resume(res[i].id); // 恢复下载状态
						}
					}
				})
				.then(function() {
					if (ids.length > 0) {
						this$1.setListenDownloading();
					}
				});
		};
		Download.prototype.setListenDownloading = function() {
			var this$1 = this;

			var ref = this.data;
			var delay = ref.delay;
			this.data.intervId = setInterval(function() {
				this$1.queryDownloading();
			}, delay);
		};
		Download.prototype.clearListenDownloading = function() {
			clearInterval(this.data.intervId);
			this.data.intervId = null;
		};
		Download.prototype.queryDownloading = function() {
			var this$1 = this;

			var ids = this.data.loadingId;
			if (ids.length == 0) {
				this.clearListenDownloading();
				return;
			}
			query(ids).then(function(res) {
				var downloadList = [];
				for (var i = 0; i < res.length; i++) {
					// 记录
					if (res[i].status == 1) {
						downloadList.push(res[i]);
						this$1.data.downloading = downloadList;
					}
					// 更新
					if (res[i].status == 3) {
						this$1.getDownLoad();
					}
				}
			});
		};
		Download.prototype.onPause = function(id) {
			var this$1 = this;

			pause(id).then(function() {
				this$1.getDownLoad();
			});
		};
		Download.prototype.onStart = function(id) {
			var this$1 = this;

			resume(id).then(function() {
				this$1.getDownLoad();
				!intervId && this$1.setListenDownloading();
			});
		};
		Download.prototype.onDelete = function(id) {
			var this$1 = this;

			api.confirm(
				{
					msg: "是否确认删除该视频",
					buttons: ["确定", "取消"]
				},
				function(ret, err) {
					if (ret.buttonIndex == 1) {
						remove(id).then(function() {
							this$1.removeLocalVideo(id);
						});
					}
				}
			);
		};
		Download.prototype.removeLocalVideo = function(id) {
			var this$1 = this;

			var localVideo = storage.get("localVideos") || [];
			for (var i = 0; i < localVideo.length; i++) {
				if (localVideo[i].id == id) {
					localVideo.splice(i, 1);
					break;
				}
			}
			storage.set("localVideos", localVideo);
			api.getPrefs(
				{
					key: "localVideos"
				},
				function() {
					this$1.getDownLoad();
				}
			);
		};
		Download.prototype.openVideo = function(savePath) {
			var pattern = /\d{0,}.mp4$/;
			var id = pattern.exec(savePath)[0];
			var videoId = parseInt(id);
			api.openWin({
				name: "video",
				url: "../video/video.stml",
				pageParam: {
					videoId: videoId
				}
			});
		};
		Download.prototype.editDel = function() {
			var this$1 = this;

			api.addEventListener(
				{
					name: "navitembtn"
				},
				function() {
					if (this$1.data.editDelete) {
						this$1.data.editDelete = !this$1.data.editDelete;
						api.setNavBarAttr({
							rightButtons: [
								{
									text: "编辑  "
								}
							]
						});
					} else {
						this$1.data.editDelete = !this$1.data.editDelete;
						api.setNavBarAttr({
							rightButtons: [
								{
									text: "完成  "
								}
							]
						});
					}
				}
			);
		};
		Download.prototype.render = function() {
			var this$1 = this;
			return apivm.h(
				"view",
				{class: "page"},

				apivm.h("text", {class: "title"}, "离线中心"),

				!this.data.hasVideo
					? apivm.h(
							"view",
							{class: "nodata"},
							apivm.h(
								"view",
								{class: "list-nodata"},
								apivm.h("image", {
									class: "list-nodata_img",
									src: "../../image/default-display-nopower.png"
								}),
								apivm.h("text", {class: "list-nodata_text"}, "暂无内容")
							)
					  )
					: apivm.h(
							"scroll-view",
							{class: "list", "show-scrollbar": "false"},

							this.data.finish.map(function(item, index) {
								return apivm.h(
									"view",
									{
										class: "list-item " + (index == 0 ? "" : "list-item_s"),
										onClick: function() {
											return this$1.openVideo(item.savePath);
										}
									},
									apivm.h(
										"view",
										{class: "list-item-course"},
										apivm.h(
											"view",
											{class: "item-course-content"},
											apivm.h("text", {class: "item-course-title"}, item.title),
											apivm.h(
												"text",
												{class: "item-course-des"},
												formatFileSize(item.finishSize),
												" | 已缓存"
											)
										),
										!this$1.data.editDelete
											? apivm.h(
													"view",
													{class: "item-course-icon"},
													apivm.h("image", {
														class: "item-course-icon_img",
														src: "../../image/default-icon-more.png"
													})
											  )
											: null,
										this$1.data.editDelete
											? apivm.h(
													"text",
													{
														class: "item-course-btn fail",
														onClick: function() {
															return this$1.onDelete(item.id);
														}
													},
													"删除"
											  )
											: null
									)
								);
							}),

							this.data.downloading.map(function(item, index) {
								return apivm.h(
									"view",
									{
										class:
											"list-item " +
											(index == 0 && this$1.data.finish.length == 0 ? "" : "list-item_s")
									},
									apivm.h(
										"view",
										{class: "list-item-course"},
										apivm.h(
											"view",
											{class: "item-course-content"},
											apivm.h("text", {class: "item-course-title"}, item.title),
											apivm.h(
												"view",
												{class: "item-course-des pause"},
												item.status == 2
													? apivm.h("text", {class: "des-data"}, "暂停中")
													: null,
												apivm.h(
													"text",
													{class: "des-data"},
													formatFileSize(item.finishSize),
													"/",
													formatFileSize(item.totalSize)
												),
												apivm.h(
													"text",
													{class: "des-pro"},
													parseInt((item.finishSize / item.totalSize) * 100),
													"%"
												)
											),
											apivm.h("progress", {
												class: "item-course-progress",
												value: parseInt((item.finishSize / item.totalSize) * 100),
												activeColor: "#17B47B",
												backgroundColor: "#E5E5E5"
											})
										),
										apivm.h(
											"text",
											{
												class: "item-course-btn",
												onClick:
													item.status == 2
														? "onStart(" + item.id + ")"
														: "onPause(" + item.id + ")",
												style: {display: !this$1.data.editDelete ? "flex" : "none"}
											},
											item.status == 2 ? "继续" : "暂停"
										),
										apivm.h(
											"text",
											{
												class: "item-course-btn fail",
												onClick: function() {
													return this$1.onDelete(item.id);
												},
												style: {display: this$1.data.editDelete ? "flex" : "none"}
											},
											"删除"
										)
									)
								);
							}),

							this.data.error.map(function(item, index) {
								return apivm.h(
									"view",
									{
										class:
											"list-item " +
											(index == 0 &&
											this$1.data.finish.length == 0 &&
											this$1.data.downloading.length == 0
												? ""
												: "list-item_s")
									},
									apivm.h(
										"view",
										{class: "list-item-course"},
										apivm.h(
											"view",
											{class: "item-course-content"},
											apivm.h("text", {class: "item-course-title"}, item.title),
											apivm.h(
												"view",
												{class: "item-course-des pause"},
												apivm.h(
													"text",
													{class: "des-data"},
													item.reason == "1004" ? "存储已满" : "下载失败/网络异常"
												),
												apivm.h(
													"text",
													{class: "des-pro"},
													parseInt((item.finishSize / item.totalSize) * 100),
													"%"
												)
											),
											apivm.h("progress", {
												class: "item-course-progress",
												value: parseInt((item.finishSize / item.totalSize) * 100),
												activeColor: "#FF3B30",
												backgroundColor: "#E5E5E5"
											})
										),
										apivm.h(
											"text",
											{
												class: "item-course-btn fail",
												onClick: function() {
													return this$1.onDelete(item.id);
												}
											},
											"删除"
										)
									)
								);
							})
					  )
			);
		};

		return Download;
	})(Component);
	Download.css = {
		".page": {
			display: "flex",
			flexDirection: "column",
			height: "100%",
			padding: "0 20px 40px 20px",
			boxSizing: "border-box"
		},
		".title": {
			lineHeight: "44px",
			fontSize: "23px",
			fontWeight: "bold",
			color: "#333",
			marginTop: "10px"
		},
		".nodata": {marginTop: "25px"},
		".list-nodata": {padding: "40px 55px 66.5px", boxSizing: "border-box"},
		".list-nodata_img": {width: "225px", height: "175px", margin: "0 auto"},
		".list-nodata_text": {textAlign: "center", fontSize: "12px", color: "#999"},
		".list": {flex: "1", marginTop: "32.5px"},
		".list-item": {flexDirection: "row"},
		".list-item_s": {marginTop: "45px"},
		".list-item-course": {
			width: "100%",
			flexDirection: "row",
			justifyContent: "space-between"
		},
		".item-course-content": {display: "flex", flexDirection: "column"},
		".item-course-title": {
			width: "225px",
			maxHeight: "42px",
			fontSize: "15px",
			fontWeight: "bold",
			overflow: "hidden",
			textOverflow: "ellipsis",
			color: "#333"
		},
		".item-course-des": {
			width: "220px",
			fontSize: "12px",
			color: "#999",
			marginTop: "10px"
		},
		".item-course-icon": {marginTop: "15.5px"},
		".item-course-icon_img": {width: "7px", height: "13px"},
		".item-course-btn": {
			alignSelf: "flex-end",
			width: "59px",
			height: "30px",
			lineHeight: "30px",
			textAlign: "center",
			borderRadius: "3px",
			border: "1px solid #17b47b",
			fontSize: "12px",
			color: "#17b47b"
		},
		".item-course-progress": {width: "220px", height: "4px", marginTop: "5px"},
		".des-data": {fontSize: "12px", color: "#999"},
		".des-pro": {fontSize: "12px", color: "#999"},
		".pause": {
			height: "16.5px",
			flexDirection: "row",
			justifyContent: "space-between",
			display: "flex"
		},
		".progress_fail": {backgroundColor: "#ff3b30"},
		".fail": {border: "1px solid #ff3b30", color: "#ff3b30"}
	};
	apivm.define("download", Download);
	apivm.render(apivm.h("download", null), "body");
})();
