(function() {
	// api接口请求地址
	var BASEURL = "https://cbt.tibaitong.com/";

	// 文件类型图标
	var FILETYPE = {
		default: "https://files.zhuokao360.com/images/fileType/unknown.png",
		txt: "https://files.zhuokao360.com/images/fileType/txt.png",
		pdf: "https://files.zhuokao360.com/images/fileType/pdf.png",
		doc: "https://files.zhuokao360.com/images/fileType/word.png",
		docx: "https://files.zhuokao360.com/images/fileType/word.png",
		ppt: "https://files.zhuokao360.com/images/fileType/ppt.png",
		pptx: "https://files.zhuokao360.com/images/fileType/ppt.png",
		rar: "https://files.zhuokao360.com/images/fileType/rar.png",
		zip: "https://files.zhuokao360.com/images/fileType/rar.png",
		jpg: "https://files.zhuokao360.com/images/fileType/image.png",
		png: "https://files.zhuokao360.com/images/fileType/image.png",
		mp4: "https://files.zhuokao360.com/images/fileType/video.png"
	};

	/********************************************
	 *             系统和业务                   *
	 ******************************************/

	// 本地存储
	var storage = {
		set: function set(key, value) {
			api.setPrefs({
				key: key,
				value: typeof value === "string" ? value : JSON.stringify(value)
			});
		},

		get: function get(key) {
			var value = api.getPrefs({sync: true, key: key}) || "";

			try {
				return JSON.parse(value);
			} catch (e) {
				return value;
			}
		},

		del: function del(key) {
			api.removePrefs({key: key});
		}
	};

	// 请求
	function ajax(_ref) {
		var url = _ref.url,
			_ref$method = _ref.method,
			method = _ref$method === void 0 ? "get" : _ref$method,
			_ref$data = _ref.data,
			data = _ref$data === void 0 ? {} : _ref$data;
		return new Promise(function(resolve, reject) {
			api.ajax(
				{
					url: url.indexOf("http") === 0 ? url : BASEURL + url,
					method: method,
					headers: {
						"Content-Type": "application/json;charset=utf-8",
						"ZK-TOKEN": storage.get("token"),
						"APP-TYPE": 2
					},

					timeout: 60,
					data: {
						body: data
					}
				},

				function(ret, err) {
					if (ret) {
						if (ret.code === 200) {
							resolve(ret.data);
						} else if (ret.code === 600) {
							api.sendEvent({
								name: "loginExpired"
							});
						} else {
							api.toast({
								msg: ret.msg
							});
						}

						reject(ret);
					} else {
						api.toast({
							msg: "网络不畅,请检查网络"
						});

						reject(err);
					}
				}
			);
		});
	}

	/**
	 * 格式化文件大小, 输出成带单位的字符串
	 * @param {Number} size 文件大小
	 */
	function formatFileSize(size) {
		var units = ["B", "K", "M", "G", "TB"];
		var fileSize = parseInt(size);
		for (var i = 0; fileSize >= 1024; i += 1) {
			fileSize /= 1024;
			units.shift();
		}
		return fileSize.toFixed(1) + units[0];
	}

	/**
	 * 浏览器打开
	 * @param {String} url 需要打开的地址
	 */
	function openBrowser(url) {
		// api.openApp({
		//   androidPkg: 'android.intent.action.VIEW',
		//   uri: url,
		//   iosUrl: url,
		// });
		// ios
		if (api.systemType == "ios") {
			api.openApp({
				iosUrl: url
			});
		} else {
			// 安卓

			var jumpbrowser = api.require("jumpbrowser");
			var param = {Url: url};
			jumpbrowser.jumpBrowser(param, function(ret, err) {
				if (err) {
					api.alert({
						title: "提示",
						msg: "出错了,请稍后再试"
					});
				}
			});
		}
	}

	/**
	 * 获取资料列表，读取讲义表
	 * @param {Number} courseId 课程id
	 */
	function getHandoutList(courseId, type) {
		return ajax({
			url: "videoHandout/findVideoHandout",
			data: {
				courseId: courseId,
				type: type
			}
		});
	}

	/**
	 * 记录用户讲义下载记录
	 * @param {Number} courseId 课程id
	 * @param {Number} handoutId 讲义id
	 */
	function saveUserHandout(handoutId, courseId) {
		return ajax({
			url: "/videoHandout/saveUserHandout",
			method: "post",
			data: {
				handoutId: handoutId,
				courseId: courseId
			}
		});
	}

	var FileCollect = /*@__PURE__*/ (function(Component) {
		function FileCollect(props) {
			Component.call(this, props);
			this.data = {
				fileList: []
			};
		}

		if (Component) FileCollect.__proto__ = Component;
		FileCollect.prototype = Object.create(Component && Component.prototype);
		FileCollect.prototype.constructor = FileCollect;
		FileCollect.prototype.apiready = function() {
			var this$1 = this;
			getHandoutList(api.pageParam.courseId, 12)
				.then(function(res) {
					this$1.data.fileList = res || [];
				})
				.catch(function(err) {
					this$1.data.fileList = [];
				});
		};
		FileCollect.prototype.downloadHandout = function(handout) {
			// 更新下载记录
			saveUserHandout(handout.videoHandoutId, api.pageParam.courseId)
				.then(function(res) {
					// 下载讲义
					openBrowser(handout.downloadUrl);
				})
				.catch(function(err) {
					console.log(err, "err");
				});
		};
		FileCollect.prototype.file = function(type) {
			return FILETYPE[type] || FILETYPE.default;
		};
		FileCollect.prototype.render = function() {
			var this$1 = this;
			return apivm.h(
				"scroll-view",
				{class: "file-collect"},
				(Array.isArray(this.data.fileList)
					? this.data.fileList
					: Object.values(this.data.fileList)
				).map(function(file) {
					return apivm.h(
						"view",
						{
							class: "file-item",
							onClick: function() {
								return this$1.downloadHandout(file);
							}
						},
						apivm.h("image", {class: "file-type", src: this$1.file(file.fileType)}),
						apivm.h(
							"view",
							{class: "file-info"},
							apivm.h("text", {class: "file-title"}, file.title),
							apivm.h("text", {class: "file-size"}, formatFileSize(file.size))
						),
						apivm.h("image", {
							class: "file-icon",
							src: "../image/default-icon-setting.png"
						})
					);
				})
			);
		};

		return FileCollect;
	})(Component);
	FileCollect.css = {
		".file-collect": {backgroundColor: "#fff", margin: "0 15px 20px"},
		".file-item": {flexDirection: "row", alignItems: "center", margin: "15px"},
		".file-type": {width: "30px", height: "30px", marginRight: "10px"},
		".file-info": {flex: "1"},
		".file-title": {fontSize: "14px", fontWeight: "bold", color: "#333"},
		".file-size": {fontSize: "12px", color: "#666", marginTop: "10px"},
		".file-icon": {width: "15px", height: "15px"}
	};
	apivm.define("file-collect", FileCollect);
	apivm.render(apivm.h("file-collect", null), "body");
})();
