(function() {
	// 本地存储
	var storage = {
		set: function set(key, value) {
			api.setPrefs({
				key: key,
				value: typeof value === "string" ? value : JSON.stringify(value)
			});
		},

		get: function get(key) {
			var value = api.getPrefs({sync: true, key: key}) || "";

			// 如果JSON字符串无法解析，直接返回
			try {
				return JSON.parse(value);
			} catch (e) {
				return value;
			}
		},

		del: function del(key) {
			api.removePrefs({key: key});
		}
	};

	/**
	 * 格式化文件大小, 输出成带单位的字符串
	 * @param {Number} size 文件大小
	 */
	function formatFileSize(size) {
		var units = ["B", "K", "M", "G", "TB"];
		var fileSize = parseInt(size);
		for (var i = 0; fileSize >= 1024; i += 1) {
			fileSize /= 1024;
			units.shift();
		}
		return fileSize.toFixed(1) + units[0];
	}

	var downloadManager = api.require("downloadManager");

	// 查询下载状态，当查询条件均为空时，返回所有下载记录信息
	function query(id) {
		return new Promise(function(resolve, reject) {
			downloadManager.query(
				{
					ids: id instanceof Array ? id : [id]
				},
				function(ret, err) {
					if (ret) {
						ret.data && ret.data.length > 0 && resolve(ret.data);
					} else {
						console.log(JSON.stringify(err));
					}
				}
			);
		});
	}
	// 暂停下载
	function pause(id) {
		if (!id) {
			return;
		}

		return new Promise(function(resolve, reject) {
			downloadManager.pause(
				{
					id: id
				},
				function(ret, err) {
					if (ret.status) {
						resolve(ret);
					} else {
						console.log(JSON.stringify(err));
					}
				}
			);
		});
	}
	// 继续下载
	function resume(id) {
		if (!id) {
			return;
		}

		return new Promise(function(resolve, reject) {
			downloadManager.resume(
				{
					id: id
				},
				function(ret, err) {
					if (ret.status) {
						resolve(ret);
					} else {
						console.log(JSON.stringify(err));
					}
				}
			);
		});
	}
	// 删除下载
	function remove(id) {
		if (!id) {
			return;
		}

		return new Promise(function(resolve, reject) {
			downloadManager.remove(
				{
					ids: [id],
					deleteFiles: true
				},
				function(ret, err) {
					if (ret) {
						resolve(ret);
					} else {
						resolve(err);
					}
				}
			);
		});
	}

	var NoEncryptDownload = /*@__PURE__*/ (function(Component) {
		function NoEncryptDownload(props) {
			Component.call(this, props);
			this.data = {
				intervId: null, // 轮询计时器
				loadingId: [], // 下载中的视频编号
				// finish: [{ "id": 2, "status": 3, "title": " 专题一 总论", "totalSize": 124399919, "finishSize": 124399919, "mimeType": "video/mp4", "reason": 1000, "savePath": "file:///storage/emulated/0/UZMap/A6177214431485/video/9417.mp4", "iconPath": "2", "url": "https://video.tibaitong.com/ccd55f6273fa4bd7a6b09f4fffebf4a0/f1e10f090cb24466947bd9f2d49882b0-f363b8fa470471978e3a5d586b255753-sd-nbv1.mp4" }], // 已完成的视频信息
				finish: [], // 已完成的视频信息
				downloading: [], // 下载中的视频信息
				error: [] // 下载失败的视频信息
			};
		}

		if (Component) NoEncryptDownload.__proto__ = Component;
		NoEncryptDownload.prototype = Object.create(Component && Component.prototype);
		NoEncryptDownload.prototype.constructor = NoEncryptDownload;
		NoEncryptDownload.prototype.installed = function() {
			this.getDownLoad();
		};
		NoEncryptDownload.prototype.getDownLoad = function() {
			var this$1 = this;

			var ids = [];
			var finishVideo = [];
			var errorVideo = [];
			var downloadingVideo = [];
			var localVideosList = storage.get("localVideos");

			this.data.downloading = [];
			this.data.loadingId = [];
			if (localVideosList.length > 0) {
				this.fire("hasDown", true);
			}
			if (localVideosList.length === 0) {
				this.data.finish = [];
				this.data.error = [];
				this.data.downloading = [];
				this.data.loadingId = [];
				this.fire("hasDown", false);
				return;
			}
			if (this.data.finish.length === 0) {
				this.data.finish = [];
			}
			// 查询所有下载
			query(ids)
				.then(function(res) {
					// 1:下载中  2:暂停  3:下载成功  4:下载失败
					for (var i = 0; i < res.length; i++) {
						if (res[i].status == 3) {
							finishVideo.push(res[i]);
							this$1.data.finish = [];
							this$1.data.finish = finishVideo;
						} else if (res[i].status == 4) {
							errorVideo.push(res[i]);
							this$1.data.error = [];
							this$1.data.error = errorVideo;
						} else if (
							res[i].status == 0 ||
							res[i].status == 1 ||
							res[i].status == 2
						) {
							downloadingVideo.push(res[i]);
							ids.push(res[i].id);
							this$1.data.downloading = downloadingVideo;
							this$1.data.loadingId = ids;
						}
					}
				})
				.then(function() {
					if (ids.length > 0) {
						this$1.setListenDownloading();
					}
				});
		};
		NoEncryptDownload.prototype.setListenDownloading = function() {
			var this$1 = this;

			this.data.intervId = setInterval(function() {
				this$1.queryDownloading();
			}, 1000);
		};
		NoEncryptDownload.prototype.clearListenDownloading = function() {
			clearInterval(this.data.intervId);
			this.data.intervId = null;
		};
		NoEncryptDownload.prototype.queryDownloading = function() {
			var this$1 = this;

			var ids = this.data.loadingId;
			if (ids.length == 0) {
				this.clearListenDownloading();
				return;
			}
			query(ids).then(function(res) {
				var downloadList = [];
				for (var i = 0; i < res.length; i++) {
					// 记录
					if (res[i].status == 1) {
						downloadList.push(res[i]);
						this$1.data.downloading = downloadList;
					}
					// 更新
					if (res[i].status == 3) {
						this$1.getDownLoad();
					}
				}
			});
		};
		NoEncryptDownload.prototype.onPause = function(id) {
			var this$1 = this;

			console.log(id);
			pause(id).then(function() {
				this$1.getDownLoad();
			});
		};
		NoEncryptDownload.prototype.onStart = function(id) {
			var this$1 = this;

			resume(id).then(function() {
				this$1.getDownLoad();
				!intervId && this$1.setListenDownloading();
			});
		};
		NoEncryptDownload.prototype.onDelete = function(id) {
			var this$1 = this;

			api.confirm(
				{
					msg: "是否确认删除该视频",
					buttons: ["确定", "取消"]
				},
				function(ret, err) {
					if (ret.buttonIndex == 1) {
						remove(id).then(function() {
							this$1.removeLocalVideo(id);
						});
					}
				}
			);
		};
		NoEncryptDownload.prototype.removeLocalVideo = function(id) {
			var this$1 = this;

			var localVideo = storage.get("localVideos") || [];
			for (var i = 0; i < localVideo.length; i++) {
				if (localVideo[i].id == id) {
					localVideo.splice(i, 1);
					break;
				}
			}
			storage.set("localVideos", localVideo);
			api.getPrefs(
				{
					key: "localVideos"
				},
				function() {
					this$1.getDownLoad();
				}
			);
		};
		NoEncryptDownload.prototype.openVideo = function(savePath) {
			var pattern = /\d{0,}.mp4$/;
			var id = pattern.exec(savePath)[0];
			var videoId = parseInt(id);
			api.openWin({
				name: "video",
				url: "../video/testali.stml",
				pageParam: {
					videoId: videoId
				}
			});
		};
		NoEncryptDownload.prototype.render = function() {
			var this$1 = this;
			return apivm.h(
				"view",
				{class: "no-encrypt-download"},

				this.data.finish.map(function(item, index) {
					return apivm.h(
						"view",
						{
							class: "list-item " + (index == 0 ? "" : "list-item_s"),
							onClick: function() {
								return this$1.openVideo(item.savePath);
							}
						},
						apivm.h(
							"view",
							{class: "list-item-course"},
							apivm.h(
								"view",
								{class: "item-course-content"},
								apivm.h("text", {class: "item-course-title"}, item.title),
								apivm.h(
									"text",
									{class: "item-course-des"},
									formatFileSize(item.finishSize),
									" | 已缓存"
								)
							),
							!this$1.props.handleVideoBtn
								? apivm.h(
										"view",
										{class: "item-course-icon"},
										apivm.h("image", {
											class: "item-course-icon_img",
											src: "../../image/default-icon-more.png"
										})
								  )
								: null,
							this$1.props.handleVideoBtn
								? apivm.h(
										"text",
										{
											class: "item-course-btn fail",
											onClick: function() {
												return this$1.onDelete(item.id);
											}
										},
										"删除"
								  )
								: null
						)
					);
				}),

				this.data.downloading.map(function(item, index) {
					return apivm.h(
						"view",
						{
							class:
								"list-item " +
								(index == 0 && this$1.data.finish.length == 0 ? "" : "list-item_s")
						},
						apivm.h(
							"view",
							{class: "list-item-course"},
							apivm.h(
								"view",
								{class: "item-course-content"},
								apivm.h("text", {class: "item-course-title"}, item.title),
								apivm.h(
									"view",
									{class: "item-course-des pause"},
									item.status == 2
										? apivm.h("text", {class: "des-data"}, "暂停中")
										: apivm.h(
												"text",
												{class: "des-data"},
												formatFileSize(item.finishSize),
												"/",
												formatFileSize(item.totalSize)
										  ),

									apivm.h(
										"text",
										{class: "des-pro"},
										parseInt((item.finishSize / item.totalSize) * 100),
										"%"
									)
								),
								apivm.h("progress", {
									class: "item-course-progress",
									value: parseInt((item.finishSize / item.totalSize) * 100),
									activeColor: "#17B47B",
									backgroundColor: "#E5E5E5"
								})
							),

							apivm.h(
								"text",
								{
									class: "item-course-btn",
									onClick: function() {
										return this$1.onStart(item.id);
									},
									style: {
										display:
											!this$1.props.handleVideoBtn && item.status == 2 ? "flex" : "none"
									}
								},
								"继续"
							),
							apivm.h(
								"text",
								{
									class: "item-course-btn",
									onClick: function() {
										return this$1.onPause(item.id);
									},
									style: {
										display:
											!this$1.props.handleVideoBtn && item.status != 2 ? "flex" : "none"
									}
								},
								"暂停"
							),
							apivm.h(
								"text",
								{
									class: "item-course-btn fail",
									onClick: function() {
										return this$1.onDelete(item.id);
									},
									style: {display: this$1.props.handleVideoBtn ? "flex" : "none"}
								},
								"删除"
							)
						)
					);
				}),

				this.data.error.map(function(item, index) {
					return apivm.h(
						"view",
						{
							class:
								"list-item " +
								(index == 0 &&
								this$1.data.finish.length == 0 &&
								this$1.data.downloading.length == 0
									? ""
									: "list-item_s")
						},
						apivm.h(
							"view",
							{class: "list-item-course"},
							apivm.h(
								"view",
								{class: "item-course-content"},
								apivm.h("text", {class: "item-course-title"}, item.title),
								apivm.h(
									"view",
									{class: "item-course-des pause"},
									apivm.h(
										"text",
										{class: "des-data"},
										item.reason == "1004" ? "存储已满" : "下载失败/网络异常"
									),
									apivm.h(
										"text",
										{class: "des-pro"},
										parseInt((item.finishSize / item.totalSize) * 100),
										"%"
									)
								),
								apivm.h("progress", {
									class: "item-course-progress",
									value: parseInt((item.finishSize / item.totalSize) * 100),
									activeColor: "#FF3B30",
									backgroundColor: "#E5E5E5"
								})
							),
							apivm.h(
								"text",
								{
									class: "item-course-btn fail",
									onClick: function() {
										return this$1.onDelete(item.id);
									}
								},
								"删除"
							)
						)
					);
				})
			);
		};

		return NoEncryptDownload;
	})(Component);
	NoEncryptDownload.css = {
		".no-encrypt-download": {
			display: "flex",
			flexDirection: "column",
			width: "100%",
			height: "100%"
		},
		".list-item": {flexDirection: "row"},
		".list-item-course": {
			width: "100%",
			flexDirection: "row",
			justifyContent: "space-between"
		},
		".item-course-content": {display: "flex", flexDirection: "column"},
		".item-course-title": {
			width: "225px",
			maxHeight: "42px",
			fontSize: "15px",
			fontWeight: "bold",
			overflow: "hidden",
			textOverflow: "ellipsis",
			color: "#333"
		},
		".item-course-des": {
			width: "220px",
			fontSize: "12px",
			color: "#999",
			marginTop: "10px"
		},
		".item-course-icon": {marginTop: "15.5px"},
		".item-course-icon_img": {width: "7px", height: "13px"},
		".item-course-btn": {
			alignSelf: "flex-end",
			width: "59px",
			height: "30px",
			lineHeight: "30px",
			textAlign: "center",
			borderRadius: "3px",
			border: "1px solid #17b47b",
			fontSize: "12px",
			color: "#17b47b"
		},
		".item-course-progress": {width: "220px", height: "4px", marginTop: "5px"},
		".des-data": {fontSize: "12px", color: "#999"},
		".des-pro": {fontSize: "12px", color: "#999"},
		".pause": {
			height: "16.5px",
			flexDirection: "row",
			justifyContent: "space-between",
			display: "flex"
		},
		".progress_fail": {backgroundColor: "#ff3b30"},
		".fail": {border: "1px solid #ff3b30", color: "#ff3b30"}
	};
	apivm.define("no-encrypt-download", NoEncryptDownload);

	global.fs = api.require("fs");
	var EncryptDownload = /*@__PURE__*/ (function(Component) {
		function EncryptDownload(props) {
			Component.call(this, props);
			this.data = {
				finish: [], // 已完成
				downloading: [], // 下载中
				progress: 0, // 下载进度
				isPause: false, // 是否暂停下载
				error: [] // 下载失败
			};
		}

		if (Component) EncryptDownload.__proto__ = Component;
		EncryptDownload.prototype = Object.create(Component && Component.prototype);
		EncryptDownload.prototype.constructor = EncryptDownload;
		EncryptDownload.prototype.installed = function() {
			this.init();
			this.initEventListenter();
			if (this.data.downloading.length > 0) {
				var AliyunPlayer = api.require("AliyunPlayer");
				AliyunPlayer.startDownload();
			}
		};
		EncryptDownload.prototype.init = function() {
			var encryptLocalVideos = storage.get("encryptLocalVideos") || [];
			if (encryptLocalVideos.length > 0) {
				this.fire("hasEnDown", true);
				var finishList = [];
				var downloadingList = [];

				encryptLocalVideos.map(function(item) {
					if (item.savePath) {
						finishList.push(item);
					} else {
						downloadingList.push(item);
					}
				});

				this.data.finish = finishList;
				this.data.downloading = downloadingList;
			} else {
				this.fire("hasEnDown", false);
				this.data.finish = [];
				this.data.downloading = [];
			}
		};
		EncryptDownload.prototype.initEventListenter = function() {
			var this$1 = this;

			api.addEventListener(
				{
					name: "progress"
				},
				function(ret) {
					if (ret.value.progress) {
						this$1.data.progress = ret.value.progress;
					} else if (ret.value.status) {
						this$1.data.progress = 0;
						this$1.init();
					} else {
						this$1.data.progress = 0;
						this$1.init();
					}
				}
			);
		};
		EncryptDownload.prototype.startOrPause = function() {
			var AliyunPlayer = api.require("AliyunPlayer");
			if (this.data.isPause) {
				AliyunPlayer.startDownload();
				this.data.isPause = false;
			} else {
				AliyunPlayer.stopDownload();
				this.data.isPause = true;
			}
		};
		EncryptDownload.prototype.onDelete = function(videoId, savePath) {
			var this$1 = this;

			api.confirm(
				{
					msg: "是否确认删除该视频",
					buttons: ["确定", "取消"]
				},
				function(ret, err) {
					if (ret.buttonIndex == 1) {
						this$1.removeLocalVideo(videoId);
					}
				}
			);
		};
		EncryptDownload.prototype.fsRemove = function(savePath) {
			var folderPath = savePath.slice(0, savePath.indexOf("."));
			// 删除 m3u8文件
			fs.remove({path: savePath});
			// 删除存储分段视频的ts文件夹
			fs.rmdir({path: folderPath});
		};
		EncryptDownload.prototype.removeLocalVideo = function(videoId) {
			var this$1 = this;

			var encryptLocalVideos = storage.get("encryptLocalVideos") || [];
			var index = encryptLocalVideos.findIndex(function(item) {
				return item.videoId === videoId;
			});
			this.fsRemove(encryptLocalVideos[index].savePath);
			encryptLocalVideos.splice(index, 1);
			storage.set("encryptLocalVideos", encryptLocalVideos);
			api.getPrefs(
				{
					key: "encryptLocalVideos"
				},
				function() {
					this$1.init();
				}
			);
		};
		EncryptDownload.prototype.openVideo = function(videoId) {
			api.openWin({
				name: "aliVideo",
				url: "../video/testali.stml",
				pageParam: {
					videoId: videoId
				}
			});
		};
		EncryptDownload.prototype.render = function() {
			var this$1 = this;
			return apivm.h(
				"view",
				{class: "encrypt-download"},

				this.data.finish.map(function(item, index) {
					return apivm.h(
						"view",
						{
							class: "list-item",
							onClick: function() {
								return this$1.openVideo(item.videoId);
							}
						},
						apivm.h(
							"view",
							{class: "list-item-course"},
							apivm.h(
								"view",
								{class: "item-course-content"},
								apivm.h("text", {class: "item-course-title"}, item.title),
								apivm.h("text", {class: "item-course-des"}, "已缓存")
							),
							!this$1.props.handleVideoBtn
								? apivm.h(
										"view",
										{class: "item-course-icon"},
										apivm.h("image", {
											class: "item-course-icon_img",
											src: "../../image/default-icon-more.png"
										})
								  )
								: null,
							this$1.props.handleVideoBtn
								? apivm.h(
										"text",
										{
											class: "item-course-btn fail",
											onClick: function() {
												return this$1.onDelete(item.videoId, item.savePath);
											}
										},
										"删除"
								  )
								: null
						)
					);
				}),

				this.data.downloading.map(function(item, index) {
					return apivm.h(
						"view",
						{class: "list-item"},
						apivm.h(
							"view",
							{class: "list-item-course"},
							apivm.h(
								"view",
								{class: "item-course-content"},
								apivm.h("text", {class: "item-course-title"}, item.title),
								apivm.h(
									"view",
									{class: "item-course-des pause"},
									index === 0
										? apivm.h("text", {class: "des-pro"}, this$1.data.progress, "%")
										: null,
									index === 0 && this$1.data.isPause
										? apivm.h("text", {class: "des-data"}, "暂停中")
										: null,
									index !== 0 ? apivm.h("text", {class: "des-data"}, "排队中") : null
								),
								index === 0
									? apivm.h("progress", {
											class: "item-course-progress",
											value: this$1.data.progress,
											activeColor: "#17B47B",
											backgroundColor: "#E5E5E5"
									  })
									: null
							),
							apivm.h(
								"text",
								{
									class: "item-course-btn",
									onClick: this$1.startOrPause,
									style: {
										display: index === 0 && !this$1.props.handleVideoBtn ? "flex" : "none"
									}
								},
								this$1.data.isPause ? "继续" : "暂停"
							)
						)
					);
				})
			);
		};

		return EncryptDownload;
	})(Component);
	EncryptDownload.css = {
		".encrypt-download": {
			display: "flex",
			flexDirection: "column",
			width: "100%"
		},
		".title": {
			lineHeight: "44px",
			fontSize: "23px",
			fontWeight: "bold",
			color: "#333",
			marginTop: "10px"
		},
		".list": {flex: "1"},
		".list-item": {flexDirection: "row", margin: "22.5px 0"},
		".list-item-course": {
			width: "100%",
			flexDirection: "row",
			justifyContent: "space-between"
		},
		".item-course-content": {display: "flex", flexDirection: "column"},
		".item-course-title": {
			width: "225px",
			maxHeight: "42px",
			fontSize: "15px",
			fontWeight: "bold",
			overflow: "hidden",
			textOverflow: "ellipsis",
			color: "#333"
		},
		".item-course-des": {
			width: "220px",
			fontSize: "12px",
			color: "#999",
			marginTop: "10px"
		},
		".item-course-icon": {marginTop: "15.5px"},
		".item-course-icon_img": {width: "7px", height: "13px"},
		".item-course-btn": {
			alignSelf: "flex-end",
			width: "59px",
			height: "30px",
			lineHeight: "30px",
			textAlign: "center",
			borderRadius: "3px",
			border: "1px solid #17b47b",
			fontSize: "12px",
			color: "#17b47b"
		},
		".item-course-progress": {width: "220px", height: "4px", marginTop: "5px"},
		".des-data": {fontSize: "12px", color: "#999"},
		".des-pro": {fontSize: "12px", color: "#999"},
		".pause": {
			height: "16.5px",
			flexDirection: "row",
			justifyContent: "space-between",
			display: "flex"
		},
		".progress_fail": {backgroundColor: "#ff3b30"},
		".fail": {border: "1px solid #ff3b30", color: "#ff3b30"}
	};
	apivm.define("encrypt-download", EncryptDownload);

	var Download = /*@__PURE__*/ (function(Component) {
		function Download(props) {
			Component.call(this, props);
			this.data = {
				hasDownload: true,
				// 是否有下载(非加密)
				hasEncryptDownload: true,
				// 是否有下载(加密)
				handleVideoBtn: false // 处理视频按钮
			};
		}

		if (Component) Download.__proto__ = Component;
		Download.prototype = Object.create(Component && Component.prototype);
		Download.prototype.constructor = Download;
		Download.prototype.apiready = function() {
			this.initEventListenter();
			console.log(JSON.stringify(storage.get("localVideos")));
			console.log(JSON.stringify(storage.get("encryptLocalVideos")));
		};
		Download.prototype.set = function() {
			storage.set("localVideos", []);
			storage.set("encryptLocalVideos", []);
			storage.set("currentDownloadFile", {});
		};
		Download.prototype.setDownload = function(isHas) {
			var this$1 = this;

			// setTimeout，为解决avm3.0语法bug问题（勿删）
			setTimeout(function() {
				this$1.data.hasDownload = isHas.detail;
			});
		};
		Download.prototype.setEncryptDownload = function(isHas) {
			var this$1 = this;

			// setTimeout，为解决avm3.0语法bug问题（勿删）
			setTimeout(function() {
				this$1.data.hasEncryptDownload = isHas.detail;
			});
		};
		Download.prototype.initEventListenter = function() {
			var this$1 = this;

			api.addEventListener(
				{
					name: "navitembtn"
				},
				function() {
					this$1.data.handleVideoBtn = !this$1.data.handleVideoBtn;
					api.setNavBarAttr({
						rightButtons: [
							{
								text: this$1.data.handleVideoBtn ? "完成  " : "编辑  "
							}
						]
					});
				}
			);
		};
		Download.prototype.render = function() {
			return apivm.h(
				"view",
				{class: "page"},

				apivm.h("text", {class: "title"}, "离线中心"),

				this.data.hasDownload || this.data.hasEncryptDownload
					? apivm.h(
							"scroll-view",
							{class: "list", "show-scrollbar": "false"},

							apivm.h("encrypt-download", {
								handleVideoBtn: this.data.handleVideoBtn,
								onHasEnDown: this.setEncryptDownload
							}),

							apivm.h("no-encrypt-download", {
								handleVideoBtn: this.data.handleVideoBtn,
								onHasDown: this.setDownload
							})
					  )
					: apivm.h(
							"view",
							{class: "nodata"},
							apivm.h(
								"view",
								{class: "list-nodata"},
								apivm.h("image", {
									class: "list-nodata_img",
									src: "../../image/default-display-nopower.png"
								}),
								apivm.h("text", {class: "list-nodata_text"}, "暂无内容")
							)
					  )
			);
		};

		return Download;
	})(Component);
	Download.css = {
		".page": {
			display: "flex",
			flexDirection: "column",
			height: "100%",
			padding: "0 20px 40px 20px",
			boxSizing: "border-box"
		},
		".title": {
			lineHeight: "44px",
			fontSize: "23px",
			fontWeight: "bold",
			color: "#333",
			marginTop: "10px"
		},
		".nodata": {marginTop: "25px"},
		".list-nodata": {padding: "40px 55px 66.5px", boxSizing: "border-box"},
		".list-nodata_img": {width: "225px", height: "175px", margin: "0 auto"},
		".list-nodata_text": {textAlign: "center", fontSize: "12px", color: "#999"},
		".list": {flex: "1"}
	};
	apivm.define("download", Download);
	apivm.render(apivm.h("download", null), "body");
})();
