(function() {
	// api接口请求地址
	var BASEURL = "https://cbt.tibaitong.com/";

	/********************************************
	 *             系统和业务                   *
	 ******************************************/

	// 本地存储
	var storage = {
		set: function set(key, value) {
			api.setPrefs({
				key: key,
				value: typeof value === "string" ? value : JSON.stringify(value)
			});
		},

		get: function get(key) {
			var value = api.getPrefs({sync: true, key: key}) || "";

			try {
				return JSON.parse(value);
			} catch (e) {
				return value;
			}
		},

		del: function del(key) {
			api.removePrefs({key: key});
		}
	};

	// 请求
	function ajax(_ref) {
		var url = _ref.url,
			_ref$method = _ref.method,
			method = _ref$method === void 0 ? "get" : _ref$method,
			_ref$data = _ref.data,
			data = _ref$data === void 0 ? {} : _ref$data;
		return new Promise(function(resolve, reject) {
			api.ajax(
				{
					url: url.indexOf("http") === 0 ? url : BASEURL + url,
					method: method,
					headers: {
						"Content-Type": "application/json;charset=utf-8",
						"ZK-TOKEN": storage.get("token"),
						"APP-TYPE": 2
					},

					timeout: 60,
					data: {
						body: data
					}
				},

				function(ret, err) {
					if (ret) {
						if (ret.code === 200) {
							resolve(ret.data);
						} else if (ret.code === 600) {
							api.sendEvent({
								name: "loginExpired"
							});
						} else {
							api.toast({
								msg: ret.msg
							});
						}

						reject(ret);
					} else {
						api.toast({
							msg: "网络不畅,请检查网络"
						});

						reject(err);
					}
				}
			);
		});
	}

	/**
	 * 打开一个带导航的本地页面
	 * @param {String} name 标题
	 * @param {String} title 标题
	 * @param {String} url 网络地址
	 */
	function openNavStml(name, title, url) {
		api.openTabLayout({
			name: name,
			title: title,
			url: url,
			navigationBar: {}
		});
	}

	/**
	 * 获取反馈与回答集合
	 */
	function getFeedbackList() {
		return ajax({
			url: "/recordFeedback/list",
			method: "get",
			data: {}
		});
	}

	/**
	 * 修改已读状态
	 * @param {Number} replyId 回复id
	 */
	function updateFeedbackRead(replyId) {
		return ajax({
			url: "/recordFeedback/updateRead/" + replyId,
			method: "post",
			data: {}
		});
	}

	var FeedbackResult = /*@__PURE__*/ (function(Component) {
		function FeedbackResult(props) {
			Component.call(this, props);
			this.data = {
				params: {},
				feedbackList: [],
				lis: [
					{id: 1, arr: [1, 2, 3]},
					{id: 2, arr: ["a", "b", "c"]}
				],
				imageUrl: "",
				imageShow: false,
				refresherTriggered: false
			};
		}

		if (Component) FeedbackResult.__proto__ = Component;
		FeedbackResult.prototype = Object.create(Component && Component.prototype);
		FeedbackResult.prototype.constructor = FeedbackResult;
		FeedbackResult.prototype.apiready = function() {
			this.init();
			this.initEventListenter();
		};
		FeedbackResult.prototype.initEventListenter = function() {
			var this$1 = this;

			api.addEventListener(
				{
					name: "viewappear"
				},
				function() {
					this$1.getFeedbackList();
				}
			);
		};
		FeedbackResult.prototype.init = function() {
			this.getFeedbackList();
		};
		FeedbackResult.prototype.back = function() {
			api.closeWin();
		};
		FeedbackResult.prototype.getFeedbackList = function() {
			var this$1 = this;

			getFeedbackList()
				.then(function(res) {
					var arr = res || [];
					if (arr.length) {
						res.forEach(function(item, index) {
							if (item.images) {
								arr[index].imagesArr = item.images.split("|");
							}
						});
						this$1.data.feedbackList = arr || [];
					}
				})
				.then(function() {
					this$1.updateFeedbackRead();
				})
				.catch(function(err) {
					this$1.data.feedbackList = [];
				});
		};
		FeedbackResult.prototype.showImage = function(url) {
			this.data.imageUrl = url;
			this.data.imageShow = true;
		};
		FeedbackResult.prototype.closeMask = function() {
			this.data.imageShow = false;
		};
		FeedbackResult.prototype.updateFeedbackRead = function() {
			this.data.feedbackList.map(function(feedbackItem) {
				if (feedbackItem.replyId && !feedbackItem.isRead) {
					updateFeedbackRead(feedbackItem.replyId).then(function(res) {});
				}
			});
			api.sendEvent({
				name: "clearUnread"
			});
		};
		FeedbackResult.prototype.onrefresherrefresh = function() {
			this.data.refresherTriggered = true;

			this.getFeedbackList();

			this.data.refresherTriggered = false;
		};
		FeedbackResult.prototype.toFeedback = function() {
			openNavStml(
				"feedback",
				"用户反馈",
				"https://vip.zhuokao360.com/app/html/feedback"
			);
		};
		FeedbackResult.prototype.render = function() {
			var this$1 = this;
			return apivm.h(
				"view",
				{class: "page"},
				apivm.h("safe-area", {class: "safe"}),
				apivm.h(
					"view",
					{class: "nav"},
					apivm.h("image", {
						class: "back",
						src: "../../image/icon/back-black.png",
						onClick: this.back
					}),
					apivm.h("text", {class: "nav_title"}, "反馈结果")
				),

				apivm.h(
					"view",
					{
						class: "container",
						style: {display: !this.data.feedbackList.length ? "flex" : "none"}
					},
					apivm.h("image", {
						class: "no-feedback-img",
						src: "../../image/no-feedback.png"
					}),
					apivm.h("text", {class: "no-feedback-tip"}, "这里空荡荡的，什么都没有~"),
					apivm.h(
						"text",
						{class: "no-feedback-button", onClick: this.toFeedback},
						"我要反馈"
					)
				),
				apivm.h(
					"scroll-view",
					{
						class: "container",
						"scroll-y": "true",
						"show-scrollbar": "false",
						"refresher-enabled": true,
						"refresher-triggered": this.data.refresherTriggered,
						onrefresherrefresh: this.onrefresherrefresh,
						style: {display: this.data.feedbackList.length ? "flex" : "none"}
					},

					(Array.isArray(this.data.feedbackList)
						? this.data.feedbackList
						: Object.values(this.data.feedbackList)
					).map(function(item$1) {
						return apivm.h(
							"view",
							{class: "feedback-item"},
							apivm.h(
								"view",
								{class: "question-title "},
								item$1.replyId && !item$1.isRead
									? apivm.h("view", {class: "un-read"})
									: null,
								apivm.h("text", null, item$1.feedbackInfo)
							),
							item$1.images
								? apivm.h(
										"view",
										{class: "question-img-list"},
										(Array.isArray(item$1.imagesArr)
											? item$1.imagesArr
											: Object.values(item$1.imagesArr)
										).map(function(imgUrl) {
											return apivm.h("image", {
												class: "question-img-item",
												src: imgUrl,
												onClick: function() {
													return this$1.showImage(imgUrl);
												}
											});
										})
								  )
								: null,
							apivm.h("text", {class: "feedback-result-tip"}, "反馈结果"),
							apivm.h(
								"text",
								{class: "feedback-result-answer"},
								item$1.replyContent ? item$1.replyContent : "未回复"
							)
						);
					})
				),

				apivm.h(
					"view",
					{
						class: "mask",
						onClick: this.closeMask,
						style: {display: this.data.imageShow ? "flex" : "none"}
					},
					apivm.h("image", {class: "big-image", src: this.data.imageUrl})
				)
			);
		};

		return FeedbackResult;
	})(Component);
	FeedbackResult.css = {
		".page": {minHeight: "100vh", background: "#f5f5f5"},
		".safe": {background: "#ffffff"},
		".nav": {
			background: "#ffffff",
			height: "44px",
			width: "100%",
			borderBottom: "1px solid rgba(120, 120, 120, 0.1)",
			padding: "3px auto 5px",
			flexDirection: "row",
			justifyContent: "center",
			alignItems: "center",
			position: "relative"
		},
		".back": {position: "absolute", left: "20px", width: "10px", height: "20px"},
		".nav_title": {fontSize: "16px", fontWeight: "bold"},
		".container": {
			width: "90vw",
			height: "94vh",
			margin: "16px auto 0",
			padding: "0 50px",
			borderTopLeftRadius: "20px",
			borderTopRightRadius: "20px",
			background: "#ffffff",
			alignItems: "center"
		},
		".feedback-item": {padding: "50px 0", borderBottom: "1px solid #eeeeee"},
		".question-title": {
			marginBottom: "20px",
			flexDirection: "row",
			alignItems: "center"
		},
		".question-img-list": {flexDirection: "row", margin: "0 0 50px"},
		".question-img-item": {width: "80px", height: "80px", marginRight: "10px"},
		".feedback-result-tip": {
			width: "80px",
			height: "26px",
			marginBottom: "20px",
			background: "#5538de",
			color: "#ffffff",
			textAlign: "center",
			lineHeight: "26px"
		},
		".mask": {
			position: "absolute",
			top: "0",
			right: "0",
			width: "100vw",
			height: "100%",
			background: "#00000048",
			justifyContent: "center",
			alignItems: "center"
		},
		".big-image": {maxWidth: "94vw", maxHeight: "94%"},
		".un-read": {
			width: "5px",
			height: "5px",
			borderRadius: "50%",
			background: "#ff1414",
			marginRight: "10px"
		},
		".no-feedback-tip": {color: "#999999"},
		".no-feedback-button": {
			background: "#5538DE",
			color: "#ffffff",
			width: "120px",
			height: "40px",
			borderRadius: "20px",
			display: "flex",
			textAlign: "center",
			marginTop: "30px",
			lineHeight: "40px"
		}
	};
	apivm.define("feedback-result", FeedbackResult);
	apivm.render(apivm.h("feedback-result", null), "body");
})();
