(function() {
	// api接口请求地址
	var BASEURL = "https://cbt.tibaitong.com/";

	/********************************************
	 *             系统和业务                   *
	 ******************************************/

	// 本地存储
	var storage = {
		set: function set(key, value) {
			api.setPrefs({
				key: key,
				value: typeof value === "string" ? value : JSON.stringify(value)
			});
		},

		get: function get(key) {
			var value = api.getPrefs({sync: true, key: key}) || "";

			try {
				return JSON.parse(value);
			} catch (e) {
				return value;
			}
		},

		del: function del(key) {
			api.removePrefs({key: key});
		}
	};

	// 请求
	function ajax(_ref) {
		var url = _ref.url,
			_ref$method = _ref.method,
			method = _ref$method === void 0 ? "get" : _ref$method,
			_ref$data = _ref.data,
			data = _ref$data === void 0 ? {} : _ref$data;
		return new Promise(function(resolve, reject) {
			api.ajax(
				{
					url: url.indexOf("http") === 0 ? url : BASEURL + url,
					method: method,
					headers: {
						"Content-Type": "application/json;charset=utf-8",
						"ZK-TOKEN": storage.get("token"),
						"APP-TYPE": 2
					},

					timeout: 60,
					data: {
						body: data
					}
				},

				function(ret, err) {
					if (ret) {
						if (ret.code === 200) {
							resolve(ret.data);
						} else if (ret.code === 600) {
							api.sendEvent({
								name: "loginExpired"
							});
						} else {
							api.toast({
								msg: ret.msg
							});
						}

						reject(ret);
					} else {
						api.toast({
							msg: "网络不畅,请检查网络"
						});

						reject(err);
					}
				}
			);
		});
	}

	/**
	 * 获取所有课程
	 */
	function getFreeCourse() {
		return ajax({
			url: "course/findAllCourseAuth"
		});
	}

	var Free = /*@__PURE__*/ (function(Component) {
		function Free(props) {
			Component.call(this, props);
			this.data = {
				courseList: []
			};
		}

		if (Component) Free.__proto__ = Component;
		Free.prototype = Object.create(Component && Component.prototype);
		Free.prototype.constructor = Free;
		Free.prototype.apiready = function() {
			this.getCourseList();
		};
		Free.prototype.getCourseList = function() {
			var this$1 = this;

			getFreeCourse()
				.then(function(res) {
					this$1.data.courseList = res || [];
				})
				.catch(function(err) {
					this$1.data.courseList = [];
				});
		};
		Free.prototype.toCourse = function(index) {
			api.openWin({
				name: "course",
				url: "../../pages/course/course.stml",
				navigationBar: {},
				pageParam: {
					name: this.data.courseList[index].name,
					courseId: this.data.courseList[index].courseId,
					yearQuestion: this.data.courseList[index].yearQuestion
				}
			});
		};
		Free.prototype.render = function() {
			var this$1 = this;
			return apivm.h(
				"view",
				{class: "page"},
				apivm.h(
					"scroll-view",
					{class: "scroll-view", "show-scrollbar": "false"},
					(Array.isArray(this.data.courseList)
						? this.data.courseList
						: Object.values(this.data.courseList)
					).map(function(item$1, index$1) {
						return apivm.h(
							"view",
							null,
							apivm.h(
								"view",
								{
									class: "course-item",
									onClick: function() {
										return this$1.toCourse(index$1);
									}
								},
								apivm.h("image", {
									class: "course-item-img",
									src: item$1.courseImageSrc,
									thumbnail: "false",
									mode: "widthFix",
									placeholder: "../../image/logo.png"
								}),
								apivm.h(
									"view",
									{class: "course-item-des"},
									apivm.h("text", {class: "course-item-profess"}, item$1.name),
									apivm.h(
										"text",
										{class: "course-item-time"},
										item$1.totalVideoNum,
										"课时"
									)
								),
								apivm.h("text", {class: "course-item-open"}, "进入课程")
							)
						);
					})
				)
			);
		};

		return Free;
	})(Component);
	Free.css = {
		".page": {height: "100%"},
		".scroll-view": {flex: "1", padding: "0 15px", marginTop: "10px"},
		".course-item": {
			display: "flex",
			flexDirection: "row",
			width: "100%",
			margin: "10px 0"
		},
		".course-item-img": {width: "90px", height: "90px", borderRadius: "10px"},
		".course-item-des": {
			flex: "1",
			justifyContent: "space-between",
			padding: "4px 0",
			marginLeft: "10px"
		},
		".course-item-profess": {fontSize: "16px", fontWeight: "bold", color: "#333"},
		".course-item-time": {fontSize: "12px", color: "#333"},
		".course-item-open": {
			alignSelf: "flex-end",
			border: "1px solid #5538de",
			fontSize: "12px",
			color: "#5538de",
			padding: "5px"
		}
	};
	apivm.define("free", Free);
	apivm.render(apivm.h("free", null), "body");
})();
