(function() {
	// api接口请求地址
	var BASEURL = "https://cbt.tibaitong.com/";

	/********************************************
	 *             系统和业务                   *
	 ******************************************/

	// 本地存储
	var storage = {
		set: function set(key, value) {
			api.setPrefs({
				key: key,
				value: typeof value === "string" ? value : JSON.stringify(value)
			});
		},

		get: function get(key) {
			var value = api.getPrefs({sync: true, key: key}) || "";

			try {
				return JSON.parse(value);
			} catch (e) {
				return value;
			}
		},

		del: function del(key) {
			api.removePrefs({key: key});
		}
	};

	// 请求
	function ajax(_ref) {
		var url = _ref.url,
			_ref$method = _ref.method,
			method = _ref$method === void 0 ? "get" : _ref$method,
			_ref$data = _ref.data,
			data = _ref$data === void 0 ? {} : _ref$data;
		return new Promise(function(resolve, reject) {
			api.ajax(
				{
					url: url.indexOf("http") === 0 ? url : BASEURL + url,
					method: method,
					headers: {
						"Content-Type": "application/json;charset=utf-8",
						"ZK-TOKEN": storage.get("token"),
						"APP-TYPE": 2
					},

					timeout: 60,
					data: {
						body: data
					}
				},

				function(ret, err) {
					if (ret) {
						if (ret.code === 200) {
							resolve(ret.data);
						} else if (ret.code === 600) {
							api.sendEvent({
								name: "loginExpired"
							});
						} else {
							api.toast({
								msg: ret.msg
							});
						}

						reject(ret);
					} else {
						api.toast({
							msg: "网络不畅,请检查网络"
						});

						reject(err);
					}
				}
			);
		});
	}

	function toast(msg) {
		api.toast({msg: msg});
	}

	/**
	 * 短信前置-获取图片验证码
	 * @param {String} phone 手机号码
	 */
	function getImageCode(phone) {
		return ajax({
			url: "sms/getImageCode",
			data: {
				phone: phone
			}
		});
	}

	var LoginMask = /*@__PURE__*/ (function(Component) {
		function LoginMask(props) {
			Component.call(this, props);
			this.data = {
				code: "",
				imgSrc: null
			};
		}

		if (Component) LoginMask.__proto__ = Component;
		LoginMask.prototype = Object.create(Component && Component.prototype);
		LoginMask.prototype.constructor = LoginMask;
		LoginMask.prototype.apiready = function() {
			this.getImageCode();
		};
		LoginMask.prototype.getImageCode = function() {
			var this$1 = this;

			getImageCode().then(function(res) {
				this$1.data.imgSrc = res.imageUrl;
			});
		};
		LoginMask.prototype.cancelMask = function() {
			api.closeFrame();
		};
		LoginMask.prototype.sureMask = function() {
			if (this.data.code.length !== 4) {
				toast("请输入4位有效的图片验证码");
			} else {
				api.sendEvent({
					name: "verifyRegister",
					extra: {
						code: this.data.code
					}
				});

				this.cancelMask();
			}
		};
		LoginMask.prototype.getCode = function(e) {
			this.data.code = e.detail.value;
		};
		LoginMask.prototype.render = function() {
			return apivm.h(
				"view",
				{class: "login-mask"},
				apivm.h(
					"view",
					{class: "mask-main"},
					apivm.h("text", {class: "mask-title"}, "请输入图片验证码"),
					apivm.h(
						"view",
						{class: "mask-verify"},
						apivm.h("input", {
							class: "mask-input",
							type: "text",
							placeholder: "请输入图片验证码",
							maxlength: 4,
							onInput: this.getCode
						}),
						apivm.h("image", {
							class: "mask-img",
							src: this.data.imgSrc,
							onClick: this.getImageCode
						})
					),
					apivm.h(
						"view",
						{class: "mask-btn"},
						apivm.h("text", {class: "mask-btn-1", onClick: this.cancelMask}, "取消"),
						apivm.h("text", {class: "mask-btn-2", onClick: this.sureMask}, "确定")
					)
				)
			);
		};

		return LoginMask;
	})(Component);
	LoginMask.css = {
		".login-mask": {
			display: "flex",
			justifyContent: "center",
			alignItems: "center",
			width: "100%",
			height: "100%",
			backgroundColor: "rgba(0, 0, 0, 0.6)"
		},
		".mask-main": {
			justifyContent: "center",
			alignItems: "center",
			width: "77%",
			backgroundColor: "#fff",
			borderRadius: "10px"
		},
		".mask-title": {margin: "15px 0"},
		".mask-verify": {
			flexDirection: "row",
			backgroundColor: "#999999",
			margin: "20px"
		},
		".mask-input": {height: "37px", border: "none", backgroundColor: "#fafafa"},
		".mask-img": {width: "75px", height: "37px"},
		".mask-btn": {
			flexDirection: "row",
			borderTop: "1px solid rgba(153, 153, 153, 0.3)",
			marginTop: "20px"
		},
		".mask-btn-1": {
			textAlign: "center",
			width: "50%",
			borderRight: "1px solid rgba(153, 153, 153, 0.3)",
			fontSize: "15px",
			padding: "12px 0"
		},
		".mask-btn-2": {
			textAlign: "center",
			width: "50%",
			fontSize: "15px",
			color: "#5538de",
			padding: "12px 0"
		}
	};
	apivm.define("login-mask", LoginMask);
	apivm.render(apivm.h("login-mask", null), "body");
})();
