(function() {
	// 打开隐私政策
	function openPrivacyPolicy() {
		api.openTabLayout({
			name: "privacyPolicy",
			url: "https://vip.zhuokao360.com/terms/privacyPolicy/btzx.html",
			title: "隐私政策",
			navigationBar: {},
			avm: false
		});
	}

	// 打开用户协议
	function openUserAgreement() {
		api.openTabLayout({
			name: "userAgreement",
			url: "https://vip.zhuokao360.com/terms/userAgreement/btzx.html",
			title: "用户协议",
			navigationBar: {},
			avm: false
		});
	}

	// api接口请求地址
	var BASEURL = "https://cbt.tibaitong.com/";

	/********************************************
	 *             系统和业务                   *
	 ******************************************/

	// 本地存储
	var storage = {
		set: function set(key, value) {
			api.setPrefs({
				key: key,
				value: typeof value === "string" ? value : JSON.stringify(value)
			});
		},

		get: function get(key) {
			var value = api.getPrefs({sync: true, key: key}) || "";

			try {
				return JSON.parse(value);
			} catch (e) {
				return value;
			}
		},

		del: function del(key) {
			api.removePrefs({key: key});
		}
	};

	// 请求
	function ajax(_ref) {
		var url = _ref.url,
			_ref$method = _ref.method,
			method = _ref$method === void 0 ? "get" : _ref$method,
			_ref$data = _ref.data,
			data = _ref$data === void 0 ? {} : _ref$data;
		return new Promise(function(resolve, reject) {
			api.ajax(
				{
					url: url.indexOf("http") === 0 ? url : BASEURL + url,
					method: method,
					headers: {
						"Content-Type": "application/json;charset=utf-8",
						"ZK-TOKEN": storage.get("token"),
						"APP-TYPE": 2
					},

					timeout: 60,
					data: {
						body: data
					}
				},

				function(ret, err) {
					if (ret) {
						if (ret.code === 200) {
							resolve(ret.data);
						} else if (ret.code === 600) {
							api.sendEvent({
								name: "loginExpired"
							});
						} else {
							api.toast({
								msg: ret.msg
							});
						}

						reject(ret);
					} else {
						api.toast({
							msg: "网络不畅,请检查网络"
						});

						reject(err);
					}
				}
			);
		});
	}

	/**
	 * 设置登录状态
	 * @param {Boolean} status 登录状态
	 */
	function setLoginStatus(status) {
		storage.set("isLogin", !!status);
	}

	/**
	 * 保存用户信息（为方便获取token，这里有意分开保存userInfo和token）
	 * @param {Object} userInfo 用户信息
	 * @param {String} token 用户TOKEN
	 */
	function saveUserInfo(userInfo, token) {
		storage.set("userInfo", userInfo);
		if (token) {
			storage.set("token", token);
		}
	}

	/**
	 * 用户登录成功
	 * @param {Object} userInfo 用户信息
	 */
	function loginSuccess(_ref2) {
		var userId = _ref2.userId,
			phone = _ref2.phone,
			token = _ref2.token,
			nick = _ref2.nick,
			photo = _ref2.photo,
			signature = _ref2.signature,
			userDeviceCodes = _ref2.userDeviceCodes,
			userLock = _ref2.userLock;
		// 设置用户登录状态
		setLoginStatus(true);

		// 保存用户信息
		saveUserInfo(
			{
				userId: userId,
				phone: phone,
				nickname: nick || "愤斗",
				avatarUrl:
					photo || "https://files.zhuokao360.com/user/photo/avatar@default.png",
				info: signature || "这家伙很懒，什么都没有留下。",
				userDeviceCodes: userDeviceCodes,
				userLock: userLock
			},

			token
		);

		closeToRoot();
		// 发送登录事件
		api.sendEvent({
			name: "login"
		});
	}

	// 获取上次登录的账号
	function getLastLogin() {
		return storage.get("lastLogin");
	}

	/**
	 * 关闭窗口
	 * @param {String} name window 名字
	 * @param {Number} timeout 延迟时间
	 */
	function closeWin(_temp) {
		var _ref3 = _temp === void 0 ? {} : _temp,
			name = _ref3.name,
			timeout = _ref3.timeout;
		function close() {
			if (typeof name === "string") {
				api.closeWin({name: name});
			} else {
				api.closeWin();
			}
		}

		if (typeof timeout === "number") {
			setTimeout(close, timeout);
		} else {
			close();
		}
	}

	/**
	 * 关闭到根页面
	 */
	function closeToRoot() {
		api.closeToWin({
			name: "root"
		});

		// 始终竖屏显示
		api.setScreenOrientation({
			orientation: "portrait_up"
		});
	}

	/**
	 * 校验手机号
	 * @param {Number} phone 手机号
	 */
	function validatorPhone(phone) {
		return /^1[3456789]\d{9}$/.test(phone);
	}

	function toast(msg) {
		api.toast({msg: msg});
	}

	/**
	 * 账户密码登录
	 * @param {String} phone 手机号
	 * @param {String} password 密码
	 */
	function login(phone, password) {
		return ajax({
			url: "login/login",
			method: "post",
			data: {
				phone: phone,
				password: password
			}
		});
	}

	/**
	 * 短信前置-获取图片验证码
	 * @param {String} phone 手机号码
	 */
	function getImageCode(phone) {
		return ajax({
			url: "sms/getImageCode",
			data: {
				phone: phone
			}
		});
	}

	/**
	 * 获取短信验证码
	 * @param {String} phone 手机号码
	 * @param {Number} imageCode 4位数字的图片验证码
	 */
	function sendSmscode(phone, imageCode) {
		return ajax({
			url: "sms/sendSms",
			method: "post",
			data: {
				phone: phone,
				imageCode: imageCode,
				type: 33
			}
		});
	}

	/**
	 * 短信验证码登录
	 * @param {String} phone 手机号码
	 * @param {Number} smscode 6位数字的短信验证码
	 */
	function smscodeLogin(phone, smscode) {
		return ajax({
			url: "login/sms",
			method: "post",
			data: {
				phone: phone,
				smsCode: smscode,
				type: 33
			}
		});
	}

	var Loading = /*@__PURE__*/ (function(Component) {
		function Loading(props) {
			Component.call(this, props);
			this.data = {};
		}

		if (Component) Loading.__proto__ = Component;
		Loading.prototype = Object.create(Component && Component.prototype);
		Loading.prototype.constructor = Loading;
		Loading.prototype.apiready = function() {};
		Loading.prototype.render = function() {
			return apivm.h("image", {
				class: "" + (this.props.type ? "loading_" + this.props.type : "loading_"),
				src: "../../image/loading.gif"
			});
		};

		return Loading;
	})(Component);
	Loading.css = {
		".loading_": {
			width: "65px",
			height: "65px",
			position: "absolute",
			top: "43%",
			left: "50%",
			transform: "translateX(-25px)",
			zIndex: "99"
		},
		".loading_login": {
			width: "65px",
			height: "65px",
			position: "absolute",
			top: "17%",
			left: "50%",
			transform: "translateX(-25px)",
			zIndex: "99"
		}
	};
	apivm.define("loading", Loading);

	var LoginMain = /*@__PURE__*/ (function(Component) {
		function LoginMain(props) {
			Component.call(this, props);
			this.data = {
				phone: null,
				code: null,
				loginModel: 0,
				isAgree: false,
				isSend: false,
				countdown: 60
			};
		}

		if (Component) LoginMain.__proto__ = Component;
		LoginMain.prototype = Object.create(Component && Component.prototype);
		LoginMain.prototype.constructor = LoginMain;
		LoginMain.prototype.installed = function() {
			var lastLogin = getLastLogin();
			var Agreement = storage.get("isAgree");
			this.data.phone = lastLogin ? lastLogin : null;
			this.data.isAgree = Agreement;
			this.initEventListenter();
		};
		LoginMain.prototype.initEventListenter = function() {
			var this$1 = this;

			api.addEventListener(
				{
					name: "verifyRegister"
				},
				function(ret) {
					var ref = ret.value;
					var code = ref.code;
					sendSmscode(this$1.data.phone, code).then(function() {
						this$1.codeLastTime();
						toast("发送成功！");
					});
				}
			);
		};
		LoginMain.prototype.requireCode = function() {
			var this$1 = this;

			if (!validatorPhone(this.data.phone)) {
				toast("请填写正确的手机号");
				return;
			}

			getImageCode(this.data.phone)
				.then(function(res) {
					var imageCode = res.imageCode;
					var imageUrl = res.imageUrl;
					if (imageCode) {
						sendSmscode(this$1.data.phone, imageCode).then(function() {
							this$1.codeLastTime();
							toast("发送成功！");
						});
						return;
					}

					if (imageUrl) {
						this$1.verifyCode();
						return;
					}

					return Promise.reject();
				})
				.catch(function(err) {
					toast("发送失败");
				});
		};
		LoginMain.prototype.verifyCode = function() {
			api.openFrame({
				name: "loginMask",
				url: "./login-mask.stml",
				rect: {
					x: 0,
					y: 0,
					w: "auto",
					h: "auto"
				}
			});
		};
		LoginMain.prototype.onSubmit = function() {
			if (!this.data.isAgree) {
				toast("请先勾选同意《用户协议》和《隐私政策》");
				return;
			}

			if (!this.data.code || !this.data.phone) {
				toast("请检查用户名或密码是否填写完整");
				return;
			}

			this.logining = true;
			this.data.loginModel
				? this.loginByPhone(this.data.phone, this.data.code)
				: this.loginBySms(this.data.phone, this.data.code);
		};
		LoginMain.prototype.loginByPhone = function(phone, code) {
			var this$1 = this;

			login(phone, code)
				.then(function(res) {
					this$1.loginSuccess(res);
					this$1.logining = false;
				})
				.catch(function(err) {
					this$1.logining = false;
				});
		};
		LoginMain.prototype.loginBySms = function(phone, code) {
			var this$1 = this;

			smscodeLogin(phone, code)
				.then(function(res) {
					this$1.loginSuccess(res);
					this$1.logining = false;
				})
				.catch(function(err) {
					this$1.logining = false;
				});
		};
		LoginMain.prototype.loginSuccess = function(userInfo) {
			toast("登录成功");

			loginSuccess(userInfo);
			closeWin({timeout: 1000});
		};
		LoginMain.prototype.getPhone = function(e) {
			this.data.phone = e.detail.value;
		};
		LoginMain.prototype.getCode = function(e) {
			this.data.code = e.detail.value;
		};
		LoginMain.prototype.codeLastTime = function() {
			var this$1 = this;

			this.data.isSend = true;

			var timer = setInterval(function() {
				if (this$1.data.countdown > 0) {
					this$1.data.countdown -= 1;
				} else {
					clearInterval(timer);
					this$1.data.countdown = 60;
					this$1.data.isSend = false;
				}
			}, 1000);
		};
		LoginMain.prototype.handleNavSwitch = function() {
			this.data.loginModel = this.data.loginModel ? 0 : 1;
		};
		LoginMain.prototype.handleAgree = function() {
			this.data.isAgree = !this.data.isAgree;
			storage.set("isAgree", this.data.isAgree);
		};
		LoginMain.prototype.render = function() {
			return apivm.h(
				"view",
				{class: "page"},
				apivm.h(
					"view",
					{class: "login"},
					apivm.h(
						"view",
						{class: "course-title"},
						apivm.h("view", {class: "course-title_line"}),
						apivm.h(
							"text",
							{class: "course-title_text"},
							"欢迎，",
							this.data.loginModel ? "密码" : "验证码",
							"登录"
						)
					),

					apivm.h(
						"view",
						{class: "login-input"},
						apivm.h("input", {
							class: "login-input_del input",
							type: "text",
							placeholder: "请输入手机号",
							maxlength: "11",
							"keyboard-type": "number",
							onInput: this.getPhone,
							value: this.data.phone
						})
					),

					apivm.h(
						"view",
						{class: "login-input"},
						apivm.h("input", {
							class: "login-input_del input",
							type: this.data.loginModel ? "password" : "text",
							placeholder: this.data.loginModel ? "请输入密码" : "请输入短信验证码",
							maxlength: this.data.loginModel ? 20 : 6,
							"keyboard-type": this.data.loginModel ? "default" : "number",
							oninput: this.getCode
						}),
						apivm.h(
							"view",
							{
								class: "login-input-sms",
								style: {display: !this.data.loginModel ? "flex" : "none"}
							},
							apivm.h("view", {class: "getCode_line"}),
							!this.data.isSend
								? apivm.h(
										"text",
										{class: "login-getCode", onClick: this.requireCode},
										"发送验证码"
								  )
								: apivm.h(
										"text",
										{class: "login-gotCode"},
										"重新获取(",
										this.data.countdown,
										")"
								  )
						)
					),

					apivm.h(
						"text",
						{class: "login-title", onClick: this.handleNavSwitch},
						this.data.loginModel ? "验证码" : "密码",
						"登录"
					),
					apivm.h("text", {class: "login-btn", onClick: this.onSubmit}, "登录"),

					apivm.h(
						"view",
						{class: "rule"},
						apivm.h("view", {
							class: "agree-icon",
							onClick: this.handleAgree,
							style: {display: this.data.isAgree ? "flex" : "none"}
						}),
						apivm.h("view", {
							class: "disagree-icon",
							onClick: this.handleAgree,
							style: {display: !this.data.isAgree ? "flex" : "none"}
						}),
						apivm.h("text", {class: "rule_text"}, "我同意《"),
						apivm.h(
							"text",
							{class: "rule_text underscore", onClick: openUserAgreement},
							"用户协议"
						),
						apivm.h("text", {class: "rule_text"}, "》和《"),
						apivm.h(
							"text",
							{class: "rule_text underscore", onClick: openPrivacyPolicy},
							"隐私政策"
						),
						apivm.h("text", {class: "rule_text"}, "》")
					)
				)
			);
		};

		return LoginMain;
	})(Component);
	LoginMain.css = {
		".input": {height: "20px", background: "none", border: "none"},
		".loading": {transform: "translateX(-25px)"},
		".course-title": {flexDirection: "row"},
		".course-title_line": {
			width: "4px",
			height: "15px",
			background: "#5538de",
			marginTop: "4.5px"
		},
		".course-title_text": {
			fontSize: "18px",
			fontWeight: "bold",
			color: "#333",
			marginLeft: "7.5px"
		},
		".login": {flex: "1", padding: "0 25px", boxSizing: "border-box"},
		".login-classify": {
			display: "flex",
			flexDirection: "row",
			marginBottom: "15px"
		},
		".login_classify_text": {fontSize: "16px", color: "#666"},
		".classify_text-active": {
			fontSize: "16px",
			fontWeight: "bold",
			color: "#333"
		},
		".login-classify_view": {flexDirection: "row"},
		".login-title": {
			flexDirection: "row-reverse",
			alignSelf: "flex-end",
			fontSize: "14px",
			margin: "8px 0"
		},
		".login-input": {
			display: "flex",
			flexDirection: "row",
			padding: "14.5px 0 14.5px 15px",
			boxSizing: "border-box",
			background: "#f8f8f8",
			border: "1px solid #eee",
			borderRadius: "5px",
			marginTop: "25px"
		},
		".login-input_del": {flex: "1"},
		".login-input-sms": {flexDirection: "row"},
		".getCode_line": {
			width: "1px",
			height: "12px",
			background: "#999",
			margin: "4px 0"
		},
		".login-getCode": {
			width: "93px",
			padding: "1px 0 1px 10px",
			boxSizing: "border-box",
			fontSize: "12px",
			color: "#5538de"
		},
		".login-gotCode": {
			width: "96px",
			padding: "1px 5px 1px 10px",
			boxSizing: "border-box",
			fontSize: "12px",
			color: "#999"
		},
		".login-btn": {
			borderRadius: "5px",
			backgroundColor: "#5538de",
			boxShadow: "2px 5px 8px rgba(85, 56, 222, 0.3)",
			padding: "12px 0",
			textAlign: "center",
			fontSize: "15px",
			color: "#fff",
			margin: "10px 0"
		},
		".rule": {
			display: "flex",
			flexDirection: "row",
			justifyContent: "center",
			fontSize: "12px",
			color: "#999"
		},
		".agree-icon": {
			width: "15px",
			height: "15px",
			background: "url(../../image/default-icon-agree.png) no-repeat",
			backgroundSize: "35px 15px",
			backgroundPosition: "-20px",
			margin: "1px 5px 0 0"
		},
		".disagree-icon": {
			width: "15px",
			height: "15px",
			background: "url(../../image/default-icon-agree.png) no-repeat",
			backgroundSize: "35px 15px",
			margin: "1px 5px 0 0"
		},
		".rule_text": {fontSize: "12px", color: "#999"},
		".underscore": {borderBottom: "1px solid #999"}
	};
	apivm.define("login-main", LoginMain);

	var Login = /*@__PURE__*/ (function(Component) {
		function Login(props) {
			Component.call(this, props);
			this.data = {
				xiaomiPad: false
			};
		}

		if (Component) Login.__proto__ = Component;
		Login.prototype = Object.create(Component && Component.prototype);
		Login.prototype.constructor = Login;
		Login.prototype.apiready = function() {
			this.init();
		};
		Login.prototype.init = function() {
			var this$1 = this;

			api.addEventListener(
				{
					name: "viewappear"
				},
				function() {
					var screenWidth = api.screenWidth;
					var screenHeight = api.screenHeight;
					if (screenWidth - screenHeight > 0) {
						this$1.data.xiaomiPad = true;
					} else {
						this$1.data.xiaomiPad = false;
					}
				}
			);
		};
		Login.prototype.render = function() {
			return apivm.h(
				"view",
				{class: "page"},

				apivm.h(
					"view",
					{class: this.data.xiaomiPad ? "logo_MI" : "logo"},
					apivm.h("image", {
						class: this.data.xiaomiPad ? "logo_img_MI" : "logo_img",
						src: "../../image/logo.png"
					})
				),

				apivm.h("view", {class: "main"}, apivm.h("login-main", null))
			);
		};

		return Login;
	})(Component);
	Login.css = {
		".page": {
			height: "100vh",
			display: "flex",
			flexDirection: "column",
			justifyContent: "center"
		},
		".logo": {
			position: "relative",
			width: "100vw",
			height: "60vw",
			backgroundImage: 'url("../../image/default-login-header.png")',
			backgroundRepeat: "no-repeat",
			backgroundSize: "contain"
		},
		".logo_img": {
			position: "absolute",
			top: "5vw",
			left: "50%",
			transform: "translateX(-50%)",
			width: "20vw",
			height: "20vw",
			border: "1px solid #fff",
			borderRadius: "13%"
		},
		".logo_MI": {
			position: "relative",
			width: "62.5vw",
			height: "37.5vw",
			backgroundImage: 'url("../../image/default-login-header.png")',
			backgroundRepeat: "no-repeat",
			backgroundSize: "contain"
		},
		".logo_img_MI": {
			position: "absolute",
			top: "3vw",
			left: "25.25vw",
			transform: "translateX(0)",
			width: "12vw",
			height: "12vw",
			border: "1px solid #fff",
			borderRadius: "13%"
		},
		".main": {flex: "1"}
	};
	apivm.define("login", Login);
	apivm.render(apivm.h("login", null), "body");
})();
