(function() {
	/********************************************
	 *             系统和业务                   *
	 ******************************************/

	// 本地存储
	var storage = {
		set: function set(key, value) {
			api.setPrefs({
				key: key,
				value: typeof value === "string" ? value : JSON.stringify(value)
			});
		},

		get: function get(key) {
			var value = api.getPrefs({sync: true, key: key}) || "";

			try {
				return JSON.parse(value);
			} catch (e) {
				return value;
			}
		},

		del: function del(key) {
			api.removePrefs({key: key});
		}
	};

	// 获取用户信息（包括昵称、头像、个性签名等）
	function getUserInfo() {
		return storage.get("userInfo") || {};
	}

	/**
	 * 打开一个带导航的本地页面
	 * @param {String} name 标题
	 * @param {String} title 标题
	 * @param {String} url 网络地址
	 */
	function openNavStml(name, title, url) {
		api.openTabLayout({
			name: name,
			title: title,
			url: url,
			navigationBar: {}
		});
	}

	var Info = /*@__PURE__*/ (function(Component) {
		function Info(props) {
			Component.call(this, props);
			this.data = {
				userInfo: [
					{
						title: "头像",
						img: "",
						isLink: false
					},

					{
						title: "昵称",
						text: "",
						isLink: true,
						method: "editNickname"
					},

					{
						title: "学习账户",
						text: "",
						isLink: false
					},

					{
						title: "个性签名",
						text: "",
						isLink: true,
						method: "editSignature"
					},

					{
						title: "修改密码",
						isLink: true,
						method: "editPassword"
					},

					{
						title: "账号注销",
						isLink: true,
						method: "cancel"
					}
				]
			};
		}

		if (Component) Info.__proto__ = Component;
		Info.prototype = Object.create(Component && Component.prototype);
		Info.prototype.constructor = Info;
		Info.prototype.apiready = function() {
			var ref = getUserInfo();
			var nickname = ref.nickname;
			var info = ref.info;
			var phone = ref.phone;
			var avatarUrl = ref.avatarUrl;
			this.data.userInfo[0].img = avatarUrl;
			this.data.userInfo[1].text = nickname;
			this.data.userInfo[2].text = phone;
			this.data.userInfo[3].text = info;
		};
		Info.prototype.editNickname = function() {
			openNavStml("nickname", "修改昵称", "./nickname.stml");
		};
		Info.prototype.editSignature = function() {
			openNavStml("signature", "个性签名", "./signature.stml");
		};
		Info.prototype.editPassword = function() {
			openNavStml("password", "", "./password.stml");
		};
		Info.prototype.cancel = function() {
			openNavStml(
				"cancel",
				"账号注销",
				"https://vip.zhuokao360.com/app/terms/cancelAccount/cancel.html?app=2"
			);
		};
		Info.prototype.render = function() {
			return apivm.h(
				"view",
				{class: "info"},
				(Array.isArray(this.data.userInfo)
					? this.data.userInfo
					: Object.values(this.data.userInfo)
				).map(function(info) {
					return apivm.h(
						"view",
						{class: "info-item", onClick: info.method},
						apivm.h("text", null, info.title),
						apivm.h(
							"view",
							{class: "info-item-value"},
							info.img ? apivm.h("image", {class: "avatar_img", src: info.img}) : null,
							apivm.h("text", {class: "value_text"}, info.text),
							info.isLink
								? apivm.h("image", {
										class: "link_img",
										src: "../../image/default-icon-more.png"
								  })
								: null
						)
					);
				})
			);
		};

		return Info;
	})(Component);
	Info.css = {
		".info": {height: "100%"},
		".info-item": {
			display: "flex",
			flexDirection: "row",
			justifyContent: "space-between",
			alignItems: "center",
			padding: "15px",
			borderBottom: "1px solid rgba(51, 51, 51, 0.1)"
		},
		".info-item-value": {
			display: "flex",
			flexDirection: "row",
			alignItems: "center"
		},
		".avatar_img": {width: "64px", height: "64px"},
		".value_text": {fontSize: "15px", color: "#999999"},
		".link_img": {width: "7px", height: "13px", marginLeft: "8px"}
	};
	apivm.define("info", Info);
	apivm.render(apivm.h("info", null), "body");
})();
