(function() {
	/********************************************
	 *             系统和业务                   *
	 ******************************************/

	// 本地存储
	var storage = {
		set: function set(key, value) {
			api.setPrefs({
				key: key,
				value: typeof value === "string" ? value : JSON.stringify(value)
			});
		},

		get: function get(key) {
			var value = api.getPrefs({sync: true, key: key}) || "";

			try {
				return JSON.parse(value);
			} catch (e) {
				return value;
			}
		},

		del: function del(key) {
			api.removePrefs({key: key});
		}
	};

	// 获取登录状态
	function getLoginStatus() {
		return storage.get("isLogin") || false;
	}

	/**
	 * 设置登录状态
	 * @param {Boolean} status 登录状态
	 */
	function setLoginStatus(status) {
		storage.set("isLogin", !!status);
	}

	// 获取用户信息（包括昵称、头像、个性签名等）
	function getUserInfo() {
		return storage.get("userInfo") || {};
	}

	// 清空用户信息
	function clearUserInfo() {
		storage.del("token");
		storage.del("userInfo");
	}

	// 打开登录页面
	function openLogin() {
		api.openTabLayout({
			name: "login",
			url: "../login/login.stml",
			navigationBar: {
				background: "#5538de",
				shadow: "#5538de",
				color: "#fff"
			}
		});
	}

	// 保存上次登录的账号
	function saveLastLogin() {
		var _getUserInfo = getUserInfo(),
			phone = _getUserInfo.phone;
		storage.set("lastLogin", phone);
	}

	// 用户退出
	function exit() {
		setLoginStatus(false);
		saveLastLogin();
		clearUserInfo();

		closeToRoot();

		// 发送退出事件
		api.sendEvent({
			name: "exitStatus"
		});
	}

	/**
	 * 关闭到根页面
	 */
	function closeToRoot() {
		api.closeToWin({
			name: "root"
		});

		// 始终竖屏显示
		api.setScreenOrientation({
			orientation: "portrait_up"
		});
	}

	/**
	 * 格式化文件大小, 输出成带单位的字符串
	 * @param {Number} size 文件大小
	 */
	function formatFileSize(size) {
		var units = ["B", "K", "M", "G", "TB"];
		var fileSize = parseInt(size);
		for (var i = 0; fileSize >= 1024; i += 1) {
			fileSize /= 1024;
			units.shift();
		}
		return fileSize.toFixed(1) + units[0];
	}

	/**
	 * 打开一个带导航的本地页面
	 * @param {String} name 标题
	 * @param {String} title 标题
	 * @param {String} url 网络地址
	 */
	function openNavStml(name, title, url) {
		api.openTabLayout({
			name: name,
			title: title,
			url: url,
			navigationBar: {}
		});
	}

	function toast(msg) {
		api.toast({msg: msg});
	}

	var downloadManager = api.require("downloadManager");

	// 打开下载管理
	function openManagerView() {
		downloadManager.openManagerView(
			{
				title: "下载管理"
			},

			function(ret) {
				if (ret && ret.id) {
					// 点击某个下载完成项
					var mapId = getMap(ret.id);
					if (mapId) {
						openVideo(mapId);
					} else {
						openDownloadedFile(id);
					}
				}
			}
		);
	}

	// 打开下载文件
	function openDownloadedFile(id) {
		downloadManager.openDownloadedFile({id: id});
	}

	// 打开视频播放页
	function openVideo(videoId) {
		api.openWin({
			name: "video",
			url: "widget://pages/video/video.stml",
			slidBackEnabled: false,
			pageParam: {
				videoId: videoId
			}
		});
	}

	// 获取映射
	function getMap(downloadId) {
		var map = storage.get("downloadMap") || {};
		return downloadId ? map[downloadId] : map;
	}

	var My = /*@__PURE__*/ (function(Component) {
		function My(props) {
			Component.call(this, props);
			this.data = {
				isLogin: false,
				name: "未登录",
				intro: "您还没有登录，点击头像登录！",
				avatar: "../../image/default-avatar-unlogin.png",
				menuList: [
					{
						title: "个人资料",
						isLink: true,
						icon: "../../image/icon/my-info.png",
						method: "openUserInfo"
					},

					{
						title: "下载管理",
						isLink: true,
						icon: "../../image/icon/my-download.png",
						method: "openDownload"
					},

					{
						title: "关于我们",
						isLink: true,
						icon: "../../image/icon/my-about.png",
						method: "openAboutUs"
					},

					{
						title: "清除缓存",
						isLink: false,
						icon: "../../image/icon/my-cancel.png",
						text: "",
						method: "clearCache"
					},

					{
						title: "版本号",
						isLink: false,
						icon: "../../image/icon/my-version.png",
						text: ""
					}
				]
			};
		}

		if (Component) My.__proto__ = Component;
		My.prototype = Object.create(Component && Component.prototype);
		My.prototype.constructor = My;
		My.prototype.apiready = function() {
			this.initEventListenter(); // this.checkLoginStatus();
			this.getCacheSize();
			this.getAppVersion();
		};
		My.prototype.initEventListenter = function() {
			var this$1 = this;

			// 监听登录事件
			api.addEventListener(
				{
					name: "login"
				},
				function() {
					this$1.checkLoginStatus();
				}
			);

			// 监听更新用户信息事件
			api.addEventListener(
				{
					name: "updateUserInfo"
				},
				function() {
					var ref = getUserInfo();
					var nickname = ref.nickname;
					var info = ref.info;
					this$1.data.name = nickname;
					this$1.data.intro = info;
				}
			);

			// api.addEventListener({
			// 	name: 'loginExpired'
			// }, () => {
			// 	this.resetInfo();
			// 	api.alert({
			// 		msg: '登录已过期，请重新登录'
			// 	}, btzx.exit);
			// });

			api.addEventListener(
				{
					name: "exitStatus"
				},
				function() {
					this$1.resetInfo();
				}
			);
		};
		My.prototype.checkLoginStatus = function() {
			this.data.isLogin = getLoginStatus();
			if (this.data.isLogin) {
				var ref = getUserInfo();
				var nickname = ref.nickname;
				var info = ref.info;
				var avatarUrl = ref.avatarUrl;
				this.data.name = nickname;
				this.data.intro = info;
				this.data.avatar = avatarUrl;
			}
		};
		My.prototype.openLogin = function() {
			if (!this.data.isLogin) {
				openLogin();
			}
		};
		My.prototype.openUserInfo = function() {
			if (!this.data.isLogin) {
				toast("登录后才可以查看个人资料哦~");
			} else {
				openNavStml("info", "个人资料", "./info.stml");
			}
		};
		My.prototype.openDownload = function() {
			openManagerView();
		};
		My.prototype.openAboutUs = function() {
			openNavStml("about", "关于我们", "./about.stml");
		};
		My.prototype.clearCache = function() {
			var this$1 = this;

			api.confirm(
				{
					msg: "确定要清除APP缓存吗？",
					buttons: ["清除", "取消"]
				},

				function(ret) {
					if (ret.buttonIndex === 1) {
						api.clearCache(function() {
							toast("清除完成");
							this$1.getCacheSize();
						});
					}
				}
			);
		};
		My.prototype.logout = function() {
			this.resetInfo();
			exit();
		};
		My.prototype.resetInfo = function() {
			this.data.isLogin = false;
			this.data.name = "未登录";
			this.data.intro = "您还没有登录，点击头像登录！";
			this.data.avatar = "../../image/default-avatar-unlogin.png";
		};
		My.prototype.getCacheSize = function() {
			var this$1 = this;

			api.getCacheSize(function(ret) {
				this$1.data.menuList[3].text = formatFileSize(ret.size);
			});
		};
		My.prototype.getAppVersion = function() {
			this.data.menuList[4].text = api.appVersion;
		};
		My.prototype.render = function() {
			return apivm.h(
				"scroll-view",
				{class: "page", "show-scrollbar": false},

				apivm.h(
					"view",
					{class: "header"},
					apivm.h(
						"view",
						{class: "user-info"},
						apivm.h("text", {class: "nickname"}, this.data.name),
						apivm.h("text", {class: "intro"}, this.data.intro),
						apivm.h("image", {
							class: "user-avatar_image",
							src: this.data.avatar,
							onClick: this.openLogin
						})
					)
				),

				apivm.h(
					"view",
					{class: "list"},
					(Array.isArray(this.data.menuList)
						? this.data.menuList
						: Object.values(this.data.menuList)
					).map(function(menu) {
						return apivm.h(
							"view",
							{class: "menu-item", onClick: menu.method},
							apivm.h(
								"view",
								{class: "menu-item-title"},
								apivm.h("image", {class: "icon_img", src: menu.icon}),
								apivm.h("text", {class: "menu-title"}, menu.title)
							),
							menu.isLink
								? apivm.h("image", {
										class: "link_img",
										src: "../../image/default-icon-more.png"
								  })
								: apivm.h("text", {class: "menu_text"}, menu.text)
						);
					})
				),

				this.data.isLogin
					? apivm.h("text", {class: "logout", onClick: this.logout}, "退出")
					: null
			);
		};

		return My;
	})(Component);
	My.css = {
		".page": {
			display: "flex",
			flexDirection: "column",
			padding: "0 0 25px 0",
			backgroundColor: "#f5f5f5"
		},
		".header": {
			position: "relative",
			width: "100vw",
			height: "69vw",
			overflow: "hidden",
			background: "url(../../image/default-my-header.png) no-repeat",
			backgroundSize: "contain"
		},
		".user-info": {
			position: "absolute",
			left: "19%",
			bottom: "0",
			width: "52%",
			lineHeight: "1.5"
		},
		".nickname": {fontSize: "21px", color: "#fff", fontWeight: "bold"},
		".intro": {
			color: "#fff",
			fontSize: "12px",
			marginTop: "5px",
			minHeight: "36px"
		},
		".user-avatar_image": {
			marginTop: "5px",
			width: "22vw",
			height: "22vw",
			borderRadius: "50%"
		},
		".list": {
			display: "flex",
			flexDirection: "column",
			background: "#fff",
			borderRadius: "10px",
			padding: "0 15px",
			margin: "25px 15px 0"
		},
		".menu-item": {
			display: "flex",
			flexDirection: "row",
			justifyContent: "space-between",
			alignItems: "center",
			padding: "20px 0",
			borderBottom: "1px solid rgba(204, 204, 204, 0.2)"
		},
		".menu-item-title": {
			display: "flex",
			flexDirection: "row",
			alignItems: "center"
		},
		".icon_img": {width: "13px", height: "13px", marginRight: "7px"},
		".menu-title": {fontSize: "16px", color: "#333"},
		".link_img": {width: "7px", height: "13px"},
		".menu_text": {fontSize: "14px", color: "#666"},
		".logout": {
			margin: "15px auto",
			color: "#fff",
			backgroundColor: "#5538de",
			borderRadius: "30px",
			boxShadow: "2px 5px 8px rgba(85, 56, 222, 0.3)",
			padding: "10px 50px"
		}
	};
	apivm.define("my", My);
	apivm.render(apivm.h("my", null), "body");
})();
