(function() {
	var Loading = /*@__PURE__*/ (function(Component) {
		function Loading(props) {
			Component.call(this, props);
			this.data = {};
		}

		if (Component) Loading.__proto__ = Component;
		Loading.prototype = Object.create(Component && Component.prototype);
		Loading.prototype.constructor = Loading;
		Loading.prototype.apiready = function() {};
		Loading.prototype.render = function() {
			return apivm.h("image", {
				class: "" + (this.props.type ? "loading_" + this.props.type : "loading_"),
				src: "../../image/loading.gif"
			});
		};

		return Loading;
	})(Component);
	Loading.css = {
		".loading_": {
			width: "65px",
			height: "65px",
			position: "absolute",
			top: "43%",
			left: "50%",
			transform: "translateX(-25px)",
			zIndex: "99"
		},
		".loading_login": {
			width: "65px",
			height: "65px",
			position: "absolute",
			top: "17%",
			left: "50%",
			transform: "translateX(-25px)",
			zIndex: "99"
		}
	};
	apivm.define("loading", Loading);

	// api接口请求地址
	var BASEURL = "https://cbt.tibaitong.com/";

	/********************************************
	 *             系统和业务                   *
	 ******************************************/

	// 本地存储
	var storage = {
		set: function set(key, value) {
			api.setPrefs({
				key: key,
				value: typeof value === "string" ? value : JSON.stringify(value)
			});
		},

		get: function get(key) {
			var value = api.getPrefs({sync: true, key: key}) || "";

			try {
				return JSON.parse(value);
			} catch (e) {
				return value;
			}
		},

		del: function del(key) {
			api.removePrefs({key: key});
		}
	};

	// 请求
	function ajax(_ref) {
		var url = _ref.url,
			_ref$method = _ref.method,
			method = _ref$method === void 0 ? "get" : _ref$method,
			_ref$data = _ref.data,
			data = _ref$data === void 0 ? {} : _ref$data;
		return new Promise(function(resolve, reject) {
			api.ajax(
				{
					url: url.indexOf("http") === 0 ? url : BASEURL + url,
					method: method,
					headers: {
						"Content-Type": "application/json;charset=utf-8",
						"ZK-TOKEN": storage.get("token"),
						"APP-TYPE": 2
					},

					timeout: 60,
					data: {
						body: data
					}
				},

				function(ret, err) {
					if (ret) {
						if (ret.code === 200) {
							resolve(ret.data);
						} else if (ret.code === 600) {
							api.sendEvent({
								name: "loginExpired"
							});
						} else {
							api.toast({
								msg: ret.msg
							});
						}

						reject(ret);
					} else {
						api.toast({
							msg: "网络不畅,请检查网络"
						});

						reject(err);
					}
				}
			);
		});
	}

	/**
	 * 设置登录状态
	 * @param {Boolean} status 登录状态
	 */
	function setLoginStatus(status) {
		storage.set("isLogin", !!status);
	}

	// 获取用户信息（包括昵称、头像、个性签名等）
	function getUserInfo() {
		return storage.get("userInfo") || {};
	}

	// 清空用户信息
	function clearUserInfo() {
		storage.del("token");
		storage.del("userInfo");
	}

	// 保存上次登录的账号
	function saveLastLogin() {
		var _getUserInfo = getUserInfo(),
			phone = _getUserInfo.phone;
		storage.set("lastLogin", phone);
	}

	// 用户退出
	function exit() {
		setLoginStatus(false);
		saveLastLogin();
		clearUserInfo();

		closeToRoot();

		// 发送退出事件
		api.sendEvent({
			name: "exitStatus"
		});
	}

	/**
	 * 关闭到根页面
	 */
	function closeToRoot() {
		api.closeToWin({
			name: "root"
		});

		// 始终竖屏显示
		api.setScreenOrientation({
			orientation: "portrait_up"
		});
	}

	/**
	 * 校验手机号
	 * @param {Number} phone 手机号
	 */
	function validatorPhone(phone) {
		return /^1[3456789]\d{9}$/.test(phone);
	}

	function toast(msg) {
		api.toast({msg: msg});
	}

	/**
	 * 短信前置-获取图片验证码
	 * @param {String} phone 手机号码
	 */
	function getImageCode(phone) {
		return ajax({
			url: "sms/getImageCode",
			data: {
				phone: phone
			}
		});
	}

	/**
	 * 获取短信验证码
	 * @param {String} phone 手机号码
	 * @param {Number} imageCode 4位数字的图片验证码
	 */
	function sendSmscode(phone, imageCode) {
		return ajax({
			url: "sms/sendSms",
			method: "post",
			data: {
				phone: phone,
				imageCode: imageCode,
				type: 33
			}
		});
	}

	/**
	 * 修改密码
	 * @param {String} phone 手机号码
	 * @param {String} smsCode 短信验证码
	 * @param {String} newPwd 新密码
	 */
	function changePassword(phone, smsCode, newPwd) {
		return ajax({
			url: "user/updatePassword",
			method: "post",
			data: {
				phone: phone,
				smsCode: smsCode,
				newPwd: newPwd
			}
		});
	}

	var Tpl = /*@__PURE__*/ (function(Component) {
		function Tpl(props) {
			Component.call(this, props);
			this.data = {
				phone: null,
				code: null,
				newPwd: null, // 新密码
				newPwds: null, // 确认密码
				isSend: false,
				countdown: 60,
				logining: false
			};
		}

		if (Component) Tpl.__proto__ = Component;
		Tpl.prototype = Object.create(Component && Component.prototype);
		Tpl.prototype.constructor = Tpl;
		Tpl.prototype.apiready = function() {
			var ref = getUserInfo();
			var phone = ref.phone;
			this.data.phone = phone ? phone : null;
		};
		Tpl.prototype.getPhone = function(e) {
			this.data.phone = e.detail.value;
		};
		Tpl.prototype.getCode = function(e) {
			this.data.code = e.detail.value;
		};
		Tpl.prototype.getNewPwd = function(e) {
			this.data.newPwd = e.detail.value;
		};
		Tpl.prototype.getNewPwds = function(e) {
			this.data.newPwds = e.detail.value;
		};
		Tpl.prototype.onSubmit = function() {
			var this$1 = this;

			var ref = this.data;
			var phone = ref.phone;
			var code = ref.code;
			var newPwd = ref.newPwd;
			var newPwds = ref.newPwds;
			if (!phone || !code || !newPwd || !newPwds) {
				toast("请检查表单是否填写完整");
				return;
			}

			if (phone.length != 11) {
				toast("请输入正确的手机号码");
				return;
			}

			if (newPwd.length < 6 || newPwd.length > 16) {
				toast("请输入6~16的新密码");
				return;
			}

			if (newPwd !== newPwds) {
				toast("两次新密码输入不一致");
				return;
			}

			this.data.logining = true;
			changePassword(phone, code, newPwd)
				.then(function(res) {
					this$1.data.logining = false;
					toast("修改密码成功");
					setTimeout(function() {
						exit();
					}, 1000);
				})
				.catch(function(err) {
					this$1.data.logining = false;
				});
		};
		Tpl.prototype.requireCode = function() {
			var this$1 = this;

			if (!validatorPhone(this.data.phone)) {
				toast("请填写正确的手机号");
				return;
			}

			getImageCode(this.data.phone)
				.then(function(res) {
					var imageCode = res.imageCode;
					if (imageCode) {
						sendSmscode(this$1.data.phone, imageCode).then(function() {
							this$1.codeLastTime();
							toast("发送成功！");
						});
						return;
					}
					return Promise.reject();
				})
				.catch(function(err) {
					toast("发送失败");
				});
		};
		Tpl.prototype.codeLastTime = function() {
			var this$1 = this;

			this.data.isSend = true;

			var timer = setInterval(function() {
				if (this$1.data.countdown > 0) {
					this$1.data.countdown -= 1;
				} else {
					clearInterval(timer);
					this$1.data.countdown = 60;
					this$1.data.isSend = false;
				}
			}, 1000);
		};
		Tpl.prototype.render = function() {
			return apivm.h(
				"view",
				{class: "page"},

				apivm.h("text", {class: "title"}, "修改密码"),

				apivm.h(
					"view",
					{class: "login"},
					this.data.logining
						? apivm.h("loading", {class: "loading", type: "login"})
						: null,

					apivm.h(
						"view",
						{class: "login-msg"},
						apivm.h("text", {class: "login-title"}, "手机号"),
						apivm.h(
							"view",
							{class: "login-input"},
							apivm.h("input", {
								class: "login-input_del input",
								placeholder: "请输入手机号",
								onInput: this.getPhone,
								value: this.data.phone
							})
						)
					),

					apivm.h(
						"view",
						{class: "login-msg"},
						apivm.h("text", {class: "login-title"}, "短信验证码"),
						apivm.h(
							"view",
							{class: "login-input"},
							apivm.h("input", {
								class: "login-input_del input",
								placeholder: "请输入验证码",
								"keyboard-type": "number",
								onInput: this.getCode,
								value: this.data.code
							}),
							apivm.h(
								"view",
								{class: "login-input-sms"},
								apivm.h("view", {class: "getCode_line"}),
								!this.data.isSend
									? apivm.h(
											"text",
											{class: "login-getCode", onClick: this.requireCode},
											"发送验证码"
									  )
									: apivm.h(
											"text",
											{class: "login-gotCode"},
											"重新获取(",
											this.data.countdown,
											")"
									  )
							)
						)
					),

					apivm.h(
						"view",
						{class: "login-msg"},
						apivm.h("text", {class: "login-title"}, "新密码"),
						apivm.h(
							"view",
							{class: "login-input"},
							apivm.h("input", {
								class: "login-input_del input",
								type: "password",
								placeholder: "请输入新密码",
								onInput: this.getNewPwd,
								value: this.data.newPwd
							})
						)
					),

					apivm.h(
						"view",
						{class: "login-msg"},
						apivm.h("text", {class: "login-title"}, "确认密码"),
						apivm.h(
							"view",
							{class: "login-input"},
							apivm.h("input", {
								class: "login-input_del input",
								type: "password",
								placeholder: "请再次确认密码",
								onInput: this.getNewPwds,
								value: this.data.newPwds
							})
						)
					),

					apivm.h("text", {class: "login-btn", onClick: this.onSubmit}, "确认修改")
				)
			);
		};

		return Tpl;
	})(Component);
	Tpl.css = {
		".page": {
			display: "flex",
			flexDirection: "column",
			height: "100%",
			padding: "0 20px 40px 20px",
			boxSizing: "border-box"
		},
		".title": {
			lineHeight: "44px",
			fontSize: "23px",
			fontWeight: "bold",
			color: "#333",
			marginTop: "10px"
		},
		".input": {height: "20px", background: "none", border: "none"},
		".loading": {position: "absolute", top: "0"},
		".login": {flex: "1"},
		".login-classify": {
			display: "flex",
			flexDirection: "row",
			marginBottom: "15px"
		},
		".login_classify_text": {fontSize: "16px", color: "#666"},
		".classify_text-active": {
			fontSize: "16px",
			fontWeight: "bold",
			color: "#333"
		},
		".login-classify_view": {flexDirection: "row"},
		".classify_line": {
			width: "1px",
			height: "12px",
			background: "#999",
			margin: "5.5px 15px"
		},
		".login-msg": {display: "flex", flexDirection: "column", marginTop: "25px"},
		".login-title": {fontSize: "12px", color: "#999"},
		".login-input": {
			flexDirection: "row",
			padding: "14.5px 0 14.5px 15px",
			boxSizing: "border-box",
			background: "#f8f8f8",
			border: "1px solid #eee",
			borderRadius: "5px",
			marginTop: "5px"
		},
		".login-input_icon": {
			width: "16px",
			height: "16px",
			background: "url(../../image/default-icon-function.png) no-repeat",
			backgroundSize: "121px 16px",
			marginTop: "2.5px",
			marginRight: "10px"
		},
		".login-input_del": {flex: "1"},
		".login-input-sms": {flexDirection: "row"},
		".getCode_line": {
			width: "1px",
			height: "12px",
			background: "#999",
			margin: "4px 0"
		},
		".login-getCode": {
			width: "93px",
			padding: "1px 0 1px 10px",
			boxSizing: "border-box",
			fontSize: "12px",
			color: "#5538de"
		},
		".login-gotCode": {
			width: "96px",
			padding: "1px 5px 1px 10px",
			boxSizing: "border-box",
			fontSize: "12px",
			color: "#999"
		},
		".login-btn": {
			borderRadius: "5px",
			backgroundColor: "#5538de",
			padding: "12px 0",
			textAlign: "center",
			fontSize: "15px",
			color: "#fff",
			margin: "25px 0 15px"
		},
		".login-des": {textAlign: "center", fontSize: "12px", color: "#666"},
		".icon_code": {backgroundPosition: "-20px 0"}
	};
	apivm.define("tpl", Tpl);
	apivm.render(apivm.h("tpl", null), "body");
})();
