(function() {
	var Loading = /*@__PURE__*/ (function(Component) {
		function Loading(props) {
			Component.call(this, props);
			this.data = {};
		}

		if (Component) Loading.__proto__ = Component;
		Loading.prototype = Object.create(Component && Component.prototype);
		Loading.prototype.constructor = Loading;
		Loading.prototype.apiready = function() {};
		Loading.prototype.render = function() {
			return apivm.h("image", {
				class: "" + (this.props.type ? "loading_" + this.props.type : "loading_"),
				src: "../../image/loading.gif"
			});
		};

		return Loading;
	})(Component);
	Loading.css = {
		".loading_": {
			width: "65px",
			height: "65px",
			position: "absolute",
			top: "43%",
			left: "50%",
			transform: "translateX(-25px)",
			zIndex: "99"
		},
		".loading_login": {
			width: "65px",
			height: "65px",
			position: "absolute",
			top: "17%",
			left: "50%",
			transform: "translateX(-25px)",
			zIndex: "99"
		}
	};
	apivm.define("loading", Loading);

	/*
	 * iap 模块封装了 iOS 系统应用内购买相关功能
	 */

	var IAP = {
		module: null, // 模块

		// 初始化
		init: function init() {
			this.module = api.require("iap"); // 引入模块
		},

		/**
		 * 获取有效商品列表
		 * @param {Array} productIds 商品id列表
		 */
		getProducts: function getProducts(productIds) {
			var _this = this;
			return new Promise(function(resolve, reject) {
				_this.module.getProducts(
					{
						productIds: productIds
					},
					function(ret, err) {
						if (ret) {
							resolve(ret.products);
						}
						reject(err);
					}
				);
			});
		},

		/**
		 * 购买商品
		 * @param {String} productId 有效的商品id
		 * @param {String} applicationUsername 用户信息
		 * @param {Function} callback 回调函数
		 */
		purchase: function purchase(productId, applicationUsername, callback) {
			this.module.purchase(
				{
					productId: productId,
					applicationUsername: applicationUsername
				},

				callback
			);
		},

		/**
		 * 完成指定交易，在完成购买并提供给用户相关功能后应该完成此次交易。
		 * @param {String} transactionId 交易id
		 */
		finishTransaction: function finishTransaction(transactionId) {
			this.module.finishTransaction({
				transactionId: transactionId
			});
		},

		/**
		 * 恢复用户以前购买过的所有商品交易
		 * @param {String} applicationUsername 用户信息
		 * @param {Function} callback 回调函数
		 */
		restoreTransactions: function restoreTransactions(
			applicationUsername,
			callback
		) {
			this.module.restoreTransactions(applicationUsername, callback);
		}
	};

	// api接口请求地址
	var BASEURL = "https://cbt.tibaitong.com/";

	/********************************************
	 *             系统和业务                   *
	 ******************************************/

	// 本地存储
	var storage = {
		set: function set(key, value) {
			api.setPrefs({
				key: key,
				value: typeof value === "string" ? value : JSON.stringify(value)
			});
		},

		get: function get(key) {
			var value = api.getPrefs({sync: true, key: key}) || "";

			try {
				return JSON.parse(value);
			} catch (e) {
				return value;
			}
		},

		del: function del(key) {
			api.removePrefs({key: key});
		}
	};

	// 请求
	function ajax(_ref) {
		var url = _ref.url,
			_ref$method = _ref.method,
			method = _ref$method === void 0 ? "get" : _ref$method,
			_ref$data = _ref.data,
			data = _ref$data === void 0 ? {} : _ref$data;
		return new Promise(function(resolve, reject) {
			api.ajax(
				{
					url: url.indexOf("http") === 0 ? url : BASEURL + url,
					method: method,
					headers: {
						"Content-Type": "application/json;charset=utf-8",
						"ZK-TOKEN": storage.get("token"),
						"APP-TYPE": 2
					},

					timeout: 60,
					data: {
						body: data
					}
				},

				function(ret, err) {
					if (ret) {
						if (ret.code === 200) {
							resolve(ret.data);
						} else if (ret.code === 600) {
							api.sendEvent({
								name: "loginExpired"
							});
						} else {
							api.toast({
								msg: ret.msg
							});
						}

						reject(ret);
					} else {
						api.toast({
							msg: "网络不畅,请检查网络"
						});

						reject(err);
					}
				}
			);
		});
	}

	// 获取用户信息（包括昵称、头像、个性签名等）
	function getUserInfo() {
		return storage.get("userInfo") || {};
	}

	// 打开登录页面
	function openLogin() {
		api.openTabLayout({
			name: "login",
			url: "../login/login.stml",
			navigationBar: {
				background: "#5538de",
				shadow: "#5538de",
				color: "#fff"
			}
		});
	}

	function toast(msg) {
		api.toast({msg: msg});
	}

	/**
	 * 自动登录
	 */
	function autoLogin() {
		return ajax({
			url: "login/autoLogin"
		});
	}

	/**
	 * 账户密码登录
	 * @param {String} phone 手机号
	 * @param {String} password 密码
	 */
	function login(phone, password) {
		return ajax({
			url: "login/login",
			method: "post",
			data: {
				phone: phone,
				password: password
			}
		});
	}

	/**
	 * 短信前置-获取图片验证码
	 * @param {String} phone 手机号码
	 */
	function getImageCode(phone) {
		return ajax({
			url: "sms/getImageCode",
			data: {
				phone: phone
			}
		});
	}

	/**
	 * 获取短信验证码
	 * @param {String} phone 手机号码
	 * @param {Number} imageCode 4位数字的图片验证码
	 */
	function sendSmscode(phone, imageCode) {
		return ajax({
			url: "sms/sendSms",
			method: "post",
			data: {
				phone: phone,
				imageCode: imageCode,
				type: 33
			}
		});
	}

	/**
	 * 短信验证码登录
	 * @param {String} phone 手机号码
	 * @param {Number} smscode 6位数字的短信验证码
	 */
	function smscodeLogin(phone, smscode) {
		return ajax({
			url: "login/sms",
			method: "post",
			data: {
				phone: phone,
				smsCode: smscode,
				type: 33
			}
		});
	}

	/**
	 * 修改昵称
	 * @param {String} nick 要修改的昵称
	 */
	function changeNick(nick) {
		return ajax({
			url: "user/changeNick",
			method: "post",
			data: {
				nick: nick
			}
		});
	}

	/**
	 * 修改个性签名
	 * @param {String} signature 要修改的签名
	 */
	function changeSignature(signature) {
		return ajax({
			url: "user/changeSignature",
			method: "post",
			data: {
				signature: signature
			}
		});
	}

	/**
	 * 修改密码
	 * @param {String} phone 手机号码
	 * @param {String} smsCode 短信验证码
	 * @param {String} newPwd 新密码
	 */
	function changePassword(phone, smsCode, newPwd) {
		return ajax({
			url: "user/updatePassword",
			method: "post",
			data: {
				phone: phone,
				smsCode: smsCode,
				newPwd: newPwd
			}
		});
	}

	/************************************************
	 *                   课程接口                    *
	 ***********************************************/

	/**
	 * 获取所有职称课程映射表
	 */
	function getProfession() {
		return ajax({
			url: "course/getUserProfession"
		});
	}

	/**
	 * 获取首页公告提示
	 */
	function getNotice(type, professionId) {
		return ajax({
			url: "notice/findNotice/" + type + "/" + professionId
		});
	}

	/**
	 * 获取视频播放历史记录
	 */
	function getHistoryVideo() {
		return ajax({
			url: "course/getNewSummary"
		});
	}

	/**
	 * 获取所有课程
	 */
	function getFreeCourse() {
		return ajax({
			url: "course/findAllCourseAuth"
		});
	}

	/**
	 * 获取课程列表
	 */
	function getCourseList() {
		return ajax({
			url: "course/findCourseAuth"
		});
	}

	/**
	 * 获取课程学习进度
	 * @param {Number} courseId 课程id
	 * @param {Number} type 课程类型
	 */
	function getCourseProgress(courseId, type) {
		if (type === void 0) {
			type = 1;
		}
		return ajax({
			url: "courseStage/getCourseLearnInfo",
			data: {
				courseId: courseId,
				type: type
			}
		});
	}

	/**
	 * 获取课时列表
	 * @param {Number} courseId 课程id
	 * @param {Number} type 课程类型
	 */
	function getLessonList(courseId, type) {
		if (type === void 0) {
			type = 1;
		}
		return ajax({
			// url: 'courseStage/findCourseStageByType',
			url: "courseStage/findNewCourseStageType",
			data: {
				courseId: courseId,
				type: type
			}
		});
	}

	/**
	 * 获取真题列表
	 * @param {Number} courseId 课程id
	 */
	function getQuestionList(courseId) {
		return ajax({
			url: "section/findSectionBy",
			data: {
				courseId: courseId,
				sectionType: 8
			}
		});
	}

	/**
	 * 是否有资料
	 * @param {Number} courseId 课程id
	 * @param {Number} type 课程类型
	 */
	function isHasFile(courseId) {
		return ajax({
			url: "videoHandout/isHas",
			data: {
				courseId: courseId,
				type: 12
			}
		});
	}

	/**
	 * 获取资料列表，读取讲义表
	 * @param {Number} courseId 课程id
	 */
	function getHandoutList(courseId, type) {
		return ajax({
			url: "videoHandout/findVideoHandout",
			data: {
				courseId: courseId,
				type: type
			}
		});
	}

	/**
	 * 获取某一课时信息
	 * @param {Number} courseStageId 课时id
	 */
	function getCourseDetail(courseStageId) {
		return ajax({
			url: "courseStage/getStageVideo",
			data: {
				courseStageId: courseStageId
			}
		});
	}

	/**
	 * 获取视频详细信息(未登录)
	 * @param {Number} videoId 视频id
	 */
	function getVideoDetailNo(videoId) {
		return ajax({
			url: "videoPlus/getVideo",
			data: {
				videoId: videoId
			}
		});
	}

	/**
	 * 获取视频详细信息
	 * @param {Number} videoId 视频id
	 */
	function getVideoDetail(videoId) {
		return ajax({
			url: "video/getDetail",
			data: {
				videoId: videoId,
				appType: 4,
				edition: "v1_0_14"
			}
		});
	}

	/**
	 * 获取加密视频信息（暂未启用）
	 * @param {Number} videoId 视频id
	 * @param {String} channelFlag 访问来源
	 * @param {String} resourcesFlag 资源种类
	 */
	function getVideoInfoByAuth(videoId) {
		return ajax({
			url: "videoPlus/getPlayInfo",
			data: {
				videoId: videoId,
				channelFlag: 1,
				resourcesFlag: 1
			}
		});
	}

	/**
	 * 获取视频讲义
	 * @param {Number} videoId 视频id
	 */
	function getVideoHandout(videoId) {
		return ajax({
			url: "courseStage/getVideoHandoutByVideoId",
			data: {
				videoId: videoId
			}
		});
	}

	/**
	 * 保存用户观看视频进度
	 * @param {Number} videoId 视频id
	 * @param {Number} watchDuration 视频观看时长
	 */
	function saveVideoProgress(videoId, watchDuration) {
		return ajax({
			url: "video/updateWatched",
			method: "post",
			data: {
				videoId: videoId,
				watchDuration: watchDuration
			}
		});
	}

	/**
	 * 记录用户讲义下载记录
	 * @param {Number} courseId 课程id
	 * @param {Number} handoutId 讲义id
	 */
	function saveUserHandout(handoutId, courseId) {
		return ajax({
			url: "/videoHandout/saveUserHandout",
			method: "post",
			data: {
				handoutId: handoutId,
				courseId: courseId
			}
		});
	}

	/**
	 * 记录用户视频下载记录
	 * @param {Number} courseId 课程id
	 * @param {Number} handoutId 讲义id
	 */
	function saveUserVideo(courseId, videoId) {
		return ajax({
			url: "/videoPlus/saveUserVideo",
			method: "post",
			data: {
				videoId: videoId,
				courseId: courseId
			}
		});
	}

	/**
	 * 获取反馈与回答集合
	 */
	function getFeedbackList() {
		return ajax({
			url: "/recordFeedback/list",
			method: "get",
			data: {}
		});
	}

	/**
	 * 修改已读状态
	 * @param {Number} replyId 回复id
	 */
	function updateFeedbackRead(replyId) {
		return ajax({
			url: "/recordFeedback/updateRead/" + replyId,
			method: "post",
			data: {}
		});
	}

	var btzxAPI = /*#__PURE__*/ Object.freeze({
		__proto__: null,
		autoLogin: autoLogin,
		login: login,
		getImageCode: getImageCode,
		sendSmscode: sendSmscode,
		smscodeLogin: smscodeLogin,
		changeNick: changeNick,
		changeSignature: changeSignature,
		changePassword: changePassword,
		getProfession: getProfession,
		getNotice: getNotice,
		getHistoryVideo: getHistoryVideo,
		getFreeCourse: getFreeCourse,
		getCourseList: getCourseList,
		getLessonList: getLessonList,
		getCourseProgress: getCourseProgress,
		getQuestionList: getQuestionList,
		isHasFile: isHasFile,
		getHandoutList: getHandoutList,
		getCourseDetail: getCourseDetail,
		getVideoDetailNo: getVideoDetailNo,
		getVideoDetail: getVideoDetail,
		getVideoInfoByAuth: getVideoInfoByAuth,
		getVideoHandout: getVideoHandout,
		saveVideoProgress: saveVideoProgress,
		saveUserHandout: saveUserHandout,
		saveUserVideo: saveUserVideo,
		getFeedbackList: getFeedbackList,
		updateFeedbackRead: updateFeedbackRead
	});

	var Tpl = /*@__PURE__*/ (function(Component) {
		function Tpl(props) {
			Component.call(this, props);
			this.data = {
				errMsg: {
					0: "未知错误",
					1: "无效请求",
					2: "用户取消购买",
					3: "交易无效",
					4: "设备不允许进行交易",
					5: "不是有效商品"
				},

				courseList: [],
				dataFinish: false
			};
		}

		if (Component) Tpl.__proto__ = Component;
		Tpl.prototype = Object.create(Component && Component.prototype);
		Tpl.prototype.constructor = Tpl;
		Tpl.prototype.apiready = function() {
			var this$1 = this;
			IAP.init();
			IAP.getProducts(["btzx21", "btzx22", "btzx28"]).then(function(res) {
				this$1.data.dataFinish = true;
				toast("获取课程成功");
				res.forEach(function(item) {
					console.log(JSON.stringify(res));
					this$1.data.courseList.push({
						id: item.productId,
						title: item.title,
						thumb:
							"https://files.zhuokao360.com/mall/banner/" +
							item.productId.match(/\d+/g) +
							".png",
						price: item.price
					});
				});
			});
		};
		Tpl.prototype.onPurchase = function(productId) {
			var this$1 = this;

			api.confirm(
				{
					title: "购买课程",
					msg: "登录账号购买，可跨平台享受课程权益。直接购买，会为当前设备开通课程",
					buttons: ["登录购买", "游客身份购买", "取消"]
				},
				function(ret) {
					var index = ret.buttonIndex;
					if (index === 1) {
						openLogin();
					} else if (index === 2) {
						this$1.purchase(productId);
					}
				}
			);
			return;
		};
		Tpl.prototype.purchase = function(productId) {
			var this$1 = this;

			var userId = getUserInfo().userId || "23766";
			IAP.purchase(productId, userId, function(res) {
				console.log(JSON.stringify("res:" + JSON.stringify(res)));
				if (res.state === 1) {
					api.alert({
						msg: "支付成功"
					});

					this$1.checkOrderStatus(res);
				} else if (res.state === 2) {
					api.alert({
						msg: this$1.data.errMsg[res.errorCode]
					});
				}
			});
		};
		Tpl.prototype.checkOrderStatus = function(order) {
			undefined({
				method: "post",
				url: "https://cj.tibaitong.com/api/main/iospay",
				data: {
					uid: order.applicationUsername,
					payload: order.receipt,
					transactionId: order.transactionId,
					pid: order.productId
				}
			})
				.then(function() {
					api.alert({
						msg: "开课成功，请退出重新登录"
					});

					IAP.finishTransaction(order.transactionId);
				})
				.catch(function(err) {
					console.log(JSON.stringify(err));
				});
		};
		Tpl.prototype.render = function() {
			var this$1 = this;
			return apivm.h(
				"view",
				{class: "page"},
				!this.data.dataFinish ? apivm.h("loading", null) : null,

				(Array.isArray(this.data.courseList)
					? this.data.courseList
					: Object.values(this.data.courseList)
				).map(function(item$1) {
					return apivm.h(
						"view",
						{
							class: "course-item",
							onClick: function() {
								return this$1.onPurchase(item$1.id);
							}
						},
						apivm.h("image", {class: "course-item-img", src: item$1.thumb}),
						apivm.h(
							"view",
							{class: "course-item-des"},
							apivm.h("text", {class: "course-item-name"}, item$1.title),
							apivm.h(
								"view",
								{class: "course-item-price"},
								apivm.h("text", {class: "price"}, "￥", item$1.price),
								apivm.h("text", {class: "count"}, "x1")
							)
						)
					);
				})
			);
		};

		return Tpl;
	})(Component);
	Tpl.css = {
		".page": {height: "100%", padding: "10px 0"},
		".course-item": {
			flexDirection: "row",
			width: "100%",
			backgroundColor: "rgba(200, 200, 200, 0.1)",
			padding: "5px 15px",
			marginTop: "10px"
		},
		".course-item-img": {
			width: "80px",
			height: "80px",
			borderRadius: "10px",
			marginRight: "10px"
		},
		".course-item-des": {flex: "1", justifyContent: "space-between"},
		".course-item-name": {fontSize: "12px", fontWeight: "bold", color: "#333"},
		".course-item-price": {
			flexDirection: "row",
			justifyContent: "space-between",
			alignItems: "center"
		},
		".price": {fontSize: "15px", fontWeight: "bold", color: "#333"},
		".count": {fontSize: "12px", color: "#666"}
	};
	apivm.define("tpl", Tpl);
	apivm.render(apivm.h("tpl", null), "body");
})();
