(function() {
	// api接口请求地址
	var BASEURL = "https://cbt.tibaitong.com/";

	/********************************************
	 *             系统和业务                   *
	 ******************************************/

	// 本地存储
	var storage = {
		set: function set(key, value) {
			api.setPrefs({
				key: key,
				value: typeof value === "string" ? value : JSON.stringify(value)
			});
		},

		get: function get(key) {
			var value = api.getPrefs({sync: true, key: key}) || "";

			try {
				return JSON.parse(value);
			} catch (e) {
				return value;
			}
		},

		del: function del(key) {
			api.removePrefs({key: key});
		}
	};

	// 请求
	function ajax(_ref) {
		var url = _ref.url,
			_ref$method = _ref.method,
			method = _ref$method === void 0 ? "get" : _ref$method,
			_ref$data = _ref.data,
			data = _ref$data === void 0 ? {} : _ref$data;
		return new Promise(function(resolve, reject) {
			api.ajax(
				{
					url: url.indexOf("http") === 0 ? url : BASEURL + url,
					method: method,
					headers: {
						"Content-Type": "application/json;charset=utf-8",
						"ZK-TOKEN": storage.get("token"),
						"APP-TYPE": 2
					},

					timeout: 60,
					data: {
						body: data
					}
				},

				function(ret, err) {
					if (ret) {
						if (ret.code === 200) {
							resolve(ret.data);
						} else if (ret.code === 600) {
							api.sendEvent({
								name: "loginExpired"
							});
						} else {
							api.toast({
								msg: ret.msg
							});
						}

						reject(ret);
					} else {
						api.toast({
							msg: "网络不畅,请检查网络"
						});

						reject(err);
					}
				}
			);
		});
	}

	/**
	 * 关闭窗口
	 * @param {String} name window 名字
	 * @param {Number} timeout 延迟时间
	 */
	function closeWin(_temp) {
		var _ref3 = _temp === void 0 ? {} : _temp,
			name = _ref3.name,
			timeout = _ref3.timeout;
		function close() {
			if (typeof name === "string") {
				api.closeWin({name: name});
			} else {
				api.closeWin();
			}
		}

		if (typeof timeout === "number") {
			setTimeout(close, timeout);
		} else {
			close();
		}
	}

	function toast(msg) {
		api.toast({msg: msg});
	}

	/**
	 * 修改个性签名
	 * @param {String} signature 要修改的签名
	 */
	function changeSignature(signature) {
		return ajax({
			url: "user/changeSignature",
			method: "post",
			data: {
				signature: signature
			}
		});
	}

	var Signature = /*@__PURE__*/ (function(Component) {
		function Signature(props) {
			Component.call(this, props);
			this.data = {
				signature: ""
			};
		}

		if (Component) Signature.__proto__ = Component;
		Signature.prototype = Object.create(Component && Component.prototype);
		Signature.prototype.constructor = Signature;
		Signature.prototype.getSignature = function(e) {
			this.data.signature = e.detail.value;
		};
		Signature.prototype.submit = function() {
			var signature = this.data.signature.trim();

			if (!signature) {
				toast("个性签名不能为空");
				return;
			}

			changeSignature(signature).then(function(res) {
				toast("修改成功");
				closeWin({timeout: 1000});
			});
		};
		Signature.prototype.render = function() {
			return apivm.h(
				"view",
				{class: "signature"},
				apivm.h("input", {
					class: "input",
					type: "text",
					placeholder: "请输入个性签名",
					maxlength: 50,
					onInput: this.getSignature
				}),
				apivm.h("text", {class: "signature-submit", onClick: this.submit}, "提交")
			);
		};

		return Signature;
	})(Component);
	Signature.css = {
		".signature": {padding: "20px 15px"},
		".input": {
			width: "100%",
			height: "30px",
			background: "none",
			border: "none",
			borderBottom: "1px solid #999999"
		},
		".signature-submit": {
			alignSelf: "flex-end",
			width: "53px",
			padding: "10px",
			backgroundColor: "#5538de",
			borderRadius: "2px",
			fontSize: "16px",
			color: "#ffffff",
			marginTop: "15px"
		}
	};
	apivm.define("signature", Signature);
	apivm.render(apivm.h("signature", null), "body");
})();
