(function() {
	// api接口请求地址
	var BASEURL = "https://cbt.tibaitong.com/";

	// 请求权限名字
	var PERMISSIONNAME = {
		camera: "相机", // 相机/拍照/录像
		photos: "访问相册", // 访问相册|本地存储空间。Android上等同storage权限
		phone: "电话", // 直接拨打电话/获取手机号码|IMEI。只支持Android
		storage: "存储", // 读取/写入|相册|多媒体|本地存储空间。只支持Android
		"phone-r": "设备信息"
	};

	// 本地存储
	var storage = {
		set: function set(key, value) {
			api.setPrefs({
				key: key,
				value: typeof value === "string" ? value : JSON.stringify(value)
			});
		},

		get: function get(key) {
			var value = api.getPrefs({sync: true, key: key}) || "";

			// 如果JSON字符串无法解析，直接返回
			try {
				return JSON.parse(value);
			} catch (e) {
				return value;
			}
		},

		del: function del(key) {
			api.removePrefs({key: key});
		}
	};

	// 请求
	function ajax(_ref) {
		var url = _ref.url,
			_ref$method = _ref.method,
			method = _ref$method === void 0 ? "get" : _ref$method,
			_ref$data = _ref.data,
			data = _ref$data === void 0 ? {} : _ref$data;
		return new Promise(function(resolve, reject) {
			api.ajax(
				{
					url: url.indexOf("http") === 0 ? url : BASEURL + url,
					method: method,
					headers: {
						"Content-Type": "application/json;charset=utf-8",
						"ZK-TOKEN": storage.get("token"),
						"APP-TYPE": 2
					},

					timeout: 60,
					data: {
						body: data
					}
				},

				function(ret, err) {
					if (ret) {
						if (ret.code === 200) {
							resolve(ret.data);
						} else if (ret.code === 600) {
							// 发送用户登录过期事件
							api.sendEvent({
								name: "loginExpired"
							});
						} else {
							api.toast({
								msg: ret.msg
							});
						}

						reject(ret);
					} else {
						api.toast({
							msg: "网络不畅,请检查网络"
						});

						reject(err);
					}
				}
			);
		});
	}

	/**
	 * 判断是否拥有权限
	 * @param {Array} perms 权限列表
	 */
	function hasPermission(perms) {
		var resultList = api.hasPermission({
			list: perms
		});

		return resultList;
	}

	/**
	 * 向系统请求权限
	 * @param {Array} perms 权限列表
	 */
	function requestPermission(perms) {
		api.requestPermission({
			list: perms,
			code: 1
		});
	}

	/**
	 * 确认权限(无权限提示获取)
	 * @param {Array} perms 权限列表
	 */
	function confirmPermission(perms) {
		var resultList = hasPermission(perms);

		// 获取需要请求的权限列表
		var requestList = [];
		resultList.forEach(function(item, index) {
			if (!item || !item.granted) {
				requestList.push(perms[index]);
			}
		});

		// 如果拥有全部权限
		if (requestList.length === 0) {
			return true;
		}

		// 否则，提示请求权限
		var str = "";
		requestList.forEach(function(per) {
			str += PERMISSIONNAME[per] + "\u3001";
		});
		str = str.slice(0, str.length - 1);

		api.confirm(
			{
				title: "提醒",
				msg:
					"\u4F7F\u7528\u76F8\u5173\u529F\u80FD\uFF0C\u9700\u8981\u83B7\u53D6 " +
					str +
					" \u6743\u9650\n\u662F\u5426\u524D\u5F80\u8BBE\u7F6E\uFF1F",
				buttons: ["去设置", "取消"]
			},

			function(ret) {
				if (ret.buttonIndex === 1) {
					requestPermission(perms);
				}
			}
		);

		return false;
	}

	/**
	 * 格式化文件大小, 输出成带单位的字符串
	 * @param {Number} size 文件大小
	 */
	function formatFileSize(size) {
		var units = ["B", "K", "M", "G", "TB"];
		var fileSize = parseInt(size);
		for (var i = 0; fileSize >= 1024; i += 1) {
			fileSize /= 1024;
			units.shift();
		}
		return fileSize.toFixed(1) + units[0];
	}

	/**
	 * 浏览器打开
	 * @param {String} url 需要打开的地址
	 */
	function openBrowser(url) {
		api.openApp({
			androidPkg: "android.intent.action.VIEW",
			uri: url,
			iosUrl: url
		});
	}

	// 获取当前网络状态
	function getNetworkStatus() {
		return api.connectionType !== "none";
	}

	function toast(msg) {
		api.toast({
			msg: msg
		});
	}

	var downloadManager = api.require("downloadManager");

	// 根据映射的ID查询下载项
	function queryById(id) {
		var map = getMap();
		var downloadId = Object.keys(map).find(function(item) {
			return map[item] === id;
		});

		if (!downloadId) {
			return Promise.resolve();
		}

		return new Promise(function(resolve, reject) {
			downloadManager.query(
				{
					ids: [downloadId]
				},
				function(ret, err) {
					if (ret) {
						if (ret.data && ret.data.length) {
							resolve(ret.data[0]);
						} else {
							delMap(downloadId);
							resolve();
						}
					} else {
						reject(err);
					}
				}
			);
		});
	}

	// 获取映射
	function getMap(downloadId) {
		var map = storage.get("downloadMap") || {};
		return downloadId ? map[downloadId] : map;
	}

	// 保存映射
	function setMap(map) {
		return storage.set("downloadMap", map);
	}

	// 添加映射
	function addMap(downloadId, id) {
		var map = getMap();
		map[downloadId] = id;
		setMap(map);
	}

	// 删除某一映射
	function delMap(downloadId) {
		var map = getMap();
		delete map[downloadId];
		setMap(map);
	}

	/*
	 * 播放器模块，封装了视频播放相关功能
	 */

	var PLAYER = {
		module: null, // 播放器模块
		positionIntervId: null, // 报告当前播放位置的计时器id
		positionDelay: 30 * 1000, // 30s报告一次

		// 初始化
		init: function init() {
			this.module = api.require("playModuleAli"); // 引入模块

			// 初始化播放器
			this.module.init(
				{FullScreenViewIsFont: false, isShowBottomBtn: true},
				function(ret, err) {
					console.log(
						new Date() +
							"\u521D\u59CB\u5316\u64AD\u653E\u5668\uFF1A" +
							JSON.stringify(ret)
					);
				}
			);

			this.initEventListener();
		},

		// 首次播放
		play: function play(_ref) {
			var _ref$x = _ref.x,
				x = _ref$x === void 0 ? 0 : _ref$x,
				_ref$y = _ref.y,
				y = _ref$y === void 0 ? 0 : _ref$y,
				_ref$w = _ref.w,
				w = _ref$w === void 0 ? 320 : _ref$w,
				_ref$h = _ref.h,
				h = _ref$h === void 0 ? 250 : _ref$h,
				title = _ref.title,
				url = _ref.url,
				position = _ref.position;
			this.module.play(
				{
					rect: {
						x: x,
						y: y,
						w: w,
						h: h
					},

					title: title, // 标题
					url: url,
					process: position, // 播放进度位置
					isShowSpeed: true,
					speedDatas: [
						{
							name: "X0.75",
							speed: 0.75
						},

						{
							name: "X1.0",
							speed: 1.0
						},

						{
							name: "X1.25",
							speed: 1.25
						},

						{
							name: "X1.5",
							speed: 1.5
						},

						{
							name: "X2.0",
							speed: 2.0
						}
					],

					isBackBtn: true, // 小窗口是否显示返回按钮
					isLongShowBackBtn: true, // 窗口模式下是否长时间显示返回按钮
					isOpenDanmu: false, // 是否打开弹幕功能
					singlePageModule: true, // 是否打开单页面播放模式
					scalingMode: 2, // 视频播放显示铺满模式（2:适应大小模式）
					options: {Format: {dns_cache_clear: 1}} // 关闭播放器的dns缓存
				},
				function(ret, err) {
					console.log(
						new Date() + "\u64AD\u653E\u89C6\u9891:" + JSON.stringify(ret)
					);
				}
			);
		},

		// 暂停
		pause: function pause() {
			this.module.pause();
		},

		// 设置播放进度位置
		seekTo: function seekTo(position) {
			if (!position) {
				return;
			}

			this.module.seekTo({
				process: position
			});
		},

		// 获取当前播放位置
		getCurrentPosition: function getCurrentPosition() {
			var _this = this;
			return new Promise(function(resolve) {
				_this.module.getCurrentPosition(function(ret, err) {
					if (ret && ret.status) {
						resolve(ret.currentPosition);
					}
				});
			});
		},

		// 获取视频的时长
		getDuration: function getDuration() {
			var _this2 = this;
			return new Promise(function(resolve) {
				_this2.module.getDuration(function(ret, err) {
					if (ret && ret.status) {
						resolve(ret.duration);
					}
				});
			});
		},

		// 清除页面所有打开的播放器
		cleanPlayers: function cleanPlayers() {
			this.module.cleanPlayers();
			this.module.stop();
		},

		// 退出全屏
		unfull: function unfull() {
			this.module.unfull();
		},

		// 关闭播放器及页面
		close: function close() {
			this.stopReportPosition();
			this.cleanPlayers();
			api.closeWin();
		},

		// 报告当前播放位置
		reportCurrentPosition: function reportCurrentPosition() {
			Promise.all([this.getCurrentPosition(), this.getDuration()]).then(function(
				res
			) {
				var position = res[0],
					duration = res[1];
				if (position > 0 && duration > 0 && position <= duration) {
					api.sendEvent({
						name: "currentPosition",
						extra: {
							position: Math.round(position / 1000),
							duration: Math.round(duration / 1000)
						}
					});
				}
			});
		},

		// 启动报告当前播放位置定时器
		startReportPosition: function startReportPosition() {
			var _this3 = this;
			this.stopReportPosition();

			this.positionIntervId = setInterval(function() {
				_this3.reportCurrentPosition();
			}, this.positionDelay);
		},

		// 停止报告当前播放位置
		stopReportPosition: function stopReportPosition() {
			if (this.positionIntervId) {
				clearInterval(this.positionIntervId);
				this.positionIntervId = null;

				// 最后报告一次当前播放位置
				this.reportCurrentPosition();
			}
		},

		// 初始化播放器监听事件
		initEventListener: function initEventListener() {
			var _this4 = this;
			// 监听设备 back 键被点击事件（仅 Android 平台有效）
			api.addEventListener(
				{
					name: "keyback"
				},
				function() {
					_this4.module.isFullScreen(function(ret, err) {
						// 全屏下退出全屏，非全屏下关闭页面
						if (ret.status) {
							_this4.unfull();
						} else {
							_this4.close();
						}
					});
				}
			);

			// 应用进入后台事件
			api.addEventListener(
				{
					name: "pause"
				},

				function() {
					return _this4.pause();
				}
			);

			// 小窗口返回按钮点击
			this.module.addEventListener(
				{
					name: "backBtn"
				},

				function(ret, err) {
					_this4.close();
				}
			);

			// ios 右滑返回
			this.module.addEventListener(
				{
					name: "viewappear"
				},

				function(ret, err) {
					_this4.close();
				}
			);

			// 播放
			this.module.addEventListener(
				{
					name: "play"
				},

				function(ret, err) {
					_this4.startReportPosition();
				}
			);

			// 暂停
			this.module.addEventListener(
				{
					name: "pause"
				},

				function(ret, err) {
					_this4.stopReportPosition();
				}
			);

			// 进入全屏
			this.module.addEventListener(
				{
					name: "full"
				},

				function() {
					api.sendEvent({
						name: "fullView"
					});
				}
			);

			// 播放结束
			this.module.addEventListener(
				{
					name: "playEnd"
				},

				function(ret, err) {
					_this4.stopReportPosition();
				}
			);

			// 播放异常
			this.module.addEventListener(
				{
					name: "playError"
				},

				function(ret, err) {
					_this4.stopReportPosition();
				}
			);
		}
	};

	/**
	 * 获取登录状态
	 */
	function getLoginStatus() {
		return storage.get("isLogin") || false;
	}

	/**
	 * 获取视频详细信息(未登录)
	 * @param {Number} videoId 视频id
	 */
	function getVideoDetailNo(videoId) {
		return ajax({
			url: "videoPlus/getVideo",
			data: {
				videoId: videoId,
				appType: 4
			}
		});
	}

	/**
	 * 获取视频详细信息
	 * @param {Number} videoId 视频id
	 */
	function getVideoDetail(videoId) {
		return ajax({
			url: "video/getDetail",
			data: {
				videoId: videoId,
				appType: 4,
				edition: "v1_0_14"
			}
		});
	}

	/**
	 * 获取视频讲义
	 * @param {Number} videoId 视频id
	 */
	function getVideoHandout(videoId) {
		return ajax({
			url: "courseStage/getVideoHandoutByVideoId",
			data: {
				videoId: videoId,
				appType: 4
			}
		});
	}

	/**
	 * 保存用户观看视频进度
	 * @param {Number} videoId 视频id
	 * @param {Number} watchDuration 视频观看时长
	 */
	function saveVideoProgress(videoId, watchDuration) {
		return ajax({
			url: "video/updateWatched",
			method: "post",
			data: {
				videoId: videoId,
				watchDuration: watchDuration,
				appType: 4
			}
		});
	}

	var Video = /*@__PURE__*/ (function(Component) {
		function Video(props) {
			Component.call(this, props);
			this.data = {
				network: true, // 网络状态
				videoId: null, // 视频id
				video: {}, // 视频信息
				videoHandout: [], // 视频讲义
				hasHandout: true, // 是否有讲义
				top: api.winWidth - 75, // 水印遮罩高度
				isLogin: false
			};
		}

		if (Component) Video.__proto__ = Component;
		Video.prototype = Object.create(Component && Component.prototype);
		Video.prototype.constructor = Video;
		Video.prototype.apiready = function() {
			//like created
			this.data.videoId = api.pageParam.videoId;
			this.data.isLogin = getLoginStatus();
			this.data.network = getNetworkStatus();
			this.initEventListenter();
			this.getHandoutDetails(); // 初始化播放器
			this.initPlay();
			var localVideosList = storage.get("downloadMap");
		};
		Video.prototype.open = function() {
			api.openFrame({
				name: "mask",
				url: "./mask.stml",
				rect: {
					x: 0,
					y: this.data.top,
					w: "auto",
					h: 10
				}
			});
		};
		Video.prototype.initEventListenter = function() {
			var this$1 = this;

			if (this.data.isLogin && this.data.network) {
				// 监听报告当前播放位置事件
				api.addEventListener(
					{
						name: "currentPosition"
					},
					function(ret) {
						var ref = ret.value;
						var position = ref.position;
						if (position > 0) {
							saveVideoProgress(this$1.data.videoId, position);
						}
					}
				);
			}

			api.addEventListener(
				{
					name: "fullView"
				},
				function(ret) {
					this$1.open();
				}
			);
		};
		Video.prototype.getVideoDetails = function() {
			var this$1 = this;

			var ref = this.data;
			var videoId = ref.videoId;
			var isLogin = ref.isLogin;
			if (isLogin) {
				getVideoDetail(videoId)
					.then(function(res) {
						this$1.data.video = res || {};
						this$1.play();
					})
					.catch(function(err) {
						this$1.data.video = {};
					});
			} else {
				getVideoDetailNo(videoId)
					.then(function(res) {
						this$1.data.video = res || {};
						this$1.play();
					})
					.catch(function(err) {
						this$1.data.video = {};
					});
			}
		};
		Video.prototype.getHandoutDetails = function() {
			var this$1 = this;

			var ref = this.data;
			var videoId = ref.videoId;
			getVideoHandout(videoId)
				.then(function(res) {
					if (res.videoHandoutId == null) {
						this$1.data.hasHandout = false;
						return;
					}
					this$1.data.videoHandout.push(res || {});
				})
				.catch(function(err) {
					this$1.data.videoHandout = [];
				});
		};
		Video.prototype.previewHandout = function(url) {
			openBrowser(url);
		};
		Video.prototype.onDownload = function() {
			var hasPower = confirmPermission(["storage"]);
			if (!hasPower) {
				return;
			}

			var downloadManager = api.require("downloadManager");
			var videoId = this.data.videoId;
			var title = this.data.video.hotspots;
			var url = this.data.video.urlSd;

			var localVideo = storage.get("localVideos") || [];
			var isExist = localVideo.findIndex(function(item) {
				return item.videoId === videoId;
			});

			// 如果该视频已经下载
			if (isExist !== -1) {
				toast("该视频已下载，不可以重复下载哦！");
				return;
			}

			// 如果已下载视频数量大于10

			// 学员特殊处理
			// const someUser = cedar.getUserInfo().phone;
			// if (localVideo.length >= 10 && someUser != '18285197594') {
			// 	ced.toast('只允许缓存10个视频哦！');
			// 	return;
			// }

			if (localVideo.length >= 10) {
				toast("只允许缓存10个视频哦！");
				return;
			}

			downloadManager.enqueue(
				{
					url: url,
					title: title,
					savePath: "fs://video/" + videoId + ".mp4",
					cache: true,
					allowResume: true, // 是否开启断点续传
					networkTypes: "all" // 允许自动下载的网络环境
				},
				function(ret, err) {
					if (ret) {
						// 本地保存
						localVideo.push({
							id: ret.id,
							videoId: videoId
						});

						addMap(ret.id, videoId);
						storage.set("localVideos", localVideo);

						toast("已成功添加到离线中心列表");
					} else {
						console.log(JSON.stringify(err));
					}
				}
			);
		};
		Video.prototype.initPlay = function() {
			var this$1 = this;

			PLAYER.init();
			// 查询本地是否下载
			var ref = this.data;
			var videoId = ref.videoId;
			queryById(videoId)
				.then(function(res) {
					if (res && res.status === 3) {
						// 已下载，使用本地视频路径直接播放
						toast("本地已缓存，正在从本地播放");

						this$1.data.video.hotspots = res.title;
						this$1.data.video.urlLd = res.savePath;
						this$1.play();
					} else {
						this$1.getVideoDetails();
					}
				})
				.catch(function() {});
		};
		Video.prototype.play = function() {
			var systemType = api.systemType;
			if (systemType === "ios") {
				PLAYER.play({
					x: 0,
					y: api.safeArea.top,
					w: api.winWidth,
					h: (api.winWidth * 9) / 16,
					title: this.data.video.hotspots,
					url: this.data.video.urlLd,
					position: 0
				});
			} else {
				PLAYER.play({
					x: 0,
					y: 0,
					w: api.winWidth,
					h: (api.winWidth * 9) / 16,
					title: this.data.video.hotspots,
					url: this.data.video.urlLd,
					position: 0
				});
			}
		};
		Video.prototype.render = function() {
			var this$1 = this;
			return apivm.h(
				"view",
				{class: "page"},
				apivm.h("safe-area", null),

				apivm.h("view", {
					class: "video",
					id: "video",
					style: "height: " + ((api.winWidth * 9) / 16 + "px")
				}),

				apivm.h(
					"view",
					{class: "course"},
					apivm.h(
						"view",
						{class: "course-message"},
						apivm.h("text", {class: "course-message-title"}, this.data.video.hotspots)
					)
				),

				apivm.h(
					"view",
					{class: "file"},
					apivm.h(
						"view",
						{class: "file-title"},
						apivm.h("view", {class: "file-title_line"}),
						apivm.h("text", {class: "file-title_text"}, "课时讲义")
					),
					(Array.isArray(this.data.videoHandout)
						? this.data.videoHandout
						: Object.values(this.data.videoHandout)
					).map(function(item$1) {
						return apivm.h(
							"view",
							{class: "file-list"},
							apivm.h(
								"view",
								{
									class: "file-list-item",
									onClick: function() {
										return this$1.previewHandout(item$1.downloadUrl);
									}
								},
								apivm.h("view", {class: "list-item-icon icon-" + item$1.fileType}),
								apivm.h(
									"view",
									{class: "list-item-file"},
									apivm.h(
										"text",
										{class: "item-file-name"},
										item$1.title,
										".",
										item$1.fileType
									),
									apivm.h("text", {class: "item-file-des"}, formatFileSize(item$1.size))
								)
							)
						);
					}),
					!this.data.hasHandout
						? apivm.h("text", {class: "no-file"}, "暂无讲义")
						: null
				),

				apivm.h(
					"text",
					{class: "download", onClick: this.onDownload},
					"下载本节视频"
				)
			);
		};

		return Video;
	})(Component);
	Video.css = {
		".page": {flexDirection: "column", height: "100%"},
		".video": {width: "100%"},
		".course": {
			flexDirection: "row",
			justifyContent: "space-between",
			padding: "20px 20px 40px",
			boxSizing: "border-box"
		},
		".course-message": {display: "flex", flexDirection: "column"},
		".course-message-title": {
			fontSize: "16px",
			fontWeight: "bold",
			color: "#333"
		},
		".course-message-teacher": {
			fontSize: "12px",
			color: "#666",
			marginTop: "5px"
		},
		".course-player": {
			borderRadius: "13px",
			border: "1px solid #ccc",
			padding: "5px 15px",
			boxSizing: "border-box",
			textAlign: "center",
			fontSize: "12px",
			color: "#999",
			margin: "9px 0"
		},
		".file": {
			flex: "1",
			margin: "0 20px",
			padding: "40px 0",
			boxSizing: "border-box",
			borderTop: "1px solid #eee"
		},
		".file-title": {
			flexDirection: "row",
			position: "relative",
			fontSize: "18px",
			fontWeight: "bold",
			color: "#333"
		},
		".file-title_line": {
			width: "3px",
			height: "12px",
			background: "#333",
			marginTop: "6.5px"
		},
		".file-title_text": {
			fontSize: "18px",
			fontWeight: "bold",
			color: "#333",
			marginLeft: "7.5px"
		},
		".file-list": {marginTop: "15px"},
		".file-list-item": {display: "flex", flexDirection: "row"},
		".file-list-item_s": {marginTop: "35px"},
		".list-item-icon": {
			width: "20px",
			height: "20px",
			background: "url(../../image/default-icon_display.png) no-repeat",
			backgroundSize: "270px 20px",
			margin: "11px 0"
		},
		".icon-pdf": {backgroundPosition: "-25px 0"},
		".icon-doc,\n.icon-docx": {backgroundPosition: "-50px 0"},
		".icon-png": {backgroundPosition: "-75px 0"},
		".icon-jpg": {backgroundPosition: "-100px 0"},
		".icon-rar,\n.icon-zip": {backgroundPosition: "-125px 0"},
		".icon-file": {backgroundPosition: "-150px 0"},
		".icon-ppt": {backgroundPosition: "-175px 0"},
		".icon-ppt,\n.icon-pptx": {backgroundPosition: "-175px 0"},
		".icon-txt": {backgroundPosition: "-200px 0"},
		".icon-mp4": {backgroundPosition: "-225px 0"},
		".icon-default": {backgroundPosition: "-250px 0"},
		".list-item-file": {
			display: "flex",
			flexDirection: "column",
			marginLeft: "15px"
		},
		".item-file-name": {fontSize: "15px", fontWeight: "bold", color: "#333"},
		".item-file-des": {fontSize: "12px", color: "#999", marginTop: "5px"},
		".no-file": {marginTop: "25px"},
		".download": {
			borderRadius: "22.5px",
			backgroundColor: "#17b47b",
			padding: "12px 0",
			textAlign: "center",
			fontSize: "15px",
			color: "#fff",
			margin: "0 25px 15px"
		}
	};
	apivm.define("video", Video);
	apivm.render(apivm.h("video", null), "body");
})();
