(function() {
	// api接口请求地址
	var BASEURL = "https://cbt.tibaitong.com/";

	// 请求权限名字
	var PERMISSIONNAME = {
		camera: "相机", // 相机/拍照/录像
		photos: "访问相册", // 访问相册|本地存储空间。Android上等同storage权限
		phone: "电话", // 直接拨打电话/获取手机号码|IMEI。只支持Android
		storage: "存储", // 读取/写入|相册|多媒体|本地存储空间。只支持Android
		"phone-r": "设备信息"
	};

	// 本地存储
	var storage = {
		set: function set(key, value) {
			api.setPrefs({
				key: key,
				value: typeof value === "string" ? value : JSON.stringify(value)
			});
		},

		get: function get(key) {
			var value = api.getPrefs({sync: true, key: key}) || "";

			// 如果JSON字符串无法解析，直接返回
			try {
				return JSON.parse(value);
			} catch (e) {
				return value;
			}
		},

		del: function del(key) {
			api.removePrefs({key: key});
		}
	};

	// 请求
	function ajax(_ref) {
		var url = _ref.url,
			_ref$method = _ref.method,
			method = _ref$method === void 0 ? "get" : _ref$method,
			_ref$data = _ref.data,
			data = _ref$data === void 0 ? {} : _ref$data;
		return new Promise(function(resolve, reject) {
			api.ajax(
				{
					url: url.indexOf("http") === 0 ? url : BASEURL + url,
					method: method,
					headers: {
						"Content-Type": "application/json;charset=utf-8",
						"ZK-TOKEN": storage.get("token"),
						"APP-TYPE": 2
					},

					timeout: 60,
					data: {
						body: data
					}
				},

				function(ret, err) {
					if (ret) {
						if (ret.code === 200) {
							resolve(ret.data);
						} else if (ret.code === 600) {
							// 发送用户登录过期事件
							api.sendEvent({
								name: "loginExpired"
							});
						} else {
							api.toast({
								msg: ret.msg
							});
						}

						reject(ret);
					} else {
						api.toast({
							msg: "网络不畅,请检查网络"
						});

						reject(err);
					}
				}
			);
		});
	}

	/**
	 * 判断是否拥有权限
	 * @param {Array} perms 权限列表
	 */
	function hasPermission(perms) {
		var resultList = api.hasPermission({
			list: perms
		});

		return resultList;
	}

	/**
	 * 向系统请求权限
	 * @param {Array} perms 权限列表
	 */
	function requestPermission(perms) {
		api.requestPermission({
			list: perms,
			code: 1
		});
	}

	/**
	 * 确认权限(无权限提示获取)
	 * @param {Array} perms 权限列表
	 */
	function confirmPermission(perms) {
		var resultList = hasPermission(perms);

		// 获取需要请求的权限列表
		var requestList = [];
		resultList.forEach(function(item, index) {
			if (!item || !item.granted) {
				requestList.push(perms[index]);
			}
		});

		// 如果拥有全部权限
		if (requestList.length === 0) {
			return true;
		}

		// 否则，提示请求权限
		var str = "";
		requestList.forEach(function(per) {
			str += PERMISSIONNAME[per] + "\u3001";
		});
		str = str.slice(0, str.length - 1);

		api.confirm(
			{
				title: "提醒",
				msg:
					"\u4F7F\u7528\u76F8\u5173\u529F\u80FD\uFF0C\u9700\u8981\u83B7\u53D6 " +
					str +
					" \u6743\u9650\n\u662F\u5426\u524D\u5F80\u8BBE\u7F6E\uFF1F",
				buttons: ["去设置", "取消"]
			},

			function(ret) {
				if (ret.buttonIndex === 1) {
					requestPermission(perms);
				}
			}
		);

		return false;
	}

	/**
	 * 格式化文件大小, 输出成带单位的字符串
	 * @param {Number} size 文件大小
	 */
	function formatFileSize(size) {
		var units = ["B", "K", "M", "G", "TB"];
		var fileSize = parseInt(size);
		for (var i = 0; fileSize >= 1024; i += 1) {
			fileSize /= 1024;
			units.shift();
		}
		return fileSize.toFixed(1) + units[0];
	}

	/**
	 * 浏览器打开
	 * @param {String} url 需要打开的地址
	 */
	function openBrowser(url) {
		api.openApp({
			androidPkg: "android.intent.action.VIEW",
			uri: url,
			iosUrl: url
		});
	}

	// 获取当前网络状态
	function getNetworkStatus() {
		return api.connectionType !== "none";
	}

	function toast(msg) {
		api.toast({
			msg: msg
		});
	}

	/**
	 * 获取登录状态
	 */
	function getLoginStatus() {
		return storage.get("isLogin") || false;
	}

	/**
	 * 获取视频详细信息
	 * @param {Number} videoId 视频id
	 */
	function getVideoDetail(videoId) {
		return ajax({
			url: "video/getDetail",
			data: {
				videoId: videoId,
				appType: 4,
				edition: "v1_0_14"
			}
		});
	}

	/**
	 * 获取加密视频信息（暂未启用）
	 * @param {Number} videoId 视频id
	 * @param {String} channelFlag 访问来源
	 * @param {String} resourcesFlag 资源种类
	 */
	function getVideoInfoByAuth(videoId) {
		return ajax({
			url: "videoPlus/getPlayInfo",
			data: {
				videoId: videoId,
				channelFlag: 1,
				resourcesFlag: 1
			}
		});
	}

	/**
	 * 获取视频讲义
	 * @param {Number} videoId 视频id
	 */
	function getVideoHandout(videoId) {
		return ajax({
			url: "courseStage/getVideoHandoutByVideoId",
			data: {
				videoId: videoId,
				appType: 4
			}
		});
	}

	/**
	 * 保存用户观看视频进度
	 * @param {Number} videoId 视频id
	 * @param {Number} watchDuration 视频观看时长
	 */
	function saveVideoProgress(videoId, watchDuration) {
		return ajax({
			url: "video/updateWatched",
			method: "post",
			data: {
				videoId: videoId,
				watchDuration: watchDuration,
				appType: 4
			}
		});
	}

	/*
	 * 播放器模块，封装了视频播放相关功能
	 */

	var AliPlayer = {
		module: null, // 播放器模块
		positionIntervId: null, // 报告当前播放位置的计时器id
		positionDelay: 30 * 1000, // 30s报告一次
		pause: true, // 30s报告一次

		// 初始化
		init: function init() {
			this.module = api.require("AliyunPlayer"); // 引入模块
			this.module.setDownloadVerifyFile({
				filePath: "fs://xskt.dat"
			});

			// this.initHandleEvent()
		},

		// 打开定制播放器
		play: function play(_ref) {
			var _this = this;
			var _ref$x = _ref.x,
				x = _ref$x === void 0 ? 0 : _ref$x,
				_ref$y = _ref.y,
				y = _ref$y === void 0 ? 0 : _ref$y,
				_ref$w = _ref.w,
				w = _ref$w === void 0 ? 320 : _ref$w,
				_ref$h = _ref.h,
				h = _ref$h === void 0 ? 250 : _ref$h,
				playAuth = _ref.playAuth,
				title = _ref.title,
				url = _ref.url,
				duration = _ref.duration;
			this.module.openCustomPlayer(
				{
					rect: {
						x: x,
						y: y,
						w: w,
						h: h
					},

					url: url,
					playAuth: playAuth,
					title: title,
					topControlColor: "rgba(0,0,0,0.2)", // 顶部控制层背景颜色
					bottomControlColor: "rgba(0,0,0,0.2)", // 底部控制层背景颜色
					autoPlay: true, // 是否自动播放
					nextBtnVisible: false, // next按钮是否显示
					danmuBtnVisible: false // 弹幕按钮是否显示
				},
				function(ret) {
					console.log(JSON.stringify(ret));

					if (ret.eventType === "play") {
						_this.startReportPosition();
					}
					if (ret.eventType === "pause") {
						_this.stopReportPosition();
					}
					if (ret.eventType === "firstFrame") {
						_this.seekToTime(duration);
					}
					if (ret.eventType === "back") {
						_this.close();
					}
				}
			);
		},

		// 关闭播放器
		closePlayer: function closePlayer() {
			this.module.closeCustomPlayer();
		},

		// 跳转到指定时间点播放
		seekToTime: function seekToTime(position) {
			if (!position) {
				return;
			}
			this.module.seekToTime({
				position: position
			});
		},

		// 获取当前播放位置
		getCurrentPosition: function getCurrentPosition() {
			var _this2 = this;
			return new Promise(function(resolve) {
				_this2.module.getCurrentPosition(function(ret) {
					if (ret) {
						resolve(ret.position);
					}
				});
			});
		},

		// 获取视频的时长
		getDuration: function getDuration() {
			var _this3 = this;
			return new Promise(function(resolve) {
				_this3.module.getDuration(function(ret, err) {
					if (ret) {
						resolve(ret.duration);
					}
				});
			});
		},

		// 报告当前播放位置
		reportCurrentPosition: function reportCurrentPosition() {
			Promise.all([this.getCurrentPosition(), this.getDuration()]).then(function(
				res
			) {
				var position = res[0];
				var duration = res[1];
				if (position > 0 && duration > 0 && position <= duration) {
					api.sendEvent({
						name: "currentPosition",
						extra: {
							position: Math.round(position / 1000)
						}
					});
				}
			});
		},

		// 启动报告当前播放位置定时器
		startReportPosition: function startReportPosition() {
			var _this4 = this;
			this.positionIntervId = setInterval(function() {
				_this4.reportCurrentPosition();
			}, this.positionDelay);
		},

		// 停止报告当前播放位置
		stopReportPosition: function stopReportPosition() {
			if (this.positionIntervId) {
				clearInterval(this.positionIntervId);
				this.positionIntervId = null;

				// 最后报告一次当前播放位置
				this.reportCurrentPosition();
			}
		},

		// 清除页面打开的播放器
		cleanPlayers: function cleanPlayers() {
			this.module.closeCustomPlayer();
			this.module.close();
		},

		// 关闭播放器及页面
		close: function close() {
			this.stopReportPosition();
			this.cleanPlayers();
			api.closeWin();
		},

		// 初始化下载
		initDownloader: function initDownloader() {
			this.module.initDownloader(
				{
					downloadDir: "fs://"
				},
				function(ret) {
					console.log(JSON.stringify(ret));
				}
			);
		},

		// 准备下载
		prepareDownload: function prepareDownload(playAuth) {
			var _this5 = this;
			return new Promise(function(resolve) {
				_this5.module.prepareDownload(
					{
						playAuth: playAuth
					},
					function(ret) {
						resolve(ret);
					}
				);
			});
		},

		// 开始下载
		startDownload: function startDownload() {
			this.module.startDownload();
		},

		// 暂停下载
		stopDownload: function stopDownload() {
			this.module.stopDownload();
		},

		// 删除下载 ios
		removeDownload: function removeDownload(vid) {
			this.module.removeDownload({
				vid: vid
			});
		},

		// 监听手势行为
		initHandleEvent: function initHandleEvent() {
			var AliyunPlayer = api.require("AliyunPlayer");
			AliyunPlayer.addTouchListener(
				{
					name: "doubleClick"
				},
				function(ret) {
					alert(JSON.stringify(ret));
				}
			);
			// this.module.addTouchListener({
			//   name: 'doubleClick',
			// }, (ret, err) => {
			//   console.log(11);
			//   if (this.pause) {
			//     this.module.start();
			//     this.pause = true;
			//   } else {
			//     this.module.pause();
			//     this.pause = false;
			//   }
			// });
		}
	};

	// 调用下载模块下载
	function aliDownload(videoId) {
		AliPlayer.init();
		AliPlayer.initDownloader();
		getVideoInfoByAuth(videoId).then(function(res) {
			var palyAuth = {
				vid: res.id,
				authInfo: res.auth
			};

			/**
			 * AliPlayer模块下载需要两个接口：
			 * 1. 先调用 prepareDownload 接口，验证下载信息
			 * 2. 先调用 startDownload 接口，开始下载视频
			 */
			AliPlayer.prepareDownload(palyAuth).then(function() {
				// 开始下载
				AliPlayer.startDownload();
			});
		});
	}

	// 下载方法（手动下载）
	function encryptDownload(videoId, title) {
		var encryptLocalVideos = storage.get("encryptLocalVideos") || [];
		var currentDownloadFile = storage.get("currentDownloadFile") || {};
		var downloadExist = encryptLocalVideos.findIndex(function(item) {
			return item.videoId === videoId;
		});

		if (downloadExist !== -1) {
			// ced.toast('该视频已下载，不可以重复下载哦！');
			encryptLocalVideos.splice(downloadExist, 1);
			// return
		}

		// 保存下载记录
		var videoInfo = {
			videoId: videoId,
			title: title,
			savePath: ""
		};

		// 保存到所有下载记录中
		encryptLocalVideos.push(videoInfo);
		storage.set("encryptLocalVideos", encryptLocalVideos);
		toast("已成功添加到离线中心列表");

		// 如果这是第一个视频，或前一个视频已完成，才开始下载
		var index = encryptLocalVideos.findIndex(function(item) {
			return item.videoId === videoId;
		});
		if (
			index === 0 ||
			(encryptLocalVideos[index - 1] && encryptLocalVideos[index - 1].savePath)
		) {
			currentDownloadFile = videoInfo;
			storage.set("currentDownloadFile", currentDownloadFile);
			aliDownload(videoId);
		}
	}

	var downloadManager = api.require("downloadManager");

	// 根据映射的ID查询下载项
	function queryById(id) {
		var map = getMap();
		var downloadId = Object.keys(map).find(function(item) {
			return map[item] === id;
		});

		if (!downloadId) {
			return Promise.resolve();
		}

		return new Promise(function(resolve, reject) {
			downloadManager.query(
				{
					ids: [downloadId]
				},
				function(ret, err) {
					if (ret) {
						if (ret.data && ret.data.length) {
							resolve(ret.data[0]);
						} else {
							delMap(downloadId);
							resolve();
						}
					} else {
						reject(err);
					}
				}
			);
		});
	}

	// 获取映射
	function getMap(downloadId) {
		var map = storage.get("downloadMap") || {};
		return downloadId ? map[downloadId] : map;
	}

	// 保存映射
	function setMap(map) {
		return storage.set("downloadMap", map);
	}

	// 添加映射
	function addMap(downloadId, id) {
		var map = getMap();
		map[downloadId] = id;
		setMap(map);
	}

	// 删除某一映射
	function delMap(downloadId) {
		var map = getMap();
		delete map[downloadId];
		setMap(map);
	}

	var Video = /*@__PURE__*/ (function(Component) {
		function Video(props) {
			Component.call(this, props);
			this.data = {
				network: true,
				// 网络状态
				videoId: null,
				// 视频id
				video: {},
				// 视频信息
				videoHandout: [],
				// 视频讲义
				hasHandout: true,
				// 是否有讲义
				isEncrypt: false,
				// 是否为加密视频
				playAuth: null,
				// 加密视频凭证
				isLogin: false // 是否登录
			};
		}

		if (Component) Video.__proto__ = Component;
		Video.prototype = Object.create(Component && Component.prototype);
		Video.prototype.constructor = Video;
		Video.prototype.apiready = function() {
			this.data.videoId = api.pageParam.videoId; // videoId
			this.data.isLogin = getLoginStatus(); // 登录状态
			this.data.network = getNetworkStatus(); // 网络状态
			this.initEventListenter(); // 初始化监听
			this.init(); // 初始化播放器
		};
		Video.prototype.initEventListenter = function() {
			var this$1 = this;
			if (this.data.isLogin && this.data.network) {
				// 报告当前播放位置事件
				api.addEventListener(
					{
						name: "currentPosition"
					},
					function(ret) {
						var ref = ret.value;
						var position = ref.position;
						if (position > 0) {
							saveVideoProgress(this$1.data.videoId, position);
						}
					}
				);
			}
			api.addEventListener(
				{
					name: "keyback"
				},
				function() {
					AliPlayer.close();
				}
			);
		};
		Video.prototype.init = function() {
			var this$1 = this;

			AliPlayer.init(); // 查询本地是否下载
			var ref = this.data;
			var videoId = ref.videoId; // 查询本地加密下载记录
			var encryptLocalVideos = storage.get("encryptLocalVideos") || [];
			var downloadExist = encryptLocalVideos.findIndex(function(item) {
				return item.videoId === videoId;
			});
			if (downloadExist !== -1 && encryptLocalVideos[downloadExist] !== "") {
				// 存在加密下载
				if (encryptLocalVideos[downloadExist].savePath) {
					this.data.video.hotspots = encryptLocalVideos[downloadExist].title;
					this.data.video.urlLd =
						"file://" + encryptLocalVideos[downloadExist].savePath;
					this.data.isEncrypt = true;
					this.play();
					toast("本地已缓存，正在从本地播放");
				} else {
					toast("正在等待课程缓存，请稍后重试...");
				}
			} else {
				queryById(videoId).then(function(res) {
					// 存在非加密下载
					if (res && res.status === 3) {
						// 已下载，使用本地视频路径直接播放
						this$1.data.video.hotspots = res.title;
						this$1.data.video.urlLd = res.savePath;
						this$1.play();
						toast("本地已缓存，正在从本地播放");
					} else {
						// 没有下载记录，获取课程数据
						this$1.getVideoDetails(videoId);
					}
				});
			} // this.getVideoDetailsByAuth(videoId);
			this.getHandoutDetails(videoId); // 获取讲义
		};
		Video.prototype.getVideoDetails = function(videoId) {
			var this$1 = this;

			getVideoDetail(videoId)
				.then(function(res) {
					console.log(JSON.stringify(res));
					this$1.data.video = res || {};
					if (res.urlLd) {
						this$1.play();
					} else {
						// this.video.urlLd = undefined; // 测试用
						this$1.data.isEncrypt = true;
						this$1.getVideoDetailsByAuth(videoId);
					}
				})
				.catch(function() {
					this$1.data.video = {};
				});
		};
		Video.prototype.getVideoDetailsByAuth = function(videoId) {
			var this$1 = this;

			getVideoInfoByAuth(videoId)
				.then(function(res) {
					var playAuth = {
						vid: res.id,
						authInfo: res.auth
					};

					this$1.data.playAuth = playAuth;
					this$1.data.video.hotspots = "测试视频" + videoId;
					this$1.play();
				})
				.catch(function() {
					this$1.data.playAuth = {};
				});
		};
		Video.prototype.getHandoutDetails = function(videoId) {
			var this$1 = this;

			getVideoHandout(videoId)
				.then(function(res) {
					if (res.videoHandoutId == null) {
						this$1.data.hasHandout = false;
						return;
					}
					this$1.data.videoHandout.push(res || {});
				})
				.catch(function(err) {
					this$1.data.hasHandout = false;
					this$1.data.videoHandout = [];
				});
		};
		Video.prototype.previewHandout = function(url) {
			openBrowser(url);
		};
		Video.prototype.play = function() {
			// ios 系统加顶部距离 ， android 系统不加顶部距离
			var top = api.systemType === "ios" ? api.safeArea.top : 0;
			AliPlayer.closePlayer();
			AliPlayer.play({
				x: 0,
				y: top,
				w: api.winWidth,
				h: (api.winWidth * 9) / 16,
				playAuth: this.data.playAuth,
				url: this.data.video.urlLd || null,
				title: this.data.video.hotspots,
				duration: this.data.video.watchDuration * 1000 || 0
			});
		};
		Video.prototype.onDownload = function() {
			// 1. 检测设备存储权限是否开启，并下载加密文件
			var hasPower = confirmPermission(["storage"]);
			if (!hasPower) {
				return;
			}
			this.downloadVerifyFile(); // 下载加密文件
			// 2. 检测该视频的下载条件
			var ref = this.data;
			var videoId = ref.videoId;
			var isEncrypt = ref.isEncrypt;
			var ref$1 = this.data.video;
			var hotspots = ref$1.hotspots; // 2.1 如果 hotspots 没有值，说明视频数据还未获取完整，不给予下载
			if (!hotspots) {
				return toast("点击得太快啦，视频信息正在加载中...");
			} // 3. 根据视频类型选择下载方式（非加密视频、加密视频）
			if (isEncrypt) {
				// 判断加密文件是否下载完成
				var hasEncryptedFile = storage.get("hasEncryptedFile") || false;
				if (!hasEncryptedFile) {
					toast("您的网络不稳定喔，请在5秒后重新点击下载");
				} else {
					encryptDownload(videoId, hotspots);
				}
			} else {
				this.onDownloadNoAuth(videoId);
			}
		};
		Video.prototype.onDownloadNoAuth = function(videoId) {
			var downloadManager = api.require("downloadManager");
			var ref = this.data.video;
			var hotspots = ref.hotspots;
			var urlSd = ref.urlSd;
			var localVideo = storage.get("localVideos") || [];
			var isExist = localVideo.findIndex(function(item) {
				return item.videoId === videoId;
			}); // 如果该视频已经下载
			if (isExist !== -1) {
				toast("该视频已下载，不可以重复下载哦！");
				return;
			} // 如果已下载视频数量大于10
			if (localVideo.length >= 10) {
				toast("只允许缓存10个视频哦！");
				return;
			}
			downloadManager.enqueue(
				{
					url: urlSd,
					title: hotspots,
					savePath: "fs://video/" + videoId + ".mp4",
					cache: true,
					allowResume: true,
					// 是否开启断点续传
					networkTypes: "all" // 允许自动下载的网络环境
				},
				function(ret, err) {
					if (ret) {
						if (ret.id === -1) {
							return toast("下载失败，请重试");
						} // 本地保存
						localVideo.push({
							id: ret.id,
							videoId: videoId
						});

						addMap(ret.id, videoId);
						storage.set("localVideos", localVideo);
						toast("已成功添加到离线中心列表");
					} else {
						toast("下载失败");
					}
				}
			);
		};
		Video.prototype.downloadVerifyFile = function() {
			var hasEncryptedFile = storage.get("hasEncryptedFile") || false;
			if (hasEncryptedFile) {
				return;
			}
			var system = api.systemType;
			if (system !== "ios" && system !== "android") {
				return toast("检测系统失败");
			}
			api.download(
				{
					url: "http://dev.zhuokao360.com/encryptedApp/" + system + "/xskt.dat",
					savePath: "fs://xskt.dat",
					report: true,
					cache: false,
					allowResume: true
				},
				function(ret) {
					if (ret.state == 1) {
						storage.set("hasEncryptedFile", true);
					}
				}
			);
		};
		Video.prototype.render = function() {
			var this$1 = this;
			return apivm.h(
				"view",
				{class: "page"},
				apivm.h("safe-area", null),

				apivm.h(
					"view",
					{
						class: "video",
						id: "video",
						style: "height: " + ((api.winWidth * 9) / 16 + "px")
					},
					apivm.h("text", {class: "video_logo"}, "雪松课堂")
				),

				apivm.h(
					"view",
					{class: "course"},
					apivm.h(
						"view",
						{class: "course-message"},
						apivm.h("text", {class: "course-message-title"}, this.data.video.hotspots)
					)
				),

				apivm.h(
					"view",
					{class: "file"},
					apivm.h(
						"view",
						{class: "file-title"},
						apivm.h("view", {class: "file-title_line"}),
						apivm.h("text", {class: "file-title_text"}, "课时讲义")
					),
					(Array.isArray(this.data.videoHandout)
						? this.data.videoHandout
						: Object.values(this.data.videoHandout)
					).map(function(item$1) {
						return apivm.h(
							"view",
							{class: "file-list"},
							apivm.h(
								"view",
								{
									class: "file-list-item",
									onClick: function() {
										return this$1.previewHandout(item$1.downloadUrl);
									}
								},
								apivm.h("view", {class: "list-item-icon icon-" + item$1.fileType}),
								apivm.h(
									"view",
									{class: "list-item-file"},
									apivm.h(
										"text",
										{class: "item-file-name"},
										item$1.title,
										".",
										item$1.fileType
									),
									apivm.h("text", {class: "item-file-des"}, formatFileSize(item$1.size))
								)
							)
						);
					}),
					!this.data.hasHandout
						? apivm.h("text", {class: "no-file"}, "暂无讲义")
						: null
				),

				apivm.h(
					"text",
					{class: "download", onClick: this.onDownload},
					"下载本节视频"
				)
			);
		};

		return Video;
	})(Component);
	Video.css = {
		".page": {flexDirection: "column", height: "100%"},
		".video": {width: "100%", backgroundColor: "#333"},
		".video_logo": {color: "#fff", fontSize: "26px", fontWeight: "bold"},
		".course": {
			flexDirection: "row",
			justifyContent: "space-between",
			padding: "20px 20px 40px",
			boxSizing: "border-box"
		},
		".course-message": {display: "flex", flexDirection: "column"},
		".course-message-title": {
			fontSize: "16px",
			fontWeight: "bold",
			color: "#333"
		},
		".course-message-teacher": {
			fontSize: "12px",
			color: "#666",
			marginTop: "5px"
		},
		".course-player": {
			borderRadius: "13px",
			border: "1px solid #ccc",
			padding: "5px 15px",
			boxSizing: "border-box",
			textAlign: "center",
			fontSize: "12px",
			color: "#999",
			margin: "9px 0"
		},
		".file": {
			flex: "1",
			margin: "0 20px",
			padding: "40px 0",
			boxSizing: "border-box",
			borderTop: "1px solid #eee"
		},
		".file-title": {
			flexDirection: "row",
			position: "relative",
			fontSize: "18px",
			fontWeight: "bold",
			color: "#333"
		},
		".file-title_line": {
			width: "3px",
			height: "12px",
			background: "#333",
			marginTop: "6.5px"
		},
		".file-title_text": {
			fontSize: "18px",
			fontWeight: "bold",
			color: "#333",
			marginLeft: "7.5px"
		},
		".file-list": {marginTop: "15px"},
		".file-list-item": {display: "flex", flexDirection: "row"},
		".file-list-item_s": {marginTop: "35px"},
		".list-item-icon": {
			width: "20px",
			height: "20px",
			background: "url(../../image/default-icon_display.png) no-repeat",
			backgroundSize: "270px 20px",
			margin: "11px 0"
		},
		".icon-pdf": {backgroundPosition: "-25px 0"},
		".icon-doc,\n.icon-docx": {backgroundPosition: "-50px 0"},
		".icon-png": {backgroundPosition: "-75px 0"},
		".icon-jpg": {backgroundPosition: "-100px 0"},
		".icon-rar,\n.icon-zip": {backgroundPosition: "-125px 0"},
		".icon-file": {backgroundPosition: "-150px 0"},
		".icon-ppt": {backgroundPosition: "-175px 0"},
		".icon-ppt,\n.icon-pptx": {backgroundPosition: "-175px 0"},
		".icon-txt": {backgroundPosition: "-200px 0"},
		".icon-mp4": {backgroundPosition: "-225px 0"},
		".icon-default": {backgroundPosition: "-250px 0"},
		".list-item-file": {
			display: "flex",
			flexDirection: "column",
			marginLeft: "15px"
		},
		".item-file-name": {fontSize: "15px", fontWeight: "bold", color: "#333"},
		".item-file-des": {fontSize: "12px", color: "#999", marginTop: "5px"},
		".no-file": {marginTop: "25px"},
		".download": {
			borderRadius: "22.5px",
			backgroundColor: "#17b47b",
			padding: "12px 0",
			textAlign: "center",
			fontSize: "15px",
			color: "#fff",
			margin: "0 25px 15px"
		}
	};
	apivm.define("video", Video);
	apivm.render(apivm.h("video", null), "body");
})();
