/*
 * 播放器模块，封装了视频播放相关功能
 */

export default {
  module: null, // 播放器模块
  positionIntervId: null, // 报告当前播放位置的计时器id
  positionDelay: 30 * 1000, // 30s报告一次
  pause: true, // 30s报告一次

  // 初始化
  init() {
    this.module = api.require('AliyunPlayer'); // 引入模块
    this.module.setDownloadVerifyFile({
      filePath: 'fs://xskt.dat',
    })
    // this.initHandleEvent()
  },

  // 打开定制播放器
  play({
    x = 0, y = 0, w = 320, h = 250, playAuth, title, url, duration
  }) {
    this.module.openCustomPlayer({
      rect: {
        x,
        y,
        w,
        h
      },
      url,
      playAuth,
      title,
      topControlColor: 'rgba(0,0,0,0.2)', // 顶部控制层背景颜色
      bottomControlColor: 'rgba(0,0,0,0.2)', // 底部控制层背景颜色
      autoPlay: true, // 是否自动播放
      nextBtnVisible: false, // next按钮是否显示
      danmuBtnVisible: false, // 弹幕按钮是否显示
    }, (ret) => {
      console.log(JSON.stringify(ret));

      if (ret.eventType === 'play') {
        this.startReportPosition();
      }
      if (ret.eventType === 'pause') {
        this.stopReportPosition();
      }
      if (ret.eventType === 'firstFrame') {
        this.seekToTime(duration);
      }
      if (ret.eventType === 'back') {
        this.close()
      }
    })
  },

  // 关闭播放器
  closePlayer() {
    this.module.closeCustomPlayer()
  },

  // 跳转到指定时间点播放
  seekToTime(position) {
    if (!position) {
      return;
    }
    this.module.seekToTime({
      position
    })
  },

  // 获取当前播放位置
  getCurrentPosition() {
    return new Promise((resolve) => {
      this.module.getCurrentPosition((ret) => {
        if (ret) {
          resolve(ret.position);
        }
      });
    });
  },

  // 获取视频的时长
  getDuration() {
    return new Promise((resolve) => {
      this.module.getDuration((ret, err) => {
        if (ret) {
          resolve(ret.duration);
        }
      });
    });
  },

  // 报告当前播放位置
  reportCurrentPosition() {
    Promise.all([this.getCurrentPosition(), this.getDuration()]).then((res) => {
      const position = res[0];
      const duration = res[1];
      if (position > 0 && duration > 0 && position <= duration) {
        api.sendEvent({
          name: 'currentPosition',
          extra: {
            position: Math.round(position / 1000),
          },
        });
      }
    });
  },

  // 启动报告当前播放位置定时器
  startReportPosition() {
    this.positionIntervId = setInterval(() => {
      this.reportCurrentPosition();
    }, this.positionDelay);
  },

  // 停止报告当前播放位置
  stopReportPosition() {
    if (this.positionIntervId) {
      clearInterval(this.positionIntervId);
      this.positionIntervId = null;

      // 最后报告一次当前播放位置
      this.reportCurrentPosition();
    }
  },

  // 清除页面打开的播放器
  cleanPlayers() {
    this.module.closeCustomPlayer();
    this.module.close();
  },

  // 关闭播放器及页面
  close() {
    this.stopReportPosition();
    this.cleanPlayers();
    api.closeWin();
  },

  // 初始化下载
  initDownloader() {
    this.module.initDownloader({
      downloadDir: 'fs://',
    }, function (ret) {
      console.log(JSON.stringify(ret));
    })
  },

  // 准备下载
  prepareDownload(playAuth) {
    return new Promise((resolve) => {
      this.module.prepareDownload({
        playAuth,
      }, (ret) => {
        resolve(ret);
      });
    });
  },

  // 开始下载
  startDownload() {
    this.module.startDownload();
  },

  // 暂停下载
  stopDownload() {
    this.module.stopDownload();
  },

  // 删除下载 ios
  removeDownload(vid) {
    this.module.removeDownload({
      vid,
    });
  },

  // 监听手势行为
  initHandleEvent() {
    var AliyunPlayer = api.require('AliyunPlayer');
    AliyunPlayer.addTouchListener({
      name: 'doubleClick'
    }, function (ret) {
      alert(JSON.stringify(ret));
    });
    // this.module.addTouchListener({
    //   name: 'doubleClick',
    // }, (ret, err) => {
    //   console.log(11);
    //   if (this.pause) {
    //     this.module.start();
    //     this.pause = true;
    //   } else {
    //     this.module.pause();
    //     this.pause = false;
    //   }
    // });
  },
};
