import * as btzx from './btzx';

/**
 * 自动登录
 */
function autoLogin() {
  return btzx.ajax({
    url: 'login/autoLogin',
  });
}

/**
 * 账户密码登录
 * @param {String} phone 手机号
 * @param {String} password 密码
 */
function login(phone, password) {
  return btzx.ajax({
    url: 'login/login',
    method: 'post',
    data: {
      phone,
      password,
    },
  });
}

/**
 * 短信前置-获取图片验证码
 * @param {String} phone 手机号码
 */
function getImageCode(phone) {
  return btzx.ajax({
    url: 'sms/getImageCode',
    data: {
      phone,
    },
  });
}

/**
 * 获取短信验证码
 * @param {String} phone 手机号码
 * @param {Number} imageCode 4位数字的图片验证码
 */
function sendSmscode(phone, imageCode) {
  return btzx.ajax({
    url: 'sms/sendSms',
    method: 'post',
    data: {
      phone,
      imageCode,
      type: 33,
    },
  });
}

/**
 * 短信验证码登录
 * @param {String} phone 手机号码
 * @param {Number} smscode 6位数字的短信验证码
 */
function smscodeLogin(phone, smscode) {
  return btzx.ajax({
    url: 'login/sms',
    method: 'post',
    data: {
      phone,
      smsCode: smscode,
      type: 33,
    },
  });
}

/**
 * 修改昵称
 * @param {String} nick 要修改的昵称
 */
function changeNick(nick) {
  return btzx.ajax({
    url: 'user/changeNick',
    method: 'post',
    data: {
      nick,
    },
  });
}


/**
 * 修改个性签名
 * @param {String} signature 要修改的签名
 */
function changeSignature(signature) {
  return btzx.ajax({
    url: 'user/changeSignature',
    method: 'post',
    data: {
      signature,
    },
  });
}

/**
 * 修改密码
 * @param {String} phone 手机号码
 * @param {String} smsCode 短信验证码
 * @param {String} newPwd 新密码
 */
function changePassword(phone, smsCode, newPwd) {
  return btzx.ajax({
    url: 'user/updatePassword',
    method: 'post',
    data: {
      phone,
      smsCode,
      newPwd
    },
  });
}

/************************************************
*                   课程接口                    *      
***********************************************/

/**
 * 获取所有职称课程映射表
 */
function getProfession() {
  return btzx.ajax({
    url: 'course/getUserProfession',
  });
}

/**
 * 获取首页公告提示
 */
function getNotice(type, professionId) {
  return btzx.ajax({
    url: `notice/findNotice/${type}/${professionId}`,
  });
}

/**
 * 获取视频播放历史记录
 */
 function getHistoryVideo() {
  return btzx.ajax({
    url: 'course/getNewSummary',
  });
}


/**
 * 获取所有课程
 */
function getFreeCourse() {
  return btzx.ajax({
    url: 'course/findAllCourseAuth',
  });
}

/**
 * 获取课程列表
 */
function getCourseList() {
  return btzx.ajax({
    url: 'course/findCourseAuth',
  });
}

/**
 * 获取课程学习进度
 * @param {Number} courseId 课程id
 * @param {Number} type 课程类型
 */
function getCourseProgress(courseId, type = 1) {
  return btzx.ajax({
    url: 'courseStage/getCourseLearnInfo',
    data: {
      courseId,
      type,
    },
  });
}

/**
 * 获取课时列表
 * @param {Number} courseId 课程id
 * @param {Number} type 课程类型
 */
function getLessonList(courseId, type = 1) {
  return btzx.ajax({
    // url: 'courseStage/findCourseStageByType',
    url: 'courseStage/findNewCourseStageType',
    data: {
      courseId,
      type,
    },
  });
}

/**
 * 获取真题列表
 * @param {Number} courseId 课程id
 */
function getQuestionList(courseId) {
  return btzx.ajax({
    url: 'section/findSectionBy',
    data: {
      courseId,
      sectionType: 8,
    },
  });
}

/**
 * 是否有资料
 * @param {Number} courseId 课程id
 * @param {Number} type 课程类型
 */
function isHasFile(courseId) {
  return btzx.ajax({
    url: 'videoHandout/isHas',
    data: {
      courseId,
      type: 12,
    },
  });
}

/**
 * 获取资料列表，读取讲义表
 * @param {Number} courseId 课程id
 */
function getHandoutList(courseId, type) {
  return btzx.ajax({
    url: 'videoHandout/findVideoHandout',
    data: {
      courseId,
      type,
    },
  });
}

/**
 * 获取某一课时信息
 * @param {Number} courseStageId 课时id
 */
function getCourseDetail(courseStageId) {
  return btzx.ajax({
    url: 'courseStage/getStageVideo',
    data: {
      courseStageId,
    },
  });
}

/**
 * 获取视频详细信息(未登录)
 * @param {Number} videoId 视频id
 */
function getVideoDetailNo(videoId) {
  return btzx.ajax({
    url: 'videoPlus/getVideo',
    data: {
      videoId,
    },
  });
}

/**
 * 获取视频详细信息
 * @param {Number} videoId 视频id
 */
function getVideoDetail(videoId) {
  return btzx.ajax({
    url: 'video/getDetail',
    data: {
      videoId,
      appType: 4,
      edition: 'v1_0_14'
    },
  });
}

/**
 * 获取加密视频信息（暂未启用）
 * @param {Number} videoId 视频id
 * @param {String} channelFlag 访问来源
 * @param {String} resourcesFlag 资源种类
 */
function getVideoInfoByAuth(videoId) {
  return btzx.ajax({
    url: 'videoPlus/getPlayInfo',
    data: {
      videoId,
      channelFlag: 1,
      resourcesFlag: 1
    },
  });
}

/**
 * 获取视频讲义
 * @param {Number} videoId 视频id
 */
function getVideoHandout(videoId) {
  return btzx.ajax({
    url: 'courseStage/getVideoHandoutByVideoId',
    data: {
      videoId,
    },
  });
}

/**
 * 保存用户观看视频进度
 * @param {Number} videoId 视频id
 * @param {Number} watchDuration 视频观看时长
 */
function saveVideoProgress(videoId, watchDuration) {
  return btzx.ajax({
    url: 'video/updateWatched',
    method: 'post',
    data: {
      videoId,
      watchDuration,
    },
  });
}


/**
 * 记录用户讲义下载记录
 * @param {Number} courseId 课程id
 * @param {Number} handoutId 讲义id
 */
 function saveUserHandout(handoutId, courseId) {
  return btzx.ajax({
    url: '/videoHandout/saveUserHandout',
    method: 'post',
    data: {
      handoutId,
      courseId,
    },
  });
}

/**
 * 记录用户视频下载记录
 * @param {Number} courseId 课程id
 * @param {Number} handoutId 讲义id
 */
 function saveUserVideo(courseId,videoId) {
  return btzx.ajax({
    url: '/videoPlus/saveUserVideo',
    method: 'post',
    data: {
      videoId,
      courseId,
    },
  });
}


/**
 * 获取反馈与回答集合
 */
 function getFeedbackList() {
  return btzx.ajax({
    url: '/recordFeedback/list',
    method: 'get',
    data: {

    },
  });
}


/**
 * 修改已读状态
 * @param {Number} replyId 回复id
 */
 function updateFeedbackRead(replyId) {
  return btzx.ajax({
    url: `/recordFeedback/updateRead/${replyId}`,
    method: 'post',
    data: {
     
    },
  });
}


export {
  autoLogin,
  login,
  getImageCode,
  sendSmscode,
  smscodeLogin,
  changeNick,
  changeSignature,
  changePassword,
  getProfession,
  getNotice,
  getHistoryVideo,
  getFreeCourse,
  getCourseList,
  getLessonList,
  getCourseProgress,
  getQuestionList,
  isHasFile,
  getHandoutList,
  getCourseDetail,
  getVideoDetailNo,
  getVideoDetail,
  getVideoInfoByAuth,
  getVideoHandout,
  saveVideoProgress,
  saveUserHandout,
  saveUserVideo,
  getFeedbackList,
  updateFeedbackRead
};
