import * as ced from './cedar';
import * as cedar from './cedar-api';
import AliPlayer from './aliPlayer';

// 调用下载模块下载
function aliDownload(videoId) {
  AliPlayer.init();
  AliPlayer.initDownloader();
  cedar.getVideoInfoByAuth(videoId)
    .then((res) => {
      const palyAuth = {
        vid: res.id,
        authInfo: res.auth
      }
      /**
       * AliPlayer模块下载需要两个接口：
       * 1. 先调用 prepareDownload 接口，验证下载信息
       * 2. 先调用 startDownload 接口，开始下载视频
       */
      AliPlayer.prepareDownload(palyAuth).then(() => {
        // 开始下载
        AliPlayer.startDownload()
      });
    })
}

// 下载方法（手动下载）
export function encryptDownload(videoId, title) {
  const encryptLocalVideos = ced.storage.get('encryptLocalVideos') || [];
  let currentDownloadFile = ced.storage.get('currentDownloadFile') || {};
  const downloadExist = encryptLocalVideos.findIndex(item => {
    return item.videoId === videoId;
  });

  if (downloadExist !== -1) {
    // ced.toast('该视频已下载，不可以重复下载哦！');
    encryptLocalVideos.splice(downloadExist, 1);
    // return
  }

  // 保存下载记录
  const videoInfo = {
    videoId: videoId,
    title: title,
    savePath: '',
  }

  // 保存到所有下载记录中
  encryptLocalVideos.push(videoInfo);
  ced.storage.set("encryptLocalVideos", encryptLocalVideos);
  ced.toast('已成功添加到离线中心列表')

  // 如果这是第一个视频，或前一个视频已完成，才开始下载 
  const index = encryptLocalVideos.findIndex(item => {
    return item.videoId === videoId;
  });
  if (index === 0 || (encryptLocalVideos[index-1] && encryptLocalVideos[index-1].savePath)) {
    currentDownloadFile = videoInfo;
    ced.storage.set("currentDownloadFile", currentDownloadFile);
    aliDownload(videoId);
  }
}

// 下载监听
export function _downloading(downloadInfo) {
  // 当前下载项
  let currentDownloadFile = ced.storage.get('currentDownloadFile') || {};
  // 下载列表
  let encryptLocalVideos = ced.storage.get('encryptLocalVideos') || [];

  if (downloadInfo.progress) {
    // 下载中
    if (downloadInfo.progress % 20 === 0) {
      console.log('正在下载' + currentDownloadFile.title + '，当前进度:' + downloadInfo.progress);
    }
  } else if (downloadInfo.status) {
    // 下载完成
    // 获取列表中当前下载项的 index
    const index = encryptLocalVideos.findIndex(item => item.videoId === currentDownloadFile.videoId);
    // 将下载地址赋值给当前下载项
    currentDownloadFile.savePath = downloadInfo.downloadedFilePath;
    // 将列表中当前下载项重新赋值,并保存在本地
    encryptLocalVideos[index] = currentDownloadFile;
    ced.storage.set('encryptLocalVideos', encryptLocalVideos);

    // 重新保存本地下载项
    ced.storage.set('currentDownloadFile', currentDownloadFile);
    console.log(JSON.stringify(encryptLocalVideos));

    // 判断是否为列表中最后一个视频。如果是，结束方法；否则发送下个视频的下载事件
    if (encryptLocalVideos.length === index + 1) return;

    // 发送下个视频的下载事件
    ced.storage.set('currentDownloadFile', encryptLocalVideos[index + 1]);
    setTimeout(() => {
      aliDownload(encryptLocalVideos[index + 1].videoId);
    }, 1000)
  } else {
    ced.toast('下载失败，请检查网络或设备存储剩余空间');
    // 如果某个视频下载失败
    // 1. 将此视频移出 encryptLocalVideos 列表，并随之添加到 errorLocalVideos 列表
    // 2. 如果 encryptLocalVideos 列表中有下个视频的话，开始下个视频的下载
    // 3. 如果没有后续视频，重置 currentDownloadFile 为 encryptLocalVideos 列表最后一个的视频信息

    // 下载失败视频列表
    const errorLocalVideos = ced.storage.get('errorLocalVideos') || [];
    // 获取列表中当前下载项的index
    const index = encryptLocalVideos.findIndex(item => item.videoId === currentDownloadFile.videoId);
    encryptLocalVideos.splice(index, 1); // 注意此时已经删除了失败视频，所以之后的使用 index 都指后一个视频
    errorLocalVideos.push(currentDownloadFile);
    ced.storage.set("encryptLocalVideos", encryptLocalVideos);

    // 判断是否为列表中最后一个视频。如果是，重置 currentDownloadFile 为上一个视频信息；否则发送下个视频的下载事件
    if (encryptLocalVideos.length === index) {
      currentDownloadFile = encryptLocalVideos[index - 1];
      ced.storage.set('currentDownloadFile', currentDownloadFile);
    } else {
      // 发送下个视频的下载事件
      ced.storage.set('currentDownloadFile', encryptLocalVideos[index]);
      aliDownload(encryptLocalVideos[index].videoId);
    }
  }
}