import * as btzx from './btzx';
const downloadManager = api.require('downloadManager');

// 根据映射的ID查询下载项
function queryById(id) {
  const map = getMap();
  const downloadId = Object.keys(map).find((item) => map[item] === id);

  if (!downloadId) {
    return Promise.resolve();
  }

  return new Promise((resolve, reject) => {
    downloadManager.query(
      {
        ids: [downloadId],
      },
      (ret, err) => {
        if (ret) {
          if (ret.data && ret.data.length) {
            resolve(ret.data[0]);
          } else {
            delMap(downloadId);
            resolve();
          }
        } else {
          reject(err);
        }
      },
    );
  });
}

// 开启下载
function enqueue(title, url, mapId, savePath) {
  return new Promise((resolve, reject) => {
    downloadManager.enqueue(
      {
        title,
        url,
        savePath,
        allowResume: true, // 开启断点续传
      },
      (ret, err) => {
        if (ret) {
          addMap(ret.id, mapId);
          resolve(ret);
        } else {
          reject(err);
        }
      },
    );
  });
}

// 打开下载管理
function openManagerView() {
  downloadManager.openManagerView(
    {
      title: '下载管理',
    },
    (ret) => {
      if (ret && ret.id) {
        // 点击某个下载完成项
        const mapId = getMap(ret.id);
        if (mapId) {
          openVideo(mapId);
        } else {
          openDownloadedFile(id);
        }
      }
    },
  );
}

// 打开下载文件
function openDownloadedFile(id) {
  downloadManager.openDownloadedFile({ id });
}

// 打开视频播放页
function openVideo(videoId) {
  api.openWin({
    name: 'video',
    url: 'widget://pages/video/video.stml',
    slidBackEnabled: false,
    pageParam: {
      videoId,
    },
  });
}

// 获取映射
function getMap(downloadId) {
  const map = btzx.storage.get('downloadMap') || {};
  return downloadId ? map[downloadId] : map;
}

// 保存映射
function setMap(map) {
  return btzx.storage.set('downloadMap', map);
}

// 添加映射
function addMap(downloadId, id) {
  const map = getMap();
  map[downloadId] = id;
  setMap(map);
}

// 删除某一映射
function delMap(downloadId) {
  const map = getMap();
  delete map[downloadId];
  setMap(map);
}

export {
  queryById, enqueue, addMap, openManagerView,
};
