const downloadManager = api.require('downloadManager');
import * as ced from './cedar';

// 查询下载状态，当查询条件均为空时，返回所有下载记录信息
function query(id) {
  return new Promise(function (resolve, reject) {
    downloadManager.query({
      ids: id instanceof Array ? id : [id],
    }, function (ret, err) {
      if (ret) {
        ret.data && ret.data.length > 0 && resolve(ret.data);
      } else {
        console.log(JSON.stringify(err));
      }
    });
  });
};

// 根据映射的ID查询下载项
function queryById(id) {
  const map = getMap();
  const downloadId = Object.keys(map).find((item) => map[item] === id);

  if (!downloadId) {
    return Promise.resolve();
  }

  return new Promise((resolve, reject) => {
    downloadManager.query({
      ids: [downloadId],
    }, (ret, err) => {
      if (ret) {
        if (ret.data && ret.data.length) {
          resolve(ret.data[0]);
        } else {
          delMap(downloadId);
          resolve();
        }
      } else {
        reject(err);
      }
    },
    );
  });
}

// 暂停下载
function pause(id) {
  if (!id) {
    return;
  }

  return new Promise(function (resolve, reject) {
    downloadManager.pause({
      id: id
    }, function (ret, err) {
      if (ret.status) {
        resolve(ret);
      } else {
        console.log(JSON.stringify(err));
      }
    });
  });
};

// 继续下载
function resume(id) {
  if (!id) {
    return;
  }

  return new Promise(function (resolve, reject) {
    downloadManager.resume({
      id: id
    }, function (ret, err) {
      if (ret.status) {
        resolve(ret);
      } else {
        console.log(JSON.stringify(err));
      }
    });
  });
};

// 删除下载
function remove(id) {
  if (!id) {
    return;
  }

  return new Promise(function (resolve, reject) {
    downloadManager.remove({
      ids: [id],
      deleteFiles: true
    }, function (ret, err) {
      if (ret) {
        resolve(ret);
      } else {
        resolve(err);
      }
    });
  });
};

// 获取映射
function getMap(downloadId) {
  const map = ced.storage.get('downloadMap') || {};
  return downloadId ? map[downloadId] : map;
}

// 保存映射
function setMap(map) {
  return ced.storage.set('downloadMap', map);
}

// 添加映射
function addMap(downloadId, id) {
  const map = getMap();
  map[downloadId] = id;
  setMap(map);
}

// 删除某一映射
function delMap(downloadId) {
  const map = getMap();
  delete map[downloadId];
  setMap(map);
}

export {
  downloadManager,
  query,
  queryById,
  pause,
  resume,
  remove,
  getMap,
  setMap,
  addMap,
  delMap,
};
