/*
 * iap 模块封装了 iOS 系统应用内购买相关功能
 */

export default {
  module: null, // 模块

  // 初始化
  init() {
    this.module = api.require('iap'); // 引入模块
  },

  /**
   * 获取有效商品列表
   * @param {Array} productIds 商品id列表
   */
  getProducts(productIds) {
    return new Promise((resolve, reject) => {
      this.module.getProducts({
        productIds,
      }, (ret, err) => {
        if (ret) {
          resolve(ret.products);
        }
        reject(err);
      },
      );
    });
  },

  /**
   * 购买商品
   * @param {String} productId 有效的商品id
   * @param {String} applicationUsername 用户信息
   * @param {Function} callback 回调函数
   */
  purchase(productId, applicationUsername, callback) {
    this.module.purchase(
      {
        productId,
        applicationUsername,
      },
      callback,
    );
  },

  /**
   * 完成指定交易，在完成购买并提供给用户相关功能后应该完成此次交易。
   * @param {String} transactionId 交易id
   */
  finishTransaction(transactionId) {
    this.module.finishTransaction({
      transactionId,
    });
  },

  /**
   * 恢复用户以前购买过的所有商品交易
   * @param {String} applicationUsername 用户信息
   * @param {Function} callback 回调函数
   */
  restoreTransactions(applicationUsername, callback) {
    this.module.restoreTransactions(applicationUsername, callback);
  },
};
